/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCloudflareInfrastructureAccessTargetsConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#account_id DataCloudflareInfrastructureAccessTargets#account_id}
    */
    readonly accountId: string;
    /**
    * A date and time after a target was created to filter on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#created_after DataCloudflareInfrastructureAccessTargets#created_after}
    */
    readonly createdAfter?: string;
    /**
    * The hostname of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#hostname DataCloudflareInfrastructureAccessTargets#hostname}
    */
    readonly hostname?: string;
    /**
    * Partial match to the hostname of a target
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#hostname_contains DataCloudflareInfrastructureAccessTargets#hostname_contains}
    */
    readonly hostnameContains?: string;
    /**
    * The target's IPv4 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ipv4 DataCloudflareInfrastructureAccessTargets#ipv4}
    */
    readonly ipv4?: string;
    /**
    * The target's IPv6 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ipv6 DataCloudflareInfrastructureAccessTargets#ipv6}
    */
    readonly ipv6?: string;
    /**
    * A date and time after a target was modified to filter on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#modified_after DataCloudflareInfrastructureAccessTargets#modified_after}
    */
    readonly modifiedAfter?: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#virtual_network_id DataCloudflareInfrastructureAccessTargets#virtual_network_id}
    */
    readonly virtualNetworkId?: string;
}
export interface DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4 {
    /**
    * The IP address of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ip_addr DataCloudflareInfrastructureAccessTargets#ip_addr}
    */
    readonly ipAddr: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#virtual_network_id DataCloudflareInfrastructureAccessTargets#virtual_network_id}
    */
    readonly virtualNetworkId: string;
}
export declare function dataCloudflareInfrastructureAccessTargetsTargetsIpIpv4ToTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4 | cdktf.IResolvable): any;
export declare function dataCloudflareInfrastructureAccessTargetsTargetsIpIpv4ToHclTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4 | cdktf.IResolvable): any;
export declare class DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4 | cdktf.IResolvable | undefined;
    set internalValue(value: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4 | cdktf.IResolvable | undefined);
    private _ipAddr?;
    get ipAddr(): string;
    set ipAddr(value: string);
    get ipAddrInput(): string | undefined;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    get virtualNetworkIdInput(): string | undefined;
}
export interface DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6 {
    /**
    * The IP address of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ip_addr DataCloudflareInfrastructureAccessTargets#ip_addr}
    */
    readonly ipAddr: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#virtual_network_id DataCloudflareInfrastructureAccessTargets#virtual_network_id}
    */
    readonly virtualNetworkId: string;
}
export declare function dataCloudflareInfrastructureAccessTargetsTargetsIpIpv6ToTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6 | cdktf.IResolvable): any;
export declare function dataCloudflareInfrastructureAccessTargetsTargetsIpIpv6ToHclTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6 | cdktf.IResolvable): any;
export declare class DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6 | cdktf.IResolvable | undefined;
    set internalValue(value: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6 | cdktf.IResolvable | undefined);
    private _ipAddr?;
    get ipAddr(): string;
    set ipAddr(value: string);
    get ipAddrInput(): string | undefined;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    get virtualNetworkIdInput(): string | undefined;
}
export interface DataCloudflareInfrastructureAccessTargetsTargetsIp {
    /**
    * The target's IPv4 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ipv4 DataCloudflareInfrastructureAccessTargets#ipv4}
    */
    readonly ipv4?: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4;
    /**
    * The target's IPv6 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ipv6 DataCloudflareInfrastructureAccessTargets#ipv6}
    */
    readonly ipv6?: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6;
}
export declare function dataCloudflareInfrastructureAccessTargetsTargetsIpToTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargetsIp): any;
export declare function dataCloudflareInfrastructureAccessTargetsTargetsIpToHclTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargetsIp): any;
export declare class DataCloudflareInfrastructureAccessTargetsTargetsIpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCloudflareInfrastructureAccessTargetsTargetsIp | undefined;
    set internalValue(value: DataCloudflareInfrastructureAccessTargetsTargetsIp | undefined);
    private _ipv4;
    get ipv4(): DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4OutputReference;
    putIpv4(value: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4): void;
    resetIpv4(): void;
    get ipv4Input(): cdktf.IResolvable | DataCloudflareInfrastructureAccessTargetsTargetsIpIpv4 | undefined;
    private _ipv6;
    get ipv6(): DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6OutputReference;
    putIpv6(value: DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6): void;
    resetIpv6(): void;
    get ipv6Input(): cdktf.IResolvable | DataCloudflareInfrastructureAccessTargetsTargetsIpIpv6 | undefined;
}
export interface DataCloudflareInfrastructureAccessTargetsTargets {
    /**
    * The IPv4/IPv6 address that identifies where to reach a target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#ip DataCloudflareInfrastructureAccessTargets#ip}
    */
    readonly ip: DataCloudflareInfrastructureAccessTargetsTargetsIp;
}
export declare function dataCloudflareInfrastructureAccessTargetsTargetsToTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargets): any;
export declare function dataCloudflareInfrastructureAccessTargetsTargetsToHclTerraform(struct?: DataCloudflareInfrastructureAccessTargetsTargets): any;
export declare class DataCloudflareInfrastructureAccessTargetsTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataCloudflareInfrastructureAccessTargetsTargets | undefined;
    set internalValue(value: DataCloudflareInfrastructureAccessTargetsTargets | undefined);
    get accountId(): string;
    get createdAt(): string;
    get hostname(): string;
    get id(): string;
    private _ip;
    get ip(): DataCloudflareInfrastructureAccessTargetsTargetsIpOutputReference;
    putIp(value: DataCloudflareInfrastructureAccessTargetsTargetsIp): void;
    get ipInput(): DataCloudflareInfrastructureAccessTargetsTargetsIp | undefined;
    get modifiedAt(): string;
}
export declare class DataCloudflareInfrastructureAccessTargetsTargetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataCloudflareInfrastructureAccessTargetsTargets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataCloudflareInfrastructureAccessTargetsTargetsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets cloudflare_infrastructure_access_targets}
*/
export declare class DataCloudflareInfrastructureAccessTargets extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "cloudflare_infrastructure_access_targets";
    /**
    * Generates CDKTF code for importing a DataCloudflareInfrastructureAccessTargets resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCloudflareInfrastructureAccessTargets to import
    * @param importFromId The id of the existing DataCloudflareInfrastructureAccessTargets that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCloudflareInfrastructureAccessTargets to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/data-sources/infrastructure_access_targets cloudflare_infrastructure_access_targets} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCloudflareInfrastructureAccessTargetsConfig
    */
    constructor(scope: Construct, id: string, config: DataCloudflareInfrastructureAccessTargetsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _createdAfter?;
    get createdAfter(): string;
    set createdAfter(value: string);
    resetCreatedAfter(): void;
    get createdAfterInput(): string | undefined;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    resetHostname(): void;
    get hostnameInput(): string | undefined;
    private _hostnameContains?;
    get hostnameContains(): string;
    set hostnameContains(value: string);
    resetHostnameContains(): void;
    get hostnameContainsInput(): string | undefined;
    private _ipv4?;
    get ipv4(): string;
    set ipv4(value: string);
    resetIpv4(): void;
    get ipv4Input(): string | undefined;
    private _ipv6?;
    get ipv6(): string;
    set ipv6(value: string);
    resetIpv6(): void;
    get ipv6Input(): string | undefined;
    private _modifiedAfter?;
    get modifiedAfter(): string;
    set modifiedAfter(value: string);
    resetModifiedAfter(): void;
    get modifiedAfterInput(): string | undefined;
    private _targets;
    get targets(): DataCloudflareInfrastructureAccessTargetsTargetsList;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    resetVirtualNetworkId(): void;
    get virtualNetworkIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
