/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface InfrastructureAccessTargetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#account_id InfrastructureAccessTarget#account_id}
    */
    readonly accountId: string;
    /**
    * A non-unique field that refers to a target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#hostname InfrastructureAccessTarget#hostname}
    */
    readonly hostname: string;
    /**
    * The IPv4/IPv6 address that identifies where to reach a target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#ip InfrastructureAccessTarget#ip}
    */
    readonly ip: InfrastructureAccessTargetIp;
}
export interface InfrastructureAccessTargetIpIpv4 {
    /**
    * The IP address of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#ip_addr InfrastructureAccessTarget#ip_addr}
    */
    readonly ipAddr: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#virtual_network_id InfrastructureAccessTarget#virtual_network_id}
    */
    readonly virtualNetworkId: string;
}
export declare function infrastructureAccessTargetIpIpv4ToTerraform(struct?: InfrastructureAccessTargetIpIpv4 | cdktf.IResolvable): any;
export declare function infrastructureAccessTargetIpIpv4ToHclTerraform(struct?: InfrastructureAccessTargetIpIpv4 | cdktf.IResolvable): any;
export declare class InfrastructureAccessTargetIpIpv4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): InfrastructureAccessTargetIpIpv4 | cdktf.IResolvable | undefined;
    set internalValue(value: InfrastructureAccessTargetIpIpv4 | cdktf.IResolvable | undefined);
    private _ipAddr?;
    get ipAddr(): string;
    set ipAddr(value: string);
    get ipAddrInput(): string | undefined;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    get virtualNetworkIdInput(): string | undefined;
}
export interface InfrastructureAccessTargetIpIpv6 {
    /**
    * The IP address of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#ip_addr InfrastructureAccessTarget#ip_addr}
    */
    readonly ipAddr: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#virtual_network_id InfrastructureAccessTarget#virtual_network_id}
    */
    readonly virtualNetworkId: string;
}
export declare function infrastructureAccessTargetIpIpv6ToTerraform(struct?: InfrastructureAccessTargetIpIpv6 | cdktf.IResolvable): any;
export declare function infrastructureAccessTargetIpIpv6ToHclTerraform(struct?: InfrastructureAccessTargetIpIpv6 | cdktf.IResolvable): any;
export declare class InfrastructureAccessTargetIpIpv6OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): InfrastructureAccessTargetIpIpv6 | cdktf.IResolvable | undefined;
    set internalValue(value: InfrastructureAccessTargetIpIpv6 | cdktf.IResolvable | undefined);
    private _ipAddr?;
    get ipAddr(): string;
    set ipAddr(value: string);
    get ipAddrInput(): string | undefined;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    get virtualNetworkIdInput(): string | undefined;
}
export interface InfrastructureAccessTargetIp {
    /**
    * The target's IPv4 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#ipv4 InfrastructureAccessTarget#ipv4}
    */
    readonly ipv4?: InfrastructureAccessTargetIpIpv4;
    /**
    * The target's IPv6 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#ipv6 InfrastructureAccessTarget#ipv6}
    */
    readonly ipv6?: InfrastructureAccessTargetIpIpv6;
}
export declare function infrastructureAccessTargetIpToTerraform(struct?: InfrastructureAccessTargetIp | cdktf.IResolvable): any;
export declare function infrastructureAccessTargetIpToHclTerraform(struct?: InfrastructureAccessTargetIp | cdktf.IResolvable): any;
export declare class InfrastructureAccessTargetIpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): InfrastructureAccessTargetIp | cdktf.IResolvable | undefined;
    set internalValue(value: InfrastructureAccessTargetIp | cdktf.IResolvable | undefined);
    private _ipv4;
    get ipv4(): InfrastructureAccessTargetIpIpv4OutputReference;
    putIpv4(value: InfrastructureAccessTargetIpIpv4): void;
    resetIpv4(): void;
    get ipv4Input(): cdktf.IResolvable | InfrastructureAccessTargetIpIpv4 | undefined;
    private _ipv6;
    get ipv6(): InfrastructureAccessTargetIpIpv6OutputReference;
    putIpv6(value: InfrastructureAccessTargetIpIpv6): void;
    resetIpv6(): void;
    get ipv6Input(): cdktf.IResolvable | InfrastructureAccessTargetIpIpv6 | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target cloudflare_infrastructure_access_target}
*/
export declare class InfrastructureAccessTarget extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_infrastructure_access_target";
    /**
    * Generates CDKTF code for importing a InfrastructureAccessTarget resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the InfrastructureAccessTarget to import
    * @param importFromId The id of the existing InfrastructureAccessTarget that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the InfrastructureAccessTarget to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/infrastructure_access_target cloudflare_infrastructure_access_target} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options InfrastructureAccessTargetConfig
    */
    constructor(scope: Construct, id: string, config: InfrastructureAccessTargetConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get createdAt(): string;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    get hostnameInput(): string | undefined;
    get id(): string;
    private _ip;
    get ip(): InfrastructureAccessTargetIpOutputReference;
    putIp(value: InfrastructureAccessTargetIp): void;
    get ipInput(): cdktf.IResolvable | InfrastructureAccessTargetIp | undefined;
    get modifiedAt(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
