/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ListItemAConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#account_id ListItemA#account_id}
    */
    readonly accountId: string;
    /**
    * Autonomous system number to include in the list. Must provide only one of: `ip`, `asn`, `redirect`, `hostname`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#asn ListItemA#asn}
    */
    readonly asn?: number;
    /**
    * An optional comment for the item.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#comment ListItemA#comment}
    */
    readonly comment?: string;
    /**
    * IP address to include in the list. Must provide only one of: `ip`, `asn`, `redirect`, `hostname`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#ip ListItemA#ip}
    */
    readonly ip?: string;
    /**
    * The list identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#list_id ListItemA#list_id}
    */
    readonly listId: string;
    /**
    * hostname block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#hostname ListItemA#hostname}
    */
    readonly hostname?: ListItemHostname[] | cdktf.IResolvable;
    /**
    * redirect block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#redirect ListItemA#redirect}
    */
    readonly redirect?: ListItemRedirect[] | cdktf.IResolvable;
}
export interface ListItemHostname {
    /**
    * The FQDN to match on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#url_hostname ListItemA#url_hostname}
    */
    readonly urlHostname: string;
}
export declare function listItemHostnameToTerraform(struct?: ListItemHostname | cdktf.IResolvable): any;
export declare function listItemHostnameToHclTerraform(struct?: ListItemHostname | cdktf.IResolvable): any;
export declare class ListItemHostnameOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ListItemHostname | cdktf.IResolvable | undefined;
    set internalValue(value: ListItemHostname | cdktf.IResolvable | undefined);
    private _urlHostname?;
    get urlHostname(): string;
    set urlHostname(value: string);
    get urlHostnameInput(): string | undefined;
}
export declare class ListItemHostnameList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ListItemHostname[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ListItemHostnameOutputReference;
}
export interface ListItemRedirect {
    /**
    * Whether the redirect also matches subdomains of the source url.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#include_subdomains ListItemA#include_subdomains}
    */
    readonly includeSubdomains?: boolean | cdktf.IResolvable;
    /**
    * Whether the redirect target url should keep the query string of the request's url.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#preserve_path_suffix ListItemA#preserve_path_suffix}
    */
    readonly preservePathSuffix?: boolean | cdktf.IResolvable;
    /**
    * Whether the redirect target url should keep the query string of the request's url.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#preserve_query_string ListItemA#preserve_query_string}
    */
    readonly preserveQueryString?: boolean | cdktf.IResolvable;
    /**
    * The source url of the redirect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#source_url ListItemA#source_url}
    */
    readonly sourceUrl: string;
    /**
    * The status code to be used when redirecting a request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#status_code ListItemA#status_code}
    */
    readonly statusCode?: number;
    /**
    * Whether the redirect also matches subpaths of the source url.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#subpath_matching ListItemA#subpath_matching}
    */
    readonly subpathMatching?: boolean | cdktf.IResolvable;
    /**
    * The target url of the redirect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#target_url ListItemA#target_url}
    */
    readonly targetUrl: string;
}
export declare function listItemRedirectToTerraform(struct?: ListItemRedirect | cdktf.IResolvable): any;
export declare function listItemRedirectToHclTerraform(struct?: ListItemRedirect | cdktf.IResolvable): any;
export declare class ListItemRedirectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ListItemRedirect | cdktf.IResolvable | undefined;
    set internalValue(value: ListItemRedirect | cdktf.IResolvable | undefined);
    private _includeSubdomains?;
    get includeSubdomains(): boolean | cdktf.IResolvable;
    set includeSubdomains(value: boolean | cdktf.IResolvable);
    resetIncludeSubdomains(): void;
    get includeSubdomainsInput(): boolean | cdktf.IResolvable | undefined;
    private _preservePathSuffix?;
    get preservePathSuffix(): boolean | cdktf.IResolvable;
    set preservePathSuffix(value: boolean | cdktf.IResolvable);
    resetPreservePathSuffix(): void;
    get preservePathSuffixInput(): boolean | cdktf.IResolvable | undefined;
    private _preserveQueryString?;
    get preserveQueryString(): boolean | cdktf.IResolvable;
    set preserveQueryString(value: boolean | cdktf.IResolvable);
    resetPreserveQueryString(): void;
    get preserveQueryStringInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceUrl?;
    get sourceUrl(): string;
    set sourceUrl(value: string);
    get sourceUrlInput(): string | undefined;
    private _statusCode?;
    get statusCode(): number;
    set statusCode(value: number);
    resetStatusCode(): void;
    get statusCodeInput(): number | undefined;
    private _subpathMatching?;
    get subpathMatching(): boolean | cdktf.IResolvable;
    set subpathMatching(value: boolean | cdktf.IResolvable);
    resetSubpathMatching(): void;
    get subpathMatchingInput(): boolean | cdktf.IResolvable | undefined;
    private _targetUrl?;
    get targetUrl(): string;
    set targetUrl(value: string);
    get targetUrlInput(): string | undefined;
}
export declare class ListItemRedirectList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ListItemRedirect[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ListItemRedirectOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item cloudflare_list_item}
*/
export declare class ListItemA extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_list_item";
    /**
    * Generates CDKTF code for importing a ListItemA resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ListItemA to import
    * @param importFromId The id of the existing ListItemA that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ListItemA to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/list_item cloudflare_list_item} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ListItemAConfig
    */
    constructor(scope: Construct, id: string, config: ListItemAConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _asn?;
    get asn(): number;
    set asn(value: number);
    resetAsn(): void;
    get asnInput(): number | undefined;
    private _comment?;
    get comment(): string;
    set comment(value: string);
    resetComment(): void;
    get commentInput(): string | undefined;
    get id(): string;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _listId?;
    get listId(): string;
    set listId(value: string);
    get listIdInput(): string | undefined;
    private _hostname;
    get hostname(): ListItemHostnameList;
    putHostname(value: ListItemHostname[] | cdktf.IResolvable): void;
    resetHostname(): void;
    get hostnameInput(): cdktf.IResolvable | ListItemHostname[] | undefined;
    private _redirect;
    get redirect(): ListItemRedirectList;
    putRedirect(value: ListItemRedirect[] | cdktf.IResolvable): void;
    resetRedirect(): void;
    get redirectInput(): cdktf.IResolvable | ListItemRedirect[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
