/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LogpushJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. Must provide only one of `account_id`, `zone_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#account_id LogpushJob#account_id}
    */
    readonly accountId?: string;
    /**
    * The kind of the dataset to use with the logpush job. Available values: `access_requests`, `casb_findings`, `firewall_events`, `http_requests`, `spectrum_events`, `nel_reports`, `audit_logs`, `gateway_dns`, `gateway_http`, `gateway_network`, `dns_logs`, `network_analytics_logs`, `workers_trace_events`, `device_posture_results`, `zero_trust_network_sessions`, `magic_ids_detections`, `page_shield_events`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#dataset LogpushJob#dataset}
    */
    readonly dataset: string;
    /**
    * Uniquely identifies a resource (such as an s3 bucket) where data will be pushed. Additional configuration parameters supported by the destination may be included. See [Logpush destination documentation](https://developers.cloudflare.com/logs/reference/logpush-api-configuration#destination).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#destination_conf LogpushJob#destination_conf}
    */
    readonly destinationConf: string;
    /**
    * Whether to enable the job.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#enabled LogpushJob#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Use filters to select the events to include and/or remove from your logs. For more information, refer to [Filters](https://developers.cloudflare.com/logs/reference/logpush-api-configuration/filters/).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#filter LogpushJob#filter}
    */
    readonly filter?: string;
    /**
    * A higher frequency will result in logs being pushed on faster with smaller files. `low` frequency will push logs less often with larger files. Available values: `high`, `low`. Defaults to `high`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#frequency LogpushJob#frequency}
    */
    readonly frequency?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#id LogpushJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The kind of logpush job to create. Available values: `edge`, `instant-logs`, `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#kind LogpushJob#kind}
    */
    readonly kind?: string;
    /**
    * Configuration string for the Logshare API. It specifies things like requested fields and timestamp formats. See [Logpush options documentation](https://developers.cloudflare.com/logs/logpush/logpush-configuration-api/understanding-logpush-api/#options).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#logpull_options LogpushJob#logpull_options}
    */
    readonly logpullOptions?: string;
    /**
    * The maximum uncompressed file size of a batch of logs. Value must be between 5MB and 1GB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#max_upload_bytes LogpushJob#max_upload_bytes}
    */
    readonly maxUploadBytes?: number;
    /**
    * The maximum interval in seconds for log batches. Value must be between 30 and 300.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#max_upload_interval_seconds LogpushJob#max_upload_interval_seconds}
    */
    readonly maxUploadIntervalSeconds?: number;
    /**
    * The maximum number of log lines per batch. Value must be between 1000 and 1,000,000.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#max_upload_records LogpushJob#max_upload_records}
    */
    readonly maxUploadRecords?: number;
    /**
    * The name of the logpush job to create.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#name LogpushJob#name}
    */
    readonly name?: string;
    /**
    * Ownership challenge token to prove destination ownership, required when destination is Amazon S3, Google Cloud Storage, Microsoft Azure or Sumo Logic. See [Developer documentation](https://developers.cloudflare.com/logs/logpush/logpush-configuration-api/understanding-logpush-api/#usage).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#ownership_challenge LogpushJob#ownership_challenge}
    */
    readonly ownershipChallenge?: string;
    /**
    * The zone identifier to target for the resource. Must provide only one of `account_id`, `zone_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#zone_id LogpushJob#zone_id}
    */
    readonly zoneId?: string;
    /**
    * output_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#output_options LogpushJob#output_options}
    */
    readonly outputOptions?: LogpushJobOutputOptions;
}
export interface LogpushJobOutputOptions {
    /**
    * String to be prepended before each batch.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#batch_prefix LogpushJob#batch_prefix}
    */
    readonly batchPrefix?: string;
    /**
    * String to be appended after each batch.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#batch_suffix LogpushJob#batch_suffix}
    */
    readonly batchSuffix?: string;
    /**
    * Mitigation for CVE-2021-44228. If set to true, will cause all occurrences of ${ in the generated files to be replaced with x{. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#cve20214428 LogpushJob#cve20214428}
    */
    readonly cve20214428?: boolean | cdktf.IResolvable;
    /**
    * String to join fields. This field be ignored when record_template is set. Defaults to `,`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#field_delimiter LogpushJob#field_delimiter}
    */
    readonly fieldDelimiter?: string;
    /**
    * List of field names to be included in the Logpush output.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#field_names LogpushJob#field_names}
    */
    readonly fieldNames?: string[];
    /**
    * Specifies the output type. Available values: `ndjson`, `csv`. Defaults to `ndjson`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#output_type LogpushJob#output_type}
    */
    readonly outputType?: string;
    /**
    * String to be inserted in-between the records as separator.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#record_delimiter LogpushJob#record_delimiter}
    */
    readonly recordDelimiter?: string;
    /**
    * String to be prepended before each record. Defaults to `{`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#record_prefix LogpushJob#record_prefix}
    */
    readonly recordPrefix?: string;
    /**
    * String to be appended after each record. Defaults to `}
    * `.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#record_suffix LogpushJob#record_suffix}
    */
    readonly recordSuffix?: string;
    /**
    * String to use as template for each record instead of the default comma-separated list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#record_template LogpushJob#record_template}
    */
    readonly recordTemplate?: string;
    /**
    * Specifies the sampling rate. Defaults to `1`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#sample_rate LogpushJob#sample_rate}
    */
    readonly sampleRate?: number;
    /**
    * Specifies the format for timestamps. Available values: `unixnano`, `unix`, `rfc3339`. Defaults to `unixnano`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#timestamp_format LogpushJob#timestamp_format}
    */
    readonly timestampFormat?: string;
}
export declare function logpushJobOutputOptionsToTerraform(struct?: LogpushJobOutputOptionsOutputReference | LogpushJobOutputOptions): any;
export declare function logpushJobOutputOptionsToHclTerraform(struct?: LogpushJobOutputOptionsOutputReference | LogpushJobOutputOptions): any;
export declare class LogpushJobOutputOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): LogpushJobOutputOptions | undefined;
    set internalValue(value: LogpushJobOutputOptions | undefined);
    private _batchPrefix?;
    get batchPrefix(): string;
    set batchPrefix(value: string);
    resetBatchPrefix(): void;
    get batchPrefixInput(): string | undefined;
    private _batchSuffix?;
    get batchSuffix(): string;
    set batchSuffix(value: string);
    resetBatchSuffix(): void;
    get batchSuffixInput(): string | undefined;
    private _cve20214428?;
    get cve20214428(): boolean | cdktf.IResolvable;
    set cve20214428(value: boolean | cdktf.IResolvable);
    resetCve20214428(): void;
    get cve20214428Input(): boolean | cdktf.IResolvable | undefined;
    private _fieldDelimiter?;
    get fieldDelimiter(): string;
    set fieldDelimiter(value: string);
    resetFieldDelimiter(): void;
    get fieldDelimiterInput(): string | undefined;
    private _fieldNames?;
    get fieldNames(): string[];
    set fieldNames(value: string[]);
    resetFieldNames(): void;
    get fieldNamesInput(): string[] | undefined;
    private _outputType?;
    get outputType(): string;
    set outputType(value: string);
    resetOutputType(): void;
    get outputTypeInput(): string | undefined;
    private _recordDelimiter?;
    get recordDelimiter(): string;
    set recordDelimiter(value: string);
    resetRecordDelimiter(): void;
    get recordDelimiterInput(): string | undefined;
    private _recordPrefix?;
    get recordPrefix(): string;
    set recordPrefix(value: string);
    resetRecordPrefix(): void;
    get recordPrefixInput(): string | undefined;
    private _recordSuffix?;
    get recordSuffix(): string;
    set recordSuffix(value: string);
    resetRecordSuffix(): void;
    get recordSuffixInput(): string | undefined;
    private _recordTemplate?;
    get recordTemplate(): string;
    set recordTemplate(value: string);
    resetRecordTemplate(): void;
    get recordTemplateInput(): string | undefined;
    private _sampleRate?;
    get sampleRate(): number;
    set sampleRate(value: number);
    resetSampleRate(): void;
    get sampleRateInput(): number | undefined;
    private _timestampFormat?;
    get timestampFormat(): string;
    set timestampFormat(value: string);
    resetTimestampFormat(): void;
    get timestampFormatInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job cloudflare_logpush_job}
*/
export declare class LogpushJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_logpush_job";
    /**
    * Generates CDKTF code for importing a LogpushJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LogpushJob to import
    * @param importFromId The id of the existing LogpushJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LogpushJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/logpush_job cloudflare_logpush_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LogpushJobConfig
    */
    constructor(scope: Construct, id: string, config: LogpushJobConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    get datasetInput(): string | undefined;
    private _destinationConf?;
    get destinationConf(): string;
    set destinationConf(value: string);
    get destinationConfInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kind?;
    get kind(): string;
    set kind(value: string);
    resetKind(): void;
    get kindInput(): string | undefined;
    private _logpullOptions?;
    get logpullOptions(): string;
    set logpullOptions(value: string);
    resetLogpullOptions(): void;
    get logpullOptionsInput(): string | undefined;
    private _maxUploadBytes?;
    get maxUploadBytes(): number;
    set maxUploadBytes(value: number);
    resetMaxUploadBytes(): void;
    get maxUploadBytesInput(): number | undefined;
    private _maxUploadIntervalSeconds?;
    get maxUploadIntervalSeconds(): number;
    set maxUploadIntervalSeconds(value: number);
    resetMaxUploadIntervalSeconds(): void;
    get maxUploadIntervalSecondsInput(): number | undefined;
    private _maxUploadRecords?;
    get maxUploadRecords(): number;
    set maxUploadRecords(value: number);
    resetMaxUploadRecords(): void;
    get maxUploadRecordsInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _ownershipChallenge?;
    get ownershipChallenge(): string;
    set ownershipChallenge(value: string);
    resetOwnershipChallenge(): void;
    get ownershipChallengeInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    private _outputOptions;
    get outputOptions(): LogpushJobOutputOptionsOutputReference;
    putOutputOptions(value: LogpushJobOutputOptions): void;
    resetOutputOptions(): void;
    get outputOptionsInput(): LogpushJobOutputOptions | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
