/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MagicFirewallRulesetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset#account_id MagicFirewallRuleset#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset#description MagicFirewallRuleset#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset#id MagicFirewallRuleset#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset#name MagicFirewallRuleset#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset#rules MagicFirewallRuleset#rules}
    */
    readonly rules?: {
        [key: string]: string;
    }[] | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset cloudflare_magic_firewall_ruleset}
*/
export declare class MagicFirewallRuleset extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_magic_firewall_ruleset";
    /**
    * Generates CDKTF code for importing a MagicFirewallRuleset resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MagicFirewallRuleset to import
    * @param importFromId The id of the existing MagicFirewallRuleset that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MagicFirewallRuleset to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/magic_firewall_ruleset cloudflare_magic_firewall_ruleset} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MagicFirewallRulesetConfig
    */
    constructor(scope: Construct, id: string, config: MagicFirewallRulesetConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _rules?;
    get rules(): {
        [key: string]: string;
    }[] | cdktf.IResolvable;
    set rules(value: {
        [key: string]: string;
    }[] | cdktf.IResolvable);
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | {
        [key: string]: string;
    }[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
