/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WaitingRoomConfig extends cdktf.TerraformMetaArguments {
    /**
    * A cookie suffix to be appended to the Cloudflare waiting room cookie name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#cookie_suffix WaitingRoom#cookie_suffix}
    */
    readonly cookieSuffix?: string;
    /**
    * This is a templated html file that will be rendered at the edge.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#custom_page_html WaitingRoom#custom_page_html}
    */
    readonly customPageHtml?: string;
    /**
    * The language to use for the default waiting room page. Available values: `de-DE`, `es-ES`, `en-US`, `fr-FR`, `id-ID`, `it-IT`, `ja-JP`, `ko-KR`, `nl-NL`, `pl-PL`, `pt-BR`, `tr-TR`, `zh-CN`, `zh-TW`, `ru-RU`, `fa-IR`, `bg-BG`, `hr-HR`, `cs-CZ`, `da-DK`, `fi-FI`, `lt-LT`, `ms-MY`, `nb-NO`, `ro-RO`, `el-GR`, `he-IL`, `hi-IN`, `hu-HU`, `sr-BA`, `sk-SK`, `sl-SI`, `sv-SE`, `tl-PH`, `th-TH`, `uk-UA`, `vi-VN`. Defaults to `en-US`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#default_template_language WaitingRoom#default_template_language}
    */
    readonly defaultTemplateLanguage?: string;
    /**
    * A description to add more details about the waiting room.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#description WaitingRoom#description}
    */
    readonly description?: string;
    /**
    * Disables automatic renewal of session cookies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#disable_session_renewal WaitingRoom#disable_session_renewal}
    */
    readonly disableSessionRenewal?: boolean | cdktf.IResolvable;
    /**
    * The list of enabled origin commands for the waiting room. Available values: `revoke`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#enabled_origin_commands WaitingRoom#enabled_origin_commands}
    */
    readonly enabledOriginCommands?: string[];
    /**
    * Host name for which the waiting room will be applied (no wildcards).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#host WaitingRoom#host}
    */
    readonly host: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#id WaitingRoom#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * If true, requests to the waiting room with the header `Accept: application/json` will receive a JSON response object.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#json_response_enabled WaitingRoom#json_response_enabled}
    */
    readonly jsonResponseEnabled?: boolean | cdktf.IResolvable;
    /**
    * A unique name to identify the waiting room. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#name WaitingRoom#name}
    */
    readonly name: string;
    /**
    * The number of new users that will be let into the route every minute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#new_users_per_minute WaitingRoom#new_users_per_minute}
    */
    readonly newUsersPerMinute: number;
    /**
    * The path within the host to enable the waiting room on. Defaults to `/`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#path WaitingRoom#path}
    */
    readonly path?: string;
    /**
    * If queue_all is true, then all traffic will be sent to the waiting room.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#queue_all WaitingRoom#queue_all}
    */
    readonly queueAll?: boolean | cdktf.IResolvable;
    /**
    * The queueing method used by the waiting room. Available values: `fifo`, `random`, `passthrough`, `reject`. Defaults to `fifo`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#queueing_method WaitingRoom#queueing_method}
    */
    readonly queueingMethod?: string;
    /**
    * HTTP status code returned to a user while in the queue. Defaults to `200`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#queueing_status_code WaitingRoom#queueing_status_code}
    */
    readonly queueingStatusCode?: number;
    /**
    * Lifetime of a cookie (in minutes) set by Cloudflare for users who get access to the origin. Defaults to `5`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#session_duration WaitingRoom#session_duration}
    */
    readonly sessionDuration?: number;
    /**
    * Suspends the waiting room.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#suspended WaitingRoom#suspended}
    */
    readonly suspended?: boolean | cdktf.IResolvable;
    /**
    * The total number of active user sessions on the route at a point in time.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#total_active_users WaitingRoom#total_active_users}
    */
    readonly totalActiveUsers: number;
    /**
    * The zone identifier to target for the resource. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#zone_id WaitingRoom#zone_id}
    */
    readonly zoneId: string;
    /**
    * additional_routes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#additional_routes WaitingRoom#additional_routes}
    */
    readonly additionalRoutes?: WaitingRoomAdditionalRoutes[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#timeouts WaitingRoom#timeouts}
    */
    readonly timeouts?: WaitingRoomTimeouts;
}
export interface WaitingRoomAdditionalRoutes {
    /**
    * The additional host name for which the waiting room to be applied on (no wildcards).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#host WaitingRoom#host}
    */
    readonly host: string;
    /**
    * The path within the additional host to enable the waiting room on. Defaults to `/`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#path WaitingRoom#path}
    */
    readonly path?: string;
}
export declare function waitingRoomAdditionalRoutesToTerraform(struct?: WaitingRoomAdditionalRoutes | cdktf.IResolvable): any;
export declare function waitingRoomAdditionalRoutesToHclTerraform(struct?: WaitingRoomAdditionalRoutes | cdktf.IResolvable): any;
export declare class WaitingRoomAdditionalRoutesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WaitingRoomAdditionalRoutes | cdktf.IResolvable | undefined;
    set internalValue(value: WaitingRoomAdditionalRoutes | cdktf.IResolvable | undefined);
    private _host?;
    get host(): string;
    set host(value: string);
    get hostInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
}
export declare class WaitingRoomAdditionalRoutesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WaitingRoomAdditionalRoutes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WaitingRoomAdditionalRoutesOutputReference;
}
export interface WaitingRoomTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#create WaitingRoom#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#update WaitingRoom#update}
    */
    readonly update?: string;
}
export declare function waitingRoomTimeoutsToTerraform(struct?: WaitingRoomTimeouts | cdktf.IResolvable): any;
export declare function waitingRoomTimeoutsToHclTerraform(struct?: WaitingRoomTimeouts | cdktf.IResolvable): any;
export declare class WaitingRoomTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WaitingRoomTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: WaitingRoomTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room cloudflare_waiting_room}
*/
export declare class WaitingRoom extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_waiting_room";
    /**
    * Generates CDKTF code for importing a WaitingRoom resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WaitingRoom to import
    * @param importFromId The id of the existing WaitingRoom that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WaitingRoom to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/waiting_room cloudflare_waiting_room} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WaitingRoomConfig
    */
    constructor(scope: Construct, id: string, config: WaitingRoomConfig);
    private _cookieSuffix?;
    get cookieSuffix(): string;
    set cookieSuffix(value: string);
    resetCookieSuffix(): void;
    get cookieSuffixInput(): string | undefined;
    private _customPageHtml?;
    get customPageHtml(): string;
    set customPageHtml(value: string);
    resetCustomPageHtml(): void;
    get customPageHtmlInput(): string | undefined;
    private _defaultTemplateLanguage?;
    get defaultTemplateLanguage(): string;
    set defaultTemplateLanguage(value: string);
    resetDefaultTemplateLanguage(): void;
    get defaultTemplateLanguageInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _disableSessionRenewal?;
    get disableSessionRenewal(): boolean | cdktf.IResolvable;
    set disableSessionRenewal(value: boolean | cdktf.IResolvable);
    resetDisableSessionRenewal(): void;
    get disableSessionRenewalInput(): boolean | cdktf.IResolvable | undefined;
    private _enabledOriginCommands?;
    get enabledOriginCommands(): string[];
    set enabledOriginCommands(value: string[]);
    resetEnabledOriginCommands(): void;
    get enabledOriginCommandsInput(): string[] | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    get hostInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _jsonResponseEnabled?;
    get jsonResponseEnabled(): boolean | cdktf.IResolvable;
    set jsonResponseEnabled(value: boolean | cdktf.IResolvable);
    resetJsonResponseEnabled(): void;
    get jsonResponseEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _newUsersPerMinute?;
    get newUsersPerMinute(): number;
    set newUsersPerMinute(value: number);
    get newUsersPerMinuteInput(): number | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _queueAll?;
    get queueAll(): boolean | cdktf.IResolvable;
    set queueAll(value: boolean | cdktf.IResolvable);
    resetQueueAll(): void;
    get queueAllInput(): boolean | cdktf.IResolvable | undefined;
    private _queueingMethod?;
    get queueingMethod(): string;
    set queueingMethod(value: string);
    resetQueueingMethod(): void;
    get queueingMethodInput(): string | undefined;
    private _queueingStatusCode?;
    get queueingStatusCode(): number;
    set queueingStatusCode(value: number);
    resetQueueingStatusCode(): void;
    get queueingStatusCodeInput(): number | undefined;
    private _sessionDuration?;
    get sessionDuration(): number;
    set sessionDuration(value: number);
    resetSessionDuration(): void;
    get sessionDurationInput(): number | undefined;
    private _suspended?;
    get suspended(): boolean | cdktf.IResolvable;
    set suspended(value: boolean | cdktf.IResolvable);
    resetSuspended(): void;
    get suspendedInput(): boolean | cdktf.IResolvable | undefined;
    private _totalActiveUsers?;
    get totalActiveUsers(): number;
    set totalActiveUsers(value: number);
    get totalActiveUsersInput(): number | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    private _additionalRoutes;
    get additionalRoutes(): WaitingRoomAdditionalRoutesList;
    putAdditionalRoutes(value: WaitingRoomAdditionalRoutes[] | cdktf.IResolvable): void;
    resetAdditionalRoutes(): void;
    get additionalRoutesInput(): cdktf.IResolvable | WaitingRoomAdditionalRoutes[] | undefined;
    private _timeouts;
    get timeouts(): WaitingRoomTimeoutsOutputReference;
    putTimeouts(value: WaitingRoomTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | WaitingRoomTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
