/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WebAnalyticsSiteConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#account_id WebAnalyticsSite#account_id}
    */
    readonly accountId: string;
    /**
    * Whether Cloudflare will automatically inject the JavaScript snippet for orange-clouded sites. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#auto_install WebAnalyticsSite#auto_install}
    */
    readonly autoInstall: boolean | cdktf.IResolvable;
    /**
    * The hostname to use for gray-clouded sites. Must provide only one of `zone_tag`. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#host WebAnalyticsSite#host}
    */
    readonly host?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#id WebAnalyticsSite#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The zone identifier for orange-clouded sites. Must provide only one of `host`. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#zone_tag WebAnalyticsSite#zone_tag}
    */
    readonly zoneTag?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#timeouts WebAnalyticsSite#timeouts}
    */
    readonly timeouts?: WebAnalyticsSiteTimeouts;
}
export interface WebAnalyticsSiteTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#create WebAnalyticsSite#create}
    */
    readonly create?: string;
}
export declare function webAnalyticsSiteTimeoutsToTerraform(struct?: WebAnalyticsSiteTimeouts | cdktf.IResolvable): any;
export declare function webAnalyticsSiteTimeoutsToHclTerraform(struct?: WebAnalyticsSiteTimeouts | cdktf.IResolvable): any;
export declare class WebAnalyticsSiteTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WebAnalyticsSiteTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: WebAnalyticsSiteTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site cloudflare_web_analytics_site}
*/
export declare class WebAnalyticsSite extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_web_analytics_site";
    /**
    * Generates CDKTF code for importing a WebAnalyticsSite resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WebAnalyticsSite to import
    * @param importFromId The id of the existing WebAnalyticsSite that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WebAnalyticsSite to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/web_analytics_site cloudflare_web_analytics_site} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WebAnalyticsSiteConfig
    */
    constructor(scope: Construct, id: string, config: WebAnalyticsSiteConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _autoInstall?;
    get autoInstall(): boolean | cdktf.IResolvable;
    set autoInstall(value: boolean | cdktf.IResolvable);
    get autoInstallInput(): boolean | cdktf.IResolvable | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    resetHost(): void;
    get hostInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get rulesetId(): string;
    get siteTag(): string;
    get siteToken(): string;
    get snippet(): string;
    private _zoneTag?;
    get zoneTag(): string;
    set zoneTag(value: string);
    resetZoneTag(): void;
    get zoneTagInput(): string | undefined;
    private _timeouts;
    get timeouts(): WebAnalyticsSiteTimeoutsOutputReference;
    putTimeouts(value: WebAnalyticsSiteTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | WebAnalyticsSiteTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
