/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WorkersScriptConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#account_id WorkersScript#account_id}
    */
    readonly accountId: string;
    /**
    * The date to use for the compatibility flag.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#compatibility_date WorkersScript#compatibility_date}
    */
    readonly compatibilityDate?: string;
    /**
    * Compatibility flags used for Worker Scripts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#compatibility_flags WorkersScript#compatibility_flags}
    */
    readonly compatibilityFlags?: string[];
    /**
    * The script content.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#content WorkersScript#content}
    */
    readonly content: string;
    /**
    * Name of the Workers for Platforms dispatch namespace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#dispatch_namespace WorkersScript#dispatch_namespace}
    */
    readonly dispatchNamespace?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#id WorkersScript#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Enabling allows Worker events to be sent to a defined Logpush destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#logpush WorkersScript#logpush}
    */
    readonly logpush?: boolean | cdktf.IResolvable;
    /**
    * Whether to upload Worker as a module.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#module WorkersScript#module}
    */
    readonly module?: boolean | cdktf.IResolvable;
    /**
    * The name for the script. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#tags WorkersScript#tags}
    */
    readonly tags?: string[];
    /**
    * analytics_engine_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#analytics_engine_binding WorkersScript#analytics_engine_binding}
    */
    readonly analyticsEngineBinding?: WorkersScriptAnalyticsEngineBinding[] | cdktf.IResolvable;
    /**
    * d1_database_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#d1_database_binding WorkersScript#d1_database_binding}
    */
    readonly d1DatabaseBinding?: WorkersScriptD1DatabaseBinding[] | cdktf.IResolvable;
    /**
    * hyperdrive_config_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#hyperdrive_config_binding WorkersScript#hyperdrive_config_binding}
    */
    readonly hyperdriveConfigBinding?: WorkersScriptHyperdriveConfigBinding[] | cdktf.IResolvable;
    /**
    * kv_namespace_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#kv_namespace_binding WorkersScript#kv_namespace_binding}
    */
    readonly kvNamespaceBinding?: WorkersScriptKvNamespaceBinding[] | cdktf.IResolvable;
    /**
    * placement block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#placement WorkersScript#placement}
    */
    readonly placement?: WorkersScriptPlacement[] | cdktf.IResolvable;
    /**
    * plain_text_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#plain_text_binding WorkersScript#plain_text_binding}
    */
    readonly plainTextBinding?: WorkersScriptPlainTextBinding[] | cdktf.IResolvable;
    /**
    * queue_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#queue_binding WorkersScript#queue_binding}
    */
    readonly queueBinding?: WorkersScriptQueueBinding[] | cdktf.IResolvable;
    /**
    * r2_bucket_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#r2_bucket_binding WorkersScript#r2_bucket_binding}
    */
    readonly r2BucketBinding?: WorkersScriptR2BucketBinding[] | cdktf.IResolvable;
    /**
    * secret_text_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#secret_text_binding WorkersScript#secret_text_binding}
    */
    readonly secretTextBinding?: WorkersScriptSecretTextBinding[] | cdktf.IResolvable;
    /**
    * service_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#service_binding WorkersScript#service_binding}
    */
    readonly serviceBinding?: WorkersScriptServiceBinding[] | cdktf.IResolvable;
    /**
    * webassembly_binding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#webassembly_binding WorkersScript#webassembly_binding}
    */
    readonly webassemblyBinding?: WorkersScriptWebassemblyBinding[] | cdktf.IResolvable;
}
export interface WorkersScriptAnalyticsEngineBinding {
    /**
    * The name of the Analytics Engine dataset to write to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#dataset WorkersScript#dataset}
    */
    readonly dataset: string;
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
}
export declare function workersScriptAnalyticsEngineBindingToTerraform(struct?: WorkersScriptAnalyticsEngineBinding | cdktf.IResolvable): any;
export declare function workersScriptAnalyticsEngineBindingToHclTerraform(struct?: WorkersScriptAnalyticsEngineBinding | cdktf.IResolvable): any;
export declare class WorkersScriptAnalyticsEngineBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptAnalyticsEngineBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptAnalyticsEngineBinding | cdktf.IResolvable | undefined);
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    get datasetInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class WorkersScriptAnalyticsEngineBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptAnalyticsEngineBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptAnalyticsEngineBindingOutputReference;
}
export interface WorkersScriptD1DatabaseBinding {
    /**
    * Database ID of D1 database to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#database_id WorkersScript#database_id}
    */
    readonly databaseId: string;
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
}
export declare function workersScriptD1DatabaseBindingToTerraform(struct?: WorkersScriptD1DatabaseBinding | cdktf.IResolvable): any;
export declare function workersScriptD1DatabaseBindingToHclTerraform(struct?: WorkersScriptD1DatabaseBinding | cdktf.IResolvable): any;
export declare class WorkersScriptD1DatabaseBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptD1DatabaseBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptD1DatabaseBinding | cdktf.IResolvable | undefined);
    private _databaseId?;
    get databaseId(): string;
    set databaseId(value: string);
    get databaseIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class WorkersScriptD1DatabaseBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptD1DatabaseBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptD1DatabaseBindingOutputReference;
}
export interface WorkersScriptHyperdriveConfigBinding {
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#binding WorkersScript#binding}
    */
    readonly binding: string;
    /**
    * The ID of the Hyperdrive config to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#id WorkersScript#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function workersScriptHyperdriveConfigBindingToTerraform(struct?: WorkersScriptHyperdriveConfigBinding | cdktf.IResolvable): any;
export declare function workersScriptHyperdriveConfigBindingToHclTerraform(struct?: WorkersScriptHyperdriveConfigBinding | cdktf.IResolvable): any;
export declare class WorkersScriptHyperdriveConfigBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptHyperdriveConfigBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptHyperdriveConfigBinding | cdktf.IResolvable | undefined);
    private _binding?;
    get binding(): string;
    set binding(value: string);
    get bindingInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export declare class WorkersScriptHyperdriveConfigBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptHyperdriveConfigBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptHyperdriveConfigBindingOutputReference;
}
export interface WorkersScriptKvNamespaceBinding {
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
    /**
    * ID of the KV namespace you want to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#namespace_id WorkersScript#namespace_id}
    */
    readonly namespaceId: string;
}
export declare function workersScriptKvNamespaceBindingToTerraform(struct?: WorkersScriptKvNamespaceBinding | cdktf.IResolvable): any;
export declare function workersScriptKvNamespaceBindingToHclTerraform(struct?: WorkersScriptKvNamespaceBinding | cdktf.IResolvable): any;
export declare class WorkersScriptKvNamespaceBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptKvNamespaceBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptKvNamespaceBinding | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespaceId?;
    get namespaceId(): string;
    set namespaceId(value: string);
    get namespaceIdInput(): string | undefined;
}
export declare class WorkersScriptKvNamespaceBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptKvNamespaceBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptKvNamespaceBindingOutputReference;
}
export interface WorkersScriptPlacement {
    /**
    * The placement mode for the Worker. Available values: `smart`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#mode WorkersScript#mode}
    */
    readonly mode: string;
}
export declare function workersScriptPlacementToTerraform(struct?: WorkersScriptPlacement | cdktf.IResolvable): any;
export declare function workersScriptPlacementToHclTerraform(struct?: WorkersScriptPlacement | cdktf.IResolvable): any;
export declare class WorkersScriptPlacementOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptPlacement | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptPlacement | cdktf.IResolvable | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
}
export declare class WorkersScriptPlacementList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptPlacement[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptPlacementOutputReference;
}
export interface WorkersScriptPlainTextBinding {
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
    /**
    * The plain text you want to store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#text WorkersScript#text}
    */
    readonly text: string;
}
export declare function workersScriptPlainTextBindingToTerraform(struct?: WorkersScriptPlainTextBinding | cdktf.IResolvable): any;
export declare function workersScriptPlainTextBindingToHclTerraform(struct?: WorkersScriptPlainTextBinding | cdktf.IResolvable): any;
export declare class WorkersScriptPlainTextBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptPlainTextBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptPlainTextBinding | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _text?;
    get text(): string;
    set text(value: string);
    get textInput(): string | undefined;
}
export declare class WorkersScriptPlainTextBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptPlainTextBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptPlainTextBindingOutputReference;
}
export interface WorkersScriptQueueBinding {
    /**
    * The name of the global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#binding WorkersScript#binding}
    */
    readonly binding: string;
    /**
    * Name of the queue you want to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#queue WorkersScript#queue}
    */
    readonly queue: string;
}
export declare function workersScriptQueueBindingToTerraform(struct?: WorkersScriptQueueBinding | cdktf.IResolvable): any;
export declare function workersScriptQueueBindingToHclTerraform(struct?: WorkersScriptQueueBinding | cdktf.IResolvable): any;
export declare class WorkersScriptQueueBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptQueueBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptQueueBinding | cdktf.IResolvable | undefined);
    private _binding?;
    get binding(): string;
    set binding(value: string);
    get bindingInput(): string | undefined;
    private _queue?;
    get queue(): string;
    set queue(value: string);
    get queueInput(): string | undefined;
}
export declare class WorkersScriptQueueBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptQueueBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptQueueBindingOutputReference;
}
export interface WorkersScriptR2BucketBinding {
    /**
    * The name of the Bucket to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#bucket_name WorkersScript#bucket_name}
    */
    readonly bucketName: string;
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
}
export declare function workersScriptR2BucketBindingToTerraform(struct?: WorkersScriptR2BucketBinding | cdktf.IResolvable): any;
export declare function workersScriptR2BucketBindingToHclTerraform(struct?: WorkersScriptR2BucketBinding | cdktf.IResolvable): any;
export declare class WorkersScriptR2BucketBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptR2BucketBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptR2BucketBinding | cdktf.IResolvable | undefined);
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class WorkersScriptR2BucketBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptR2BucketBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptR2BucketBindingOutputReference;
}
export interface WorkersScriptSecretTextBinding {
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
    /**
    * The secret text you want to store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#text WorkersScript#text}
    */
    readonly text: string;
}
export declare function workersScriptSecretTextBindingToTerraform(struct?: WorkersScriptSecretTextBinding | cdktf.IResolvable): any;
export declare function workersScriptSecretTextBindingToHclTerraform(struct?: WorkersScriptSecretTextBinding | cdktf.IResolvable): any;
export declare class WorkersScriptSecretTextBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptSecretTextBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptSecretTextBinding | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _text?;
    get text(): string;
    set text(value: string);
    get textInput(): string | undefined;
}
export declare class WorkersScriptSecretTextBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptSecretTextBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptSecretTextBindingOutputReference;
}
export interface WorkersScriptServiceBinding {
    /**
    * The name of the Worker environment to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#environment WorkersScript#environment}
    */
    readonly environment?: string;
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
    /**
    * The name of the Worker to bind to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#service WorkersScript#service}
    */
    readonly service: string;
}
export declare function workersScriptServiceBindingToTerraform(struct?: WorkersScriptServiceBinding | cdktf.IResolvable): any;
export declare function workersScriptServiceBindingToHclTerraform(struct?: WorkersScriptServiceBinding | cdktf.IResolvable): any;
export declare class WorkersScriptServiceBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptServiceBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptServiceBinding | cdktf.IResolvable | undefined);
    private _environment?;
    get environment(): string;
    set environment(value: string);
    resetEnvironment(): void;
    get environmentInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
}
export declare class WorkersScriptServiceBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptServiceBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptServiceBindingOutputReference;
}
export interface WorkersScriptWebassemblyBinding {
    /**
    * The base64 encoded wasm module you want to store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#module WorkersScript#module}
    */
    readonly module: string;
    /**
    * The global variable for the binding in your Worker code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#name WorkersScript#name}
    */
    readonly name: string;
}
export declare function workersScriptWebassemblyBindingToTerraform(struct?: WorkersScriptWebassemblyBinding | cdktf.IResolvable): any;
export declare function workersScriptWebassemblyBindingToHclTerraform(struct?: WorkersScriptWebassemblyBinding | cdktf.IResolvable): any;
export declare class WorkersScriptWebassemblyBindingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): WorkersScriptWebassemblyBinding | cdktf.IResolvable | undefined;
    set internalValue(value: WorkersScriptWebassemblyBinding | cdktf.IResolvable | undefined);
    private _module?;
    get module(): string;
    set module(value: string);
    get moduleInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class WorkersScriptWebassemblyBindingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: WorkersScriptWebassemblyBinding[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): WorkersScriptWebassemblyBindingOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script cloudflare_workers_script}
*/
export declare class WorkersScript extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_workers_script";
    /**
    * Generates CDKTF code for importing a WorkersScript resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WorkersScript to import
    * @param importFromId The id of the existing WorkersScript that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WorkersScript to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/workers_script cloudflare_workers_script} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WorkersScriptConfig
    */
    constructor(scope: Construct, id: string, config: WorkersScriptConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _compatibilityDate?;
    get compatibilityDate(): string;
    set compatibilityDate(value: string);
    resetCompatibilityDate(): void;
    get compatibilityDateInput(): string | undefined;
    private _compatibilityFlags?;
    get compatibilityFlags(): string[];
    set compatibilityFlags(value: string[]);
    resetCompatibilityFlags(): void;
    get compatibilityFlagsInput(): string[] | undefined;
    private _content?;
    get content(): string;
    set content(value: string);
    get contentInput(): string | undefined;
    private _dispatchNamespace?;
    get dispatchNamespace(): string;
    set dispatchNamespace(value: string);
    resetDispatchNamespace(): void;
    get dispatchNamespaceInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _logpush?;
    get logpush(): boolean | cdktf.IResolvable;
    set logpush(value: boolean | cdktf.IResolvable);
    resetLogpush(): void;
    get logpushInput(): boolean | cdktf.IResolvable | undefined;
    private _module?;
    get module(): boolean | cdktf.IResolvable;
    set module(value: boolean | cdktf.IResolvable);
    resetModule(): void;
    get moduleInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _analyticsEngineBinding;
    get analyticsEngineBinding(): WorkersScriptAnalyticsEngineBindingList;
    putAnalyticsEngineBinding(value: WorkersScriptAnalyticsEngineBinding[] | cdktf.IResolvable): void;
    resetAnalyticsEngineBinding(): void;
    get analyticsEngineBindingInput(): cdktf.IResolvable | WorkersScriptAnalyticsEngineBinding[] | undefined;
    private _d1DatabaseBinding;
    get d1DatabaseBinding(): WorkersScriptD1DatabaseBindingList;
    putD1DatabaseBinding(value: WorkersScriptD1DatabaseBinding[] | cdktf.IResolvable): void;
    resetD1DatabaseBinding(): void;
    get d1DatabaseBindingInput(): cdktf.IResolvable | WorkersScriptD1DatabaseBinding[] | undefined;
    private _hyperdriveConfigBinding;
    get hyperdriveConfigBinding(): WorkersScriptHyperdriveConfigBindingList;
    putHyperdriveConfigBinding(value: WorkersScriptHyperdriveConfigBinding[] | cdktf.IResolvable): void;
    resetHyperdriveConfigBinding(): void;
    get hyperdriveConfigBindingInput(): cdktf.IResolvable | WorkersScriptHyperdriveConfigBinding[] | undefined;
    private _kvNamespaceBinding;
    get kvNamespaceBinding(): WorkersScriptKvNamespaceBindingList;
    putKvNamespaceBinding(value: WorkersScriptKvNamespaceBinding[] | cdktf.IResolvable): void;
    resetKvNamespaceBinding(): void;
    get kvNamespaceBindingInput(): cdktf.IResolvable | WorkersScriptKvNamespaceBinding[] | undefined;
    private _placement;
    get placement(): WorkersScriptPlacementList;
    putPlacement(value: WorkersScriptPlacement[] | cdktf.IResolvable): void;
    resetPlacement(): void;
    get placementInput(): cdktf.IResolvable | WorkersScriptPlacement[] | undefined;
    private _plainTextBinding;
    get plainTextBinding(): WorkersScriptPlainTextBindingList;
    putPlainTextBinding(value: WorkersScriptPlainTextBinding[] | cdktf.IResolvable): void;
    resetPlainTextBinding(): void;
    get plainTextBindingInput(): cdktf.IResolvable | WorkersScriptPlainTextBinding[] | undefined;
    private _queueBinding;
    get queueBinding(): WorkersScriptQueueBindingList;
    putQueueBinding(value: WorkersScriptQueueBinding[] | cdktf.IResolvable): void;
    resetQueueBinding(): void;
    get queueBindingInput(): cdktf.IResolvable | WorkersScriptQueueBinding[] | undefined;
    private _r2BucketBinding;
    get r2BucketBinding(): WorkersScriptR2BucketBindingList;
    putR2BucketBinding(value: WorkersScriptR2BucketBinding[] | cdktf.IResolvable): void;
    resetR2BucketBinding(): void;
    get r2BucketBindingInput(): cdktf.IResolvable | WorkersScriptR2BucketBinding[] | undefined;
    private _secretTextBinding;
    get secretTextBinding(): WorkersScriptSecretTextBindingList;
    putSecretTextBinding(value: WorkersScriptSecretTextBinding[] | cdktf.IResolvable): void;
    resetSecretTextBinding(): void;
    get secretTextBindingInput(): cdktf.IResolvable | WorkersScriptSecretTextBinding[] | undefined;
    private _serviceBinding;
    get serviceBinding(): WorkersScriptServiceBindingList;
    putServiceBinding(value: WorkersScriptServiceBinding[] | cdktf.IResolvable): void;
    resetServiceBinding(): void;
    get serviceBindingInput(): cdktf.IResolvable | WorkersScriptServiceBinding[] | undefined;
    private _webassemblyBinding;
    get webassemblyBinding(): WorkersScriptWebassemblyBindingList;
    putWebassemblyBinding(value: WorkersScriptWebassemblyBinding[] | cdktf.IResolvable): void;
    resetWebassemblyBinding(): void;
    get webassemblyBindingInput(): cdktf.IResolvable | WorkersScriptWebassemblyBinding[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
