/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustAccessApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. Conflicts with `zone_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#account_id ZeroTrustAccessApplication#account_id}
    */
    readonly accountId?: string;
    /**
    * When set to true, users can authenticate to this application using their WARP session. When set to false this application will always require direct IdP authentication. This setting always overrides the organization setting for WARP authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allow_authenticate_via_warp ZeroTrustAccessApplication#allow_authenticate_via_warp}
    */
    readonly allowAuthenticateViaWarp?: boolean | cdktf.IResolvable;
    /**
    * The identity providers selected for the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allowed_idps ZeroTrustAccessApplication#allowed_idps}
    */
    readonly allowedIdps?: string[];
    /**
    * The logo URL of the app launcher.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#app_launcher_logo_url ZeroTrustAccessApplication#app_launcher_logo_url}
    */
    readonly appLauncherLogoUrl?: string;
    /**
    * Option to show/hide applications in App Launcher. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#app_launcher_visible ZeroTrustAccessApplication#app_launcher_visible}
    */
    readonly appLauncherVisible?: boolean | cdktf.IResolvable;
    /**
    * Option to skip identity provider selection if only one is configured in `allowed_idps`. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#auto_redirect_to_identity ZeroTrustAccessApplication#auto_redirect_to_identity}
    */
    readonly autoRedirectToIdentity?: boolean | cdktf.IResolvable;
    /**
    * The background color of the app launcher.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#bg_color ZeroTrustAccessApplication#bg_color}
    */
    readonly bgColor?: string;
    /**
    * Option that returns a custom error message when a user is denied access to the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#custom_deny_message ZeroTrustAccessApplication#custom_deny_message}
    */
    readonly customDenyMessage?: string;
    /**
    * Option that redirects to a custom URL when a user is denied access to the application via identity based rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#custom_deny_url ZeroTrustAccessApplication#custom_deny_url}
    */
    readonly customDenyUrl?: string;
    /**
    * Option that redirects to a custom URL when a user is denied access to the application via non identity rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#custom_non_identity_deny_url ZeroTrustAccessApplication#custom_non_identity_deny_url}
    */
    readonly customNonIdentityDenyUrl?: string;
    /**
    * The custom pages selected for the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#custom_pages ZeroTrustAccessApplication#custom_pages}
    */
    readonly customPages?: string[];
    /**
    * The primary hostname and path that Access will secure. If the app is visible in the App Launcher dashboard, this is the domain that will be displayed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#domain ZeroTrustAccessApplication#domain}
    */
    readonly domain?: string;
    /**
    * Option to provide increased security against compromised authorization tokens and CSRF attacks by requiring an additional "binding" cookie on requests. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#enable_binding_cookie ZeroTrustAccessApplication#enable_binding_cookie}
    */
    readonly enableBindingCookie?: boolean | cdktf.IResolvable;
    /**
    * The background color of the header bar in the app launcher.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#header_bg_color ZeroTrustAccessApplication#header_bg_color}
    */
    readonly headerBgColor?: string;
    /**
    * Option to add the `HttpOnly` cookie flag to access tokens.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#http_only_cookie_attribute ZeroTrustAccessApplication#http_only_cookie_attribute}
    */
    readonly httpOnlyCookieAttribute?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#id ZeroTrustAccessApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Image URL for the logo shown in the app launcher dashboard.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#logo_url ZeroTrustAccessApplication#logo_url}
    */
    readonly logoUrl?: string;
    /**
    * Friendly name of the Access Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name?: string;
    /**
    * Allows options preflight requests to bypass Access authentication and go directly to the origin. Cannot turn on if cors_headers is set. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#options_preflight_bypass ZeroTrustAccessApplication#options_preflight_bypass}
    */
    readonly optionsPreflightBypass?: boolean | cdktf.IResolvable;
    /**
    * The policies associated with the application, in ascending order of precedence. Warning: Do not use this field while you still have this application ID referenced as `application_id` in any `cloudflare_access_policy` resource, as it can result in an inconsistent state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#policies ZeroTrustAccessApplication#policies}
    */
    readonly policies?: string[];
    /**
    * Defines the same-site cookie setting for access tokens. Available values: `none`, `lax`, `strict`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#same_site_cookie_attribute ZeroTrustAccessApplication#same_site_cookie_attribute}
    */
    readonly sameSiteCookieAttribute?: string;
    /**
    * List of domains that access will secure. Only present for self_hosted, vnc, and ssh applications. Always includes the value set as `domain`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#self_hosted_domains ZeroTrustAccessApplication#self_hosted_domains}
    */
    readonly selfHostedDomains?: string[];
    /**
    * Option to return a 401 status code in service authentication rules on failed requests. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#service_auth_401_redirect ZeroTrustAccessApplication#service_auth_401_redirect}
    */
    readonly serviceAuth401Redirect?: boolean | cdktf.IResolvable;
    /**
    * How often a user will be forced to re-authorise. Must be in the format `48h` or `2h45m`. Defaults to `24h`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#session_duration ZeroTrustAccessApplication#session_duration}
    */
    readonly sessionDuration?: string;
    /**
    * Option to skip the App Launcher landing page. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#skip_app_launcher_login_page ZeroTrustAccessApplication#skip_app_launcher_login_page}
    */
    readonly skipAppLauncherLoginPage?: boolean | cdktf.IResolvable;
    /**
    * Option to skip the authorization interstitial when using the CLI. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#skip_interstitial ZeroTrustAccessApplication#skip_interstitial}
    */
    readonly skipInterstitial?: boolean | cdktf.IResolvable;
    /**
    * The itags associated with the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#tags ZeroTrustAccessApplication#tags}
    */
    readonly tags?: string[];
    /**
    * The application type. Available values: `app_launcher`, `bookmark`, `biso`, `dash_sso`, `saas`, `self_hosted`, `ssh`, `vnc`, `warp`, `infrastructure`. Defaults to `self_hosted`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#type ZeroTrustAccessApplication#type}
    */
    readonly type?: string;
    /**
    * The zone identifier to target for the resource. Conflicts with `account_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#zone_id ZeroTrustAccessApplication#zone_id}
    */
    readonly zoneId?: string;
    /**
    * cors_headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#cors_headers ZeroTrustAccessApplication#cors_headers}
    */
    readonly corsHeaders?: ZeroTrustAccessApplicationCorsHeaders[] | cdktf.IResolvable;
    /**
    * footer_links block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#footer_links ZeroTrustAccessApplication#footer_links}
    */
    readonly footerLinks?: ZeroTrustAccessApplicationFooterLinks[] | cdktf.IResolvable;
    /**
    * landing_page_design block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#landing_page_design ZeroTrustAccessApplication#landing_page_design}
    */
    readonly landingPageDesign?: ZeroTrustAccessApplicationLandingPageDesign;
    /**
    * saas_app block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#saas_app ZeroTrustAccessApplication#saas_app}
    */
    readonly saasApp?: ZeroTrustAccessApplicationSaasApp;
    /**
    * scim_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#scim_config ZeroTrustAccessApplication#scim_config}
    */
    readonly scimConfig?: ZeroTrustAccessApplicationScimConfig;
    /**
    * target_criteria block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#target_criteria ZeroTrustAccessApplication#target_criteria}
    */
    readonly targetCriteria?: ZeroTrustAccessApplicationTargetCriteria[] | cdktf.IResolvable;
}
export interface ZeroTrustAccessApplicationCorsHeaders {
    /**
    * Value to determine whether all HTTP headers are exposed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allow_all_headers ZeroTrustAccessApplication#allow_all_headers}
    */
    readonly allowAllHeaders?: boolean | cdktf.IResolvable;
    /**
    * Value to determine whether all methods are exposed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allow_all_methods ZeroTrustAccessApplication#allow_all_methods}
    */
    readonly allowAllMethods?: boolean | cdktf.IResolvable;
    /**
    * Value to determine whether all origins are permitted to make CORS requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allow_all_origins ZeroTrustAccessApplication#allow_all_origins}
    */
    readonly allowAllOrigins?: boolean | cdktf.IResolvable;
    /**
    * Value to determine if credentials (cookies, authorization headers, or TLS client certificates) are included with requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allow_credentials ZeroTrustAccessApplication#allow_credentials}
    */
    readonly allowCredentials?: boolean | cdktf.IResolvable;
    /**
    * List of HTTP headers to expose via CORS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allowed_headers ZeroTrustAccessApplication#allowed_headers}
    */
    readonly allowedHeaders?: string[];
    /**
    * List of methods to expose via CORS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allowed_methods ZeroTrustAccessApplication#allowed_methods}
    */
    readonly allowedMethods?: string[];
    /**
    * List of origins permitted to make CORS requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allowed_origins ZeroTrustAccessApplication#allowed_origins}
    */
    readonly allowedOrigins?: string[];
    /**
    * The maximum time a preflight request will be cached.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#max_age ZeroTrustAccessApplication#max_age}
    */
    readonly maxAge?: number;
}
export declare function zeroTrustAccessApplicationCorsHeadersToTerraform(struct?: ZeroTrustAccessApplicationCorsHeaders | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationCorsHeadersToHclTerraform(struct?: ZeroTrustAccessApplicationCorsHeaders | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationCorsHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationCorsHeaders | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationCorsHeaders | cdktf.IResolvable | undefined);
    private _allowAllHeaders?;
    get allowAllHeaders(): boolean | cdktf.IResolvable;
    set allowAllHeaders(value: boolean | cdktf.IResolvable);
    resetAllowAllHeaders(): void;
    get allowAllHeadersInput(): boolean | cdktf.IResolvable | undefined;
    private _allowAllMethods?;
    get allowAllMethods(): boolean | cdktf.IResolvable;
    set allowAllMethods(value: boolean | cdktf.IResolvable);
    resetAllowAllMethods(): void;
    get allowAllMethodsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowAllOrigins?;
    get allowAllOrigins(): boolean | cdktf.IResolvable;
    set allowAllOrigins(value: boolean | cdktf.IResolvable);
    resetAllowAllOrigins(): void;
    get allowAllOriginsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowCredentials?;
    get allowCredentials(): boolean | cdktf.IResolvable;
    set allowCredentials(value: boolean | cdktf.IResolvable);
    resetAllowCredentials(): void;
    get allowCredentialsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedHeaders?;
    get allowedHeaders(): string[];
    set allowedHeaders(value: string[]);
    resetAllowedHeaders(): void;
    get allowedHeadersInput(): string[] | undefined;
    private _allowedMethods?;
    get allowedMethods(): string[];
    set allowedMethods(value: string[]);
    resetAllowedMethods(): void;
    get allowedMethodsInput(): string[] | undefined;
    private _allowedOrigins?;
    get allowedOrigins(): string[];
    set allowedOrigins(value: string[]);
    resetAllowedOrigins(): void;
    get allowedOriginsInput(): string[] | undefined;
    private _maxAge?;
    get maxAge(): number;
    set maxAge(value: number);
    resetMaxAge(): void;
    get maxAgeInput(): number | undefined;
}
export declare class ZeroTrustAccessApplicationCorsHeadersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationCorsHeaders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationCorsHeadersOutputReference;
}
export interface ZeroTrustAccessApplicationFooterLinks {
    /**
    * The name of the footer link.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name?: string;
    /**
    * The URL of the footer link.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#url ZeroTrustAccessApplication#url}
    */
    readonly url?: string;
}
export declare function zeroTrustAccessApplicationFooterLinksToTerraform(struct?: ZeroTrustAccessApplicationFooterLinks | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationFooterLinksToHclTerraform(struct?: ZeroTrustAccessApplicationFooterLinks | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationFooterLinksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationFooterLinks | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationFooterLinks | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _url?;
    get url(): string;
    set url(value: string);
    resetUrl(): void;
    get urlInput(): string | undefined;
}
export declare class ZeroTrustAccessApplicationFooterLinksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationFooterLinks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationFooterLinksOutputReference;
}
export interface ZeroTrustAccessApplicationLandingPageDesign {
    /**
    * The button color of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#button_color ZeroTrustAccessApplication#button_color}
    */
    readonly buttonColor?: string;
    /**
    * The button text color of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#button_text_color ZeroTrustAccessApplication#button_text_color}
    */
    readonly buttonTextColor?: string;
    /**
    * The URL of the image to be displayed in the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#image_url ZeroTrustAccessApplication#image_url}
    */
    readonly imageUrl?: string;
    /**
    * The message of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#message ZeroTrustAccessApplication#message}
    */
    readonly message?: string;
    /**
    * The title of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#title ZeroTrustAccessApplication#title}
    */
    readonly title?: string;
}
export declare function zeroTrustAccessApplicationLandingPageDesignToTerraform(struct?: ZeroTrustAccessApplicationLandingPageDesignOutputReference | ZeroTrustAccessApplicationLandingPageDesign): any;
export declare function zeroTrustAccessApplicationLandingPageDesignToHclTerraform(struct?: ZeroTrustAccessApplicationLandingPageDesignOutputReference | ZeroTrustAccessApplicationLandingPageDesign): any;
export declare class ZeroTrustAccessApplicationLandingPageDesignOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationLandingPageDesign | undefined;
    set internalValue(value: ZeroTrustAccessApplicationLandingPageDesign | undefined);
    private _buttonColor?;
    get buttonColor(): string;
    set buttonColor(value: string);
    resetButtonColor(): void;
    get buttonColorInput(): string | undefined;
    private _buttonTextColor?;
    get buttonTextColor(): string;
    set buttonTextColor(value: string);
    resetButtonTextColor(): void;
    get buttonTextColorInput(): string | undefined;
    private _imageUrl?;
    get imageUrl(): string;
    set imageUrl(value: string);
    resetImageUrl(): void;
    get imageUrlInput(): string | undefined;
    private _message?;
    get message(): string;
    set message(value: string);
    resetMessage(): void;
    get messageInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface ZeroTrustAccessApplicationSaasAppCustomAttributeSource {
    /**
    * The name of the attribute as provided by the IDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name: string;
    /**
    * A mapping from IdP ID to claim name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name_by_idp ZeroTrustAccessApplication#name_by_idp}
    */
    readonly nameByIdp?: {
        [key: string]: string;
    };
}
export declare function zeroTrustAccessApplicationSaasAppCustomAttributeSourceToTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomAttributeSourceOutputReference | ZeroTrustAccessApplicationSaasAppCustomAttributeSource): any;
export declare function zeroTrustAccessApplicationSaasAppCustomAttributeSourceToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomAttributeSourceOutputReference | ZeroTrustAccessApplicationSaasAppCustomAttributeSource): any;
export declare class ZeroTrustAccessApplicationSaasAppCustomAttributeSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationSaasAppCustomAttributeSource | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasAppCustomAttributeSource | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nameByIdp?;
    get nameByIdp(): {
        [key: string]: string;
    };
    set nameByIdp(value: {
        [key: string]: string;
    });
    resetNameByIdp(): void;
    get nameByIdpInput(): {
        [key: string]: string;
    } | undefined;
}
export interface ZeroTrustAccessApplicationSaasAppCustomAttribute {
    /**
    * A friendly name for the attribute as provided to the SaaS app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#friendly_name ZeroTrustAccessApplication#friendly_name}
    */
    readonly friendlyName?: string;
    /**
    * The name of the attribute as provided to the SaaS app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name?: string;
    /**
    * A globally unique name for an identity or service provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name_format ZeroTrustAccessApplication#name_format}
    */
    readonly nameFormat?: string;
    /**
    * True if the attribute must be always present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#required ZeroTrustAccessApplication#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#source ZeroTrustAccessApplication#source}
    */
    readonly source: ZeroTrustAccessApplicationSaasAppCustomAttributeSource;
}
export declare function zeroTrustAccessApplicationSaasAppCustomAttributeToTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomAttribute | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationSaasAppCustomAttributeToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomAttribute | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationSaasAppCustomAttributeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationSaasAppCustomAttribute | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasAppCustomAttribute | cdktf.IResolvable | undefined);
    private _friendlyName?;
    get friendlyName(): string;
    set friendlyName(value: string);
    resetFriendlyName(): void;
    get friendlyNameInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _nameFormat?;
    get nameFormat(): string;
    set nameFormat(value: string);
    resetNameFormat(): void;
    get nameFormatInput(): string | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _source;
    get source(): ZeroTrustAccessApplicationSaasAppCustomAttributeSourceOutputReference;
    putSource(value: ZeroTrustAccessApplicationSaasAppCustomAttributeSource): void;
    get sourceInput(): ZeroTrustAccessApplicationSaasAppCustomAttributeSource | undefined;
}
export declare class ZeroTrustAccessApplicationSaasAppCustomAttributeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationSaasAppCustomAttribute[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationSaasAppCustomAttributeOutputReference;
}
export interface ZeroTrustAccessApplicationSaasAppCustomClaimSource {
    /**
    * The name of the attribute as provided by the IDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name: string;
    /**
    * A mapping from IdP ID to claim name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name_by_idp ZeroTrustAccessApplication#name_by_idp}
    */
    readonly nameByIdp?: {
        [key: string]: string;
    };
}
export declare function zeroTrustAccessApplicationSaasAppCustomClaimSourceToTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomClaimSourceOutputReference | ZeroTrustAccessApplicationSaasAppCustomClaimSource): any;
export declare function zeroTrustAccessApplicationSaasAppCustomClaimSourceToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomClaimSourceOutputReference | ZeroTrustAccessApplicationSaasAppCustomClaimSource): any;
export declare class ZeroTrustAccessApplicationSaasAppCustomClaimSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationSaasAppCustomClaimSource | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasAppCustomClaimSource | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nameByIdp?;
    get nameByIdp(): {
        [key: string]: string;
    };
    set nameByIdp(value: {
        [key: string]: string;
    });
    resetNameByIdp(): void;
    get nameByIdpInput(): {
        [key: string]: string;
    } | undefined;
}
export interface ZeroTrustAccessApplicationSaasAppCustomClaim {
    /**
    * The name of the attribute as provided to the SaaS app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name?: string;
    /**
    * True if the attribute must be always present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#required ZeroTrustAccessApplication#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * The scope of the claim.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#scope ZeroTrustAccessApplication#scope}
    */
    readonly scope?: string;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#source ZeroTrustAccessApplication#source}
    */
    readonly source: ZeroTrustAccessApplicationSaasAppCustomClaimSource;
}
export declare function zeroTrustAccessApplicationSaasAppCustomClaimToTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomClaim | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationSaasAppCustomClaimToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppCustomClaim | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationSaasAppCustomClaimOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationSaasAppCustomClaim | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasAppCustomClaim | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _source;
    get source(): ZeroTrustAccessApplicationSaasAppCustomClaimSourceOutputReference;
    putSource(value: ZeroTrustAccessApplicationSaasAppCustomClaimSource): void;
    get sourceInput(): ZeroTrustAccessApplicationSaasAppCustomClaimSource | undefined;
}
export declare class ZeroTrustAccessApplicationSaasAppCustomClaimList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationSaasAppCustomClaim[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationSaasAppCustomClaimOutputReference;
}
export interface ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions {
    /**
    * If true, the authorization endpoint will return an access token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#return_access_token_from_authorization_endpoint ZeroTrustAccessApplication#return_access_token_from_authorization_endpoint}
    */
    readonly returnAccessTokenFromAuthorizationEndpoint?: boolean | cdktf.IResolvable;
    /**
    * If true, the authorization endpoint will return an id token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#return_id_token_from_authorization_endpoint ZeroTrustAccessApplication#return_id_token_from_authorization_endpoint}
    */
    readonly returnIdTokenFromAuthorizationEndpoint?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustAccessApplicationSaasAppHybridAndImplicitOptionsToTerraform(struct?: ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptionsOutputReference | ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions): any;
export declare function zeroTrustAccessApplicationSaasAppHybridAndImplicitOptionsToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptionsOutputReference | ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions): any;
export declare class ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions | undefined);
    private _returnAccessTokenFromAuthorizationEndpoint?;
    get returnAccessTokenFromAuthorizationEndpoint(): boolean | cdktf.IResolvable;
    set returnAccessTokenFromAuthorizationEndpoint(value: boolean | cdktf.IResolvable);
    resetReturnAccessTokenFromAuthorizationEndpoint(): void;
    get returnAccessTokenFromAuthorizationEndpointInput(): boolean | cdktf.IResolvable | undefined;
    private _returnIdTokenFromAuthorizationEndpoint?;
    get returnIdTokenFromAuthorizationEndpoint(): boolean | cdktf.IResolvable;
    set returnIdTokenFromAuthorizationEndpoint(value: boolean | cdktf.IResolvable);
    resetReturnIdTokenFromAuthorizationEndpoint(): void;
    get returnIdTokenFromAuthorizationEndpointInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustAccessApplicationSaasAppRefreshTokenOptions {
    /**
    * How long a refresh token will be valid for after creation. Valid units are `m`, `h` and `d`. Must be longer than 1m.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#lifetime ZeroTrustAccessApplication#lifetime}
    */
    readonly lifetime?: string;
}
export declare function zeroTrustAccessApplicationSaasAppRefreshTokenOptionsToTerraform(struct?: ZeroTrustAccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationSaasAppRefreshTokenOptionsToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationSaasAppRefreshTokenOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable | undefined);
    private _lifetime?;
    get lifetime(): string;
    set lifetime(value: string);
    resetLifetime(): void;
    get lifetimeInput(): string | undefined;
}
export declare class ZeroTrustAccessApplicationSaasAppRefreshTokenOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationSaasAppRefreshTokenOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationSaasAppRefreshTokenOptionsOutputReference;
}
export interface ZeroTrustAccessApplicationSaasApp {
    /**
    * The lifetime of the Access Token after creation. Valid units are `m` and `h`. Must be greater than or equal to 1m and less than or equal to 24h.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#access_token_lifetime ZeroTrustAccessApplication#access_token_lifetime}
    */
    readonly accessTokenLifetime?: string;
    /**
    * Allow PKCE flow without a client secret.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#allow_pkce_without_client_secret ZeroTrustAccessApplication#allow_pkce_without_client_secret}
    */
    readonly allowPkceWithoutClientSecret?: boolean | cdktf.IResolvable;
    /**
    * The URL where this applications tile redirects users.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#app_launcher_url ZeroTrustAccessApplication#app_launcher_url}
    */
    readonly appLauncherUrl?: string;
    /**
    * **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#auth_type ZeroTrustAccessApplication#auth_type}
    */
    readonly authType?: string;
    /**
    * The service provider's endpoint that is responsible for receiving and parsing a SAML assertion.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#consumer_service_url ZeroTrustAccessApplication#consumer_service_url}
    */
    readonly consumerServiceUrl?: string;
    /**
    * The relay state used if not provided by the identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#default_relay_state ZeroTrustAccessApplication#default_relay_state}
    */
    readonly defaultRelayState?: string;
    /**
    * The OIDC flows supported by this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#grant_types ZeroTrustAccessApplication#grant_types}
    */
    readonly grantTypes?: string[];
    /**
    * A regex to filter Cloudflare groups returned in ID token and userinfo endpoint.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#group_filter_regex ZeroTrustAccessApplication#group_filter_regex}
    */
    readonly groupFilterRegex?: string;
    /**
    * The format of the name identifier sent to the SaaS application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name_id_format ZeroTrustAccessApplication#name_id_format}
    */
    readonly nameIdFormat?: string;
    /**
    * A [JSONata](https://jsonata.org/) expression that transforms an application's user identities into a NameID value for its SAML assertion. This expression should evaluate to a singular string. The output of this expression can override the `name_id_format` setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name_id_transform_jsonata ZeroTrustAccessApplication#name_id_transform_jsonata}
    */
    readonly nameIdTransformJsonata?: string;
    /**
    * The permitted URL's for Cloudflare to return Authorization codes and Access/ID tokens.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#redirect_uris ZeroTrustAccessApplication#redirect_uris}
    */
    readonly redirectUris?: string[];
    /**
    * A [JSONata](https://jsonata.org/) expression that transforms an application's user identities into attribute assertions in the SAML response. The expression can transform id, email, name, and groups values. It can also transform fields listed in the saml_attributes or oidc_fields of the identity provider used to authenticate. The output of this expression must be a JSON object.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#saml_attribute_transform_jsonata ZeroTrustAccessApplication#saml_attribute_transform_jsonata}
    */
    readonly samlAttributeTransformJsonata?: string;
    /**
    * Define the user information shared with access.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#scopes ZeroTrustAccessApplication#scopes}
    */
    readonly scopes?: string[];
    /**
    * A globally unique name for an identity or service provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#sp_entity_id ZeroTrustAccessApplication#sp_entity_id}
    */
    readonly spEntityId?: string;
    /**
    * custom_attribute block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#custom_attribute ZeroTrustAccessApplication#custom_attribute}
    */
    readonly customAttribute?: ZeroTrustAccessApplicationSaasAppCustomAttribute[] | cdktf.IResolvable;
    /**
    * custom_claim block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#custom_claim ZeroTrustAccessApplication#custom_claim}
    */
    readonly customClaim?: ZeroTrustAccessApplicationSaasAppCustomClaim[] | cdktf.IResolvable;
    /**
    * hybrid_and_implicit_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#hybrid_and_implicit_options ZeroTrustAccessApplication#hybrid_and_implicit_options}
    */
    readonly hybridAndImplicitOptions?: ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions;
    /**
    * refresh_token_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#refresh_token_options ZeroTrustAccessApplication#refresh_token_options}
    */
    readonly refreshTokenOptions?: ZeroTrustAccessApplicationSaasAppRefreshTokenOptions[] | cdktf.IResolvable;
}
export declare function zeroTrustAccessApplicationSaasAppToTerraform(struct?: ZeroTrustAccessApplicationSaasAppOutputReference | ZeroTrustAccessApplicationSaasApp): any;
export declare function zeroTrustAccessApplicationSaasAppToHclTerraform(struct?: ZeroTrustAccessApplicationSaasAppOutputReference | ZeroTrustAccessApplicationSaasApp): any;
export declare class ZeroTrustAccessApplicationSaasAppOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationSaasApp | undefined;
    set internalValue(value: ZeroTrustAccessApplicationSaasApp | undefined);
    private _accessTokenLifetime?;
    get accessTokenLifetime(): string;
    set accessTokenLifetime(value: string);
    resetAccessTokenLifetime(): void;
    get accessTokenLifetimeInput(): string | undefined;
    private _allowPkceWithoutClientSecret?;
    get allowPkceWithoutClientSecret(): boolean | cdktf.IResolvable;
    set allowPkceWithoutClientSecret(value: boolean | cdktf.IResolvable);
    resetAllowPkceWithoutClientSecret(): void;
    get allowPkceWithoutClientSecretInput(): boolean | cdktf.IResolvable | undefined;
    private _appLauncherUrl?;
    get appLauncherUrl(): string;
    set appLauncherUrl(value: string);
    resetAppLauncherUrl(): void;
    get appLauncherUrlInput(): string | undefined;
    private _authType?;
    get authType(): string;
    set authType(value: string);
    resetAuthType(): void;
    get authTypeInput(): string | undefined;
    get clientId(): string;
    get clientSecret(): string;
    private _consumerServiceUrl?;
    get consumerServiceUrl(): string;
    set consumerServiceUrl(value: string);
    resetConsumerServiceUrl(): void;
    get consumerServiceUrlInput(): string | undefined;
    private _defaultRelayState?;
    get defaultRelayState(): string;
    set defaultRelayState(value: string);
    resetDefaultRelayState(): void;
    get defaultRelayStateInput(): string | undefined;
    private _grantTypes?;
    get grantTypes(): string[];
    set grantTypes(value: string[]);
    resetGrantTypes(): void;
    get grantTypesInput(): string[] | undefined;
    private _groupFilterRegex?;
    get groupFilterRegex(): string;
    set groupFilterRegex(value: string);
    resetGroupFilterRegex(): void;
    get groupFilterRegexInput(): string | undefined;
    get idpEntityId(): string;
    private _nameIdFormat?;
    get nameIdFormat(): string;
    set nameIdFormat(value: string);
    resetNameIdFormat(): void;
    get nameIdFormatInput(): string | undefined;
    private _nameIdTransformJsonata?;
    get nameIdTransformJsonata(): string;
    set nameIdTransformJsonata(value: string);
    resetNameIdTransformJsonata(): void;
    get nameIdTransformJsonataInput(): string | undefined;
    get publicKey(): string;
    private _redirectUris?;
    get redirectUris(): string[];
    set redirectUris(value: string[]);
    resetRedirectUris(): void;
    get redirectUrisInput(): string[] | undefined;
    private _samlAttributeTransformJsonata?;
    get samlAttributeTransformJsonata(): string;
    set samlAttributeTransformJsonata(value: string);
    resetSamlAttributeTransformJsonata(): void;
    get samlAttributeTransformJsonataInput(): string | undefined;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    resetScopes(): void;
    get scopesInput(): string[] | undefined;
    private _spEntityId?;
    get spEntityId(): string;
    set spEntityId(value: string);
    resetSpEntityId(): void;
    get spEntityIdInput(): string | undefined;
    get ssoEndpoint(): string;
    private _customAttribute;
    get customAttribute(): ZeroTrustAccessApplicationSaasAppCustomAttributeList;
    putCustomAttribute(value: ZeroTrustAccessApplicationSaasAppCustomAttribute[] | cdktf.IResolvable): void;
    resetCustomAttribute(): void;
    get customAttributeInput(): cdktf.IResolvable | ZeroTrustAccessApplicationSaasAppCustomAttribute[] | undefined;
    private _customClaim;
    get customClaim(): ZeroTrustAccessApplicationSaasAppCustomClaimList;
    putCustomClaim(value: ZeroTrustAccessApplicationSaasAppCustomClaim[] | cdktf.IResolvable): void;
    resetCustomClaim(): void;
    get customClaimInput(): cdktf.IResolvable | ZeroTrustAccessApplicationSaasAppCustomClaim[] | undefined;
    private _hybridAndImplicitOptions;
    get hybridAndImplicitOptions(): ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptionsOutputReference;
    putHybridAndImplicitOptions(value: ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions): void;
    resetHybridAndImplicitOptions(): void;
    get hybridAndImplicitOptionsInput(): ZeroTrustAccessApplicationSaasAppHybridAndImplicitOptions | undefined;
    private _refreshTokenOptions;
    get refreshTokenOptions(): ZeroTrustAccessApplicationSaasAppRefreshTokenOptionsList;
    putRefreshTokenOptions(value: ZeroTrustAccessApplicationSaasAppRefreshTokenOptions[] | cdktf.IResolvable): void;
    resetRefreshTokenOptions(): void;
    get refreshTokenOptionsInput(): cdktf.IResolvable | ZeroTrustAccessApplicationSaasAppRefreshTokenOptions[] | undefined;
}
export interface ZeroTrustAccessApplicationScimConfigAuthentication {
    /**
    * URL used to generate the auth code used during token generation. Required when using `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.token_url`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#authorization_url ZeroTrustAccessApplication#authorization_url}
    */
    readonly authorizationUrl?: string;
    /**
    * Client ID used to authenticate when generating a token for authenticating with the remote SCIM service. Required when using `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#client_id ZeroTrustAccessApplication#client_id}
    */
    readonly clientId?: string;
    /**
    * Secret used to authenticate when generating a token for authenticating with the remove SCIM service. Required when using `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#client_secret ZeroTrustAccessApplication#client_secret}
    */
    readonly clientSecret?: string;
    /**
    * Required when using `scim_config.0.authentication.0.user`. Conflicts with `scim_config.0.authentication.0.token`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`, `scim_config.0.authentication.0.scopes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#password ZeroTrustAccessApplication#password}
    */
    readonly password?: string;
    /**
    * The authentication scheme to use when making SCIM requests to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#scheme ZeroTrustAccessApplication#scheme}
    */
    readonly scheme: string;
    /**
    * The authorization scopes to request when generating the token used to authenticate with the remove SCIM service. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#scopes ZeroTrustAccessApplication#scopes}
    */
    readonly scopes?: string[];
    /**
    * Token used to authenticate with the remote SCIM service. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`, `scim_config.0.authentication.0.scopes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#token ZeroTrustAccessApplication#token}
    */
    readonly token?: string;
    /**
    * URL used to generate the token used to authenticate with the remote SCIM service. Required when using `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.client_id`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#token_url ZeroTrustAccessApplication#token_url}
    */
    readonly tokenUrl?: string;
    /**
    * User name used to authenticate with the remote SCIM service. Required when using `scim_config.0.authentication.0.password`. Conflicts with `scim_config.0.authentication.0.token`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`, `scim_config.0.authentication.0.scopes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#user ZeroTrustAccessApplication#user}
    */
    readonly user?: string;
}
export declare function zeroTrustAccessApplicationScimConfigAuthenticationToTerraform(struct?: ZeroTrustAccessApplicationScimConfigAuthenticationOutputReference | ZeroTrustAccessApplicationScimConfigAuthentication): any;
export declare function zeroTrustAccessApplicationScimConfigAuthenticationToHclTerraform(struct?: ZeroTrustAccessApplicationScimConfigAuthenticationOutputReference | ZeroTrustAccessApplicationScimConfigAuthentication): any;
export declare class ZeroTrustAccessApplicationScimConfigAuthenticationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationScimConfigAuthentication | undefined;
    set internalValue(value: ZeroTrustAccessApplicationScimConfigAuthentication | undefined);
    private _authorizationUrl?;
    get authorizationUrl(): string;
    set authorizationUrl(value: string);
    resetAuthorizationUrl(): void;
    get authorizationUrlInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string;
    set clientSecret(value: string);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    get schemeInput(): string | undefined;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    resetScopes(): void;
    get scopesInput(): string[] | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _tokenUrl?;
    get tokenUrl(): string;
    set tokenUrl(value: string);
    resetTokenUrl(): void;
    get tokenUrlInput(): string | undefined;
    private _user?;
    get user(): string;
    set user(value: string);
    resetUser(): void;
    get userInput(): string | undefined;
}
export interface ZeroTrustAccessApplicationScimConfigMappingsOperations {
    /**
    * Whether or not this mapping applies to create (POST) operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#create ZeroTrustAccessApplication#create}
    */
    readonly create?: boolean | cdktf.IResolvable;
    /**
    * Whether or not this mapping applies to DELETE operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#delete ZeroTrustAccessApplication#delete}
    */
    readonly delete?: boolean | cdktf.IResolvable;
    /**
    * Whether or not this mapping applies to update (PATCH/PUT) operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#update ZeroTrustAccessApplication#update}
    */
    readonly update?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustAccessApplicationScimConfigMappingsOperationsToTerraform(struct?: ZeroTrustAccessApplicationScimConfigMappingsOperationsOutputReference | ZeroTrustAccessApplicationScimConfigMappingsOperations): any;
export declare function zeroTrustAccessApplicationScimConfigMappingsOperationsToHclTerraform(struct?: ZeroTrustAccessApplicationScimConfigMappingsOperationsOutputReference | ZeroTrustAccessApplicationScimConfigMappingsOperations): any;
export declare class ZeroTrustAccessApplicationScimConfigMappingsOperationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationScimConfigMappingsOperations | undefined;
    set internalValue(value: ZeroTrustAccessApplicationScimConfigMappingsOperations | undefined);
    private _create?;
    get create(): boolean | cdktf.IResolvable;
    set create(value: boolean | cdktf.IResolvable);
    resetCreate(): void;
    get createInput(): boolean | cdktf.IResolvable | undefined;
    private _delete?;
    get delete(): boolean | cdktf.IResolvable;
    set delete(value: boolean | cdktf.IResolvable);
    resetDelete(): void;
    get deleteInput(): boolean | cdktf.IResolvable | undefined;
    private _update?;
    get update(): boolean | cdktf.IResolvable;
    set update(value: boolean | cdktf.IResolvable);
    resetUpdate(): void;
    get updateInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustAccessApplicationScimConfigMappings {
    /**
    * Whether or not this mapping is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#enabled ZeroTrustAccessApplication#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * A [SCIM filter expression](https://datatracker.ietf.org/doc/html/rfc7644#section-3.4.2.2) that matches resources that should be provisioned to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#filter ZeroTrustAccessApplication#filter}
    */
    readonly filter?: string;
    /**
    * Which SCIM resource type this mapping applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#schema ZeroTrustAccessApplication#schema}
    */
    readonly schema: string;
    /**
    * A [JSONata](https://jsonata.org/) expression that transforms the resource before provisioning it in the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#transform_jsonata ZeroTrustAccessApplication#transform_jsonata}
    */
    readonly transformJsonata?: string;
    /**
    * operations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#operations ZeroTrustAccessApplication#operations}
    */
    readonly operations?: ZeroTrustAccessApplicationScimConfigMappingsOperations;
}
export declare function zeroTrustAccessApplicationScimConfigMappingsToTerraform(struct?: ZeroTrustAccessApplicationScimConfigMappings | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationScimConfigMappingsToHclTerraform(struct?: ZeroTrustAccessApplicationScimConfigMappings | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationScimConfigMappingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationScimConfigMappings | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationScimConfigMappings | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _schema?;
    get schema(): string;
    set schema(value: string);
    get schemaInput(): string | undefined;
    private _transformJsonata?;
    get transformJsonata(): string;
    set transformJsonata(value: string);
    resetTransformJsonata(): void;
    get transformJsonataInput(): string | undefined;
    private _operations;
    get operations(): ZeroTrustAccessApplicationScimConfigMappingsOperationsOutputReference;
    putOperations(value: ZeroTrustAccessApplicationScimConfigMappingsOperations): void;
    resetOperations(): void;
    get operationsInput(): ZeroTrustAccessApplicationScimConfigMappingsOperations | undefined;
}
export declare class ZeroTrustAccessApplicationScimConfigMappingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationScimConfigMappings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationScimConfigMappingsOutputReference;
}
export interface ZeroTrustAccessApplicationScimConfig {
    /**
    * If false, propagates DELETE requests to the target application for SCIM resources. If true, sets 'active' to false on the SCIM resource. Note: Some targets do not support DELETE operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#deactivate_on_delete ZeroTrustAccessApplication#deactivate_on_delete}
    */
    readonly deactivateOnDelete?: boolean | cdktf.IResolvable;
    /**
    * Whether SCIM provisioning is turned on for this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#enabled ZeroTrustAccessApplication#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * The UID of the IdP to use as the source for SCIM resources to provision to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#idp_uid ZeroTrustAccessApplication#idp_uid}
    */
    readonly idpUid: string;
    /**
    * The base URI for the application's SCIM-compatible API.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#remote_uri ZeroTrustAccessApplication#remote_uri}
    */
    readonly remoteUri: string;
    /**
    * authentication block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#authentication ZeroTrustAccessApplication#authentication}
    */
    readonly authentication?: ZeroTrustAccessApplicationScimConfigAuthentication;
    /**
    * mappings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#mappings ZeroTrustAccessApplication#mappings}
    */
    readonly mappings?: ZeroTrustAccessApplicationScimConfigMappings[] | cdktf.IResolvable;
}
export declare function zeroTrustAccessApplicationScimConfigToTerraform(struct?: ZeroTrustAccessApplicationScimConfigOutputReference | ZeroTrustAccessApplicationScimConfig): any;
export declare function zeroTrustAccessApplicationScimConfigToHclTerraform(struct?: ZeroTrustAccessApplicationScimConfigOutputReference | ZeroTrustAccessApplicationScimConfig): any;
export declare class ZeroTrustAccessApplicationScimConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustAccessApplicationScimConfig | undefined;
    set internalValue(value: ZeroTrustAccessApplicationScimConfig | undefined);
    private _deactivateOnDelete?;
    get deactivateOnDelete(): boolean | cdktf.IResolvable;
    set deactivateOnDelete(value: boolean | cdktf.IResolvable);
    resetDeactivateOnDelete(): void;
    get deactivateOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _idpUid?;
    get idpUid(): string;
    set idpUid(value: string);
    get idpUidInput(): string | undefined;
    private _remoteUri?;
    get remoteUri(): string;
    set remoteUri(value: string);
    get remoteUriInput(): string | undefined;
    private _authentication;
    get authentication(): ZeroTrustAccessApplicationScimConfigAuthenticationOutputReference;
    putAuthentication(value: ZeroTrustAccessApplicationScimConfigAuthentication): void;
    resetAuthentication(): void;
    get authenticationInput(): ZeroTrustAccessApplicationScimConfigAuthentication | undefined;
    private _mappings;
    get mappings(): ZeroTrustAccessApplicationScimConfigMappingsList;
    putMappings(value: ZeroTrustAccessApplicationScimConfigMappings[] | cdktf.IResolvable): void;
    resetMappings(): void;
    get mappingsInput(): cdktf.IResolvable | ZeroTrustAccessApplicationScimConfigMappings[] | undefined;
}
export interface ZeroTrustAccessApplicationTargetCriteriaTargetAttributes {
    /**
    * The key of the attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#name ZeroTrustAccessApplication#name}
    */
    readonly name: string;
    /**
    * The values of the attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#values ZeroTrustAccessApplication#values}
    */
    readonly values: string[];
}
export declare function zeroTrustAccessApplicationTargetCriteriaTargetAttributesToTerraform(struct?: ZeroTrustAccessApplicationTargetCriteriaTargetAttributes | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationTargetCriteriaTargetAttributesToHclTerraform(struct?: ZeroTrustAccessApplicationTargetCriteriaTargetAttributes | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationTargetCriteriaTargetAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationTargetCriteriaTargetAttributes | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationTargetCriteriaTargetAttributes | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _values?;
    get values(): string[];
    set values(value: string[]);
    get valuesInput(): string[] | undefined;
}
export declare class ZeroTrustAccessApplicationTargetCriteriaTargetAttributesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationTargetCriteriaTargetAttributes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationTargetCriteriaTargetAttributesOutputReference;
}
export interface ZeroTrustAccessApplicationTargetCriteria {
    /**
    * The port that the targets use for the chosen communication protocol. A port cannot be assigned to multiple protocols.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#port ZeroTrustAccessApplication#port}
    */
    readonly port: number;
    /**
    * The communication protocol your application secures.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#protocol ZeroTrustAccessApplication#protocol}
    */
    readonly protocol: string;
    /**
    * target_attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#target_attributes ZeroTrustAccessApplication#target_attributes}
    */
    readonly targetAttributes: ZeroTrustAccessApplicationTargetCriteriaTargetAttributes[] | cdktf.IResolvable;
}
export declare function zeroTrustAccessApplicationTargetCriteriaToTerraform(struct?: ZeroTrustAccessApplicationTargetCriteria | cdktf.IResolvable): any;
export declare function zeroTrustAccessApplicationTargetCriteriaToHclTerraform(struct?: ZeroTrustAccessApplicationTargetCriteria | cdktf.IResolvable): any;
export declare class ZeroTrustAccessApplicationTargetCriteriaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessApplicationTargetCriteria | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessApplicationTargetCriteria | cdktf.IResolvable | undefined);
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
    private _targetAttributes;
    get targetAttributes(): ZeroTrustAccessApplicationTargetCriteriaTargetAttributesList;
    putTargetAttributes(value: ZeroTrustAccessApplicationTargetCriteriaTargetAttributes[] | cdktf.IResolvable): void;
    get targetAttributesInput(): cdktf.IResolvable | ZeroTrustAccessApplicationTargetCriteriaTargetAttributes[] | undefined;
}
export declare class ZeroTrustAccessApplicationTargetCriteriaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessApplicationTargetCriteria[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessApplicationTargetCriteriaOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application cloudflare_zero_trust_access_application}
*/
export declare class ZeroTrustAccessApplication extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_access_application";
    /**
    * Generates CDKTF code for importing a ZeroTrustAccessApplication resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustAccessApplication to import
    * @param importFromId The id of the existing ZeroTrustAccessApplication that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustAccessApplication to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_application cloudflare_zero_trust_access_application} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustAccessApplicationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: ZeroTrustAccessApplicationConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _allowAuthenticateViaWarp?;
    get allowAuthenticateViaWarp(): boolean | cdktf.IResolvable;
    set allowAuthenticateViaWarp(value: boolean | cdktf.IResolvable);
    resetAllowAuthenticateViaWarp(): void;
    get allowAuthenticateViaWarpInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedIdps?;
    get allowedIdps(): string[];
    set allowedIdps(value: string[]);
    resetAllowedIdps(): void;
    get allowedIdpsInput(): string[] | undefined;
    private _appLauncherLogoUrl?;
    get appLauncherLogoUrl(): string;
    set appLauncherLogoUrl(value: string);
    resetAppLauncherLogoUrl(): void;
    get appLauncherLogoUrlInput(): string | undefined;
    private _appLauncherVisible?;
    get appLauncherVisible(): boolean | cdktf.IResolvable;
    set appLauncherVisible(value: boolean | cdktf.IResolvable);
    resetAppLauncherVisible(): void;
    get appLauncherVisibleInput(): boolean | cdktf.IResolvable | undefined;
    get aud(): string;
    private _autoRedirectToIdentity?;
    get autoRedirectToIdentity(): boolean | cdktf.IResolvable;
    set autoRedirectToIdentity(value: boolean | cdktf.IResolvable);
    resetAutoRedirectToIdentity(): void;
    get autoRedirectToIdentityInput(): boolean | cdktf.IResolvable | undefined;
    private _bgColor?;
    get bgColor(): string;
    set bgColor(value: string);
    resetBgColor(): void;
    get bgColorInput(): string | undefined;
    private _customDenyMessage?;
    get customDenyMessage(): string;
    set customDenyMessage(value: string);
    resetCustomDenyMessage(): void;
    get customDenyMessageInput(): string | undefined;
    private _customDenyUrl?;
    get customDenyUrl(): string;
    set customDenyUrl(value: string);
    resetCustomDenyUrl(): void;
    get customDenyUrlInput(): string | undefined;
    private _customNonIdentityDenyUrl?;
    get customNonIdentityDenyUrl(): string;
    set customNonIdentityDenyUrl(value: string);
    resetCustomNonIdentityDenyUrl(): void;
    get customNonIdentityDenyUrlInput(): string | undefined;
    private _customPages?;
    get customPages(): string[];
    set customPages(value: string[]);
    resetCustomPages(): void;
    get customPagesInput(): string[] | undefined;
    private _domain?;
    get domain(): string;
    set domain(value: string);
    resetDomain(): void;
    get domainInput(): string | undefined;
    private _enableBindingCookie?;
    get enableBindingCookie(): boolean | cdktf.IResolvable;
    set enableBindingCookie(value: boolean | cdktf.IResolvable);
    resetEnableBindingCookie(): void;
    get enableBindingCookieInput(): boolean | cdktf.IResolvable | undefined;
    private _headerBgColor?;
    get headerBgColor(): string;
    set headerBgColor(value: string);
    resetHeaderBgColor(): void;
    get headerBgColorInput(): string | undefined;
    private _httpOnlyCookieAttribute?;
    get httpOnlyCookieAttribute(): boolean | cdktf.IResolvable;
    set httpOnlyCookieAttribute(value: boolean | cdktf.IResolvable);
    resetHttpOnlyCookieAttribute(): void;
    get httpOnlyCookieAttributeInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _logoUrl?;
    get logoUrl(): string;
    set logoUrl(value: string);
    resetLogoUrl(): void;
    get logoUrlInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _optionsPreflightBypass?;
    get optionsPreflightBypass(): boolean | cdktf.IResolvable;
    set optionsPreflightBypass(value: boolean | cdktf.IResolvable);
    resetOptionsPreflightBypass(): void;
    get optionsPreflightBypassInput(): boolean | cdktf.IResolvable | undefined;
    private _policies?;
    get policies(): string[];
    set policies(value: string[]);
    resetPolicies(): void;
    get policiesInput(): string[] | undefined;
    private _sameSiteCookieAttribute?;
    get sameSiteCookieAttribute(): string;
    set sameSiteCookieAttribute(value: string);
    resetSameSiteCookieAttribute(): void;
    get sameSiteCookieAttributeInput(): string | undefined;
    private _selfHostedDomains?;
    get selfHostedDomains(): string[];
    set selfHostedDomains(value: string[]);
    resetSelfHostedDomains(): void;
    get selfHostedDomainsInput(): string[] | undefined;
    private _serviceAuth401Redirect?;
    get serviceAuth401Redirect(): boolean | cdktf.IResolvable;
    set serviceAuth401Redirect(value: boolean | cdktf.IResolvable);
    resetServiceAuth401Redirect(): void;
    get serviceAuth401RedirectInput(): boolean | cdktf.IResolvable | undefined;
    private _sessionDuration?;
    get sessionDuration(): string;
    set sessionDuration(value: string);
    resetSessionDuration(): void;
    get sessionDurationInput(): string | undefined;
    private _skipAppLauncherLoginPage?;
    get skipAppLauncherLoginPage(): boolean | cdktf.IResolvable;
    set skipAppLauncherLoginPage(value: boolean | cdktf.IResolvable);
    resetSkipAppLauncherLoginPage(): void;
    get skipAppLauncherLoginPageInput(): boolean | cdktf.IResolvable | undefined;
    private _skipInterstitial?;
    get skipInterstitial(): boolean | cdktf.IResolvable;
    set skipInterstitial(value: boolean | cdktf.IResolvable);
    resetSkipInterstitial(): void;
    get skipInterstitialInput(): boolean | cdktf.IResolvable | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    private _corsHeaders;
    get corsHeaders(): ZeroTrustAccessApplicationCorsHeadersList;
    putCorsHeaders(value: ZeroTrustAccessApplicationCorsHeaders[] | cdktf.IResolvable): void;
    resetCorsHeaders(): void;
    get corsHeadersInput(): cdktf.IResolvable | ZeroTrustAccessApplicationCorsHeaders[] | undefined;
    private _footerLinks;
    get footerLinks(): ZeroTrustAccessApplicationFooterLinksList;
    putFooterLinks(value: ZeroTrustAccessApplicationFooterLinks[] | cdktf.IResolvable): void;
    resetFooterLinks(): void;
    get footerLinksInput(): cdktf.IResolvable | ZeroTrustAccessApplicationFooterLinks[] | undefined;
    private _landingPageDesign;
    get landingPageDesign(): ZeroTrustAccessApplicationLandingPageDesignOutputReference;
    putLandingPageDesign(value: ZeroTrustAccessApplicationLandingPageDesign): void;
    resetLandingPageDesign(): void;
    get landingPageDesignInput(): ZeroTrustAccessApplicationLandingPageDesign | undefined;
    private _saasApp;
    get saasApp(): ZeroTrustAccessApplicationSaasAppOutputReference;
    putSaasApp(value: ZeroTrustAccessApplicationSaasApp): void;
    resetSaasApp(): void;
    get saasAppInput(): ZeroTrustAccessApplicationSaasApp | undefined;
    private _scimConfig;
    get scimConfig(): ZeroTrustAccessApplicationScimConfigOutputReference;
    putScimConfig(value: ZeroTrustAccessApplicationScimConfig): void;
    resetScimConfig(): void;
    get scimConfigInput(): ZeroTrustAccessApplicationScimConfig | undefined;
    private _targetCriteria;
    get targetCriteria(): ZeroTrustAccessApplicationTargetCriteriaList;
    putTargetCriteria(value: ZeroTrustAccessApplicationTargetCriteria[] | cdktf.IResolvable): void;
    resetTargetCriteria(): void;
    get targetCriteriaInput(): cdktf.IResolvable | ZeroTrustAccessApplicationTargetCriteria[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
