/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustAccessGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. Conflicts with `zone_id`. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#account_id ZeroTrustAccessGroup#account_id}
    */
    readonly accountId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name: string;
    /**
    * The zone identifier to target for the resource. Conflicts with `account_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#zone_id ZeroTrustAccessGroup#zone_id}
    */
    readonly zoneId?: string;
    /**
    * exclude block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#exclude ZeroTrustAccessGroup#exclude}
    */
    readonly exclude?: ZeroTrustAccessGroupExclude[] | cdktf.IResolvable;
    /**
    * include block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#include ZeroTrustAccessGroup#include}
    */
    readonly include: ZeroTrustAccessGroupInclude[] | cdktf.IResolvable;
    /**
    * require block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#require ZeroTrustAccessGroup#require}
    */
    readonly require?: ZeroTrustAccessGroupRequire[] | cdktf.IResolvable;
}
export interface ZeroTrustAccessGroupExcludeAuthContext {
    /**
    * The ACID of the Authentication Context.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ac_id ZeroTrustAccessGroup#ac_id}
    */
    readonly acId: string;
    /**
    * The ID of the Authentication Context.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The ID of the Azure identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId: string;
}
export declare function zeroTrustAccessGroupExcludeAuthContextToTerraform(struct?: ZeroTrustAccessGroupExcludeAuthContext | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeAuthContextToHclTerraform(struct?: ZeroTrustAccessGroupExcludeAuthContext | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeAuthContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeAuthContext | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeAuthContext | cdktf.IResolvable | undefined);
    private _acId?;
    get acId(): string;
    set acId(value: string);
    get acIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupExcludeAuthContextList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeAuthContext[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeAuthContextOutputReference;
}
export interface ZeroTrustAccessGroupExcludeAzure {
    /**
    * The ID of the Azure group or user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string[];
    /**
    * The ID of the Azure identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupExcludeAzureToTerraform(struct?: ZeroTrustAccessGroupExcludeAzure | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeAzureToHclTerraform(struct?: ZeroTrustAccessGroupExcludeAzure | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeAzureOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeAzure | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeAzure | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string[];
    set id(value: string[]);
    resetId(): void;
    get idInput(): string[] | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupExcludeAzureList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeAzure[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeAzureOutputReference;
}
export interface ZeroTrustAccessGroupExcludeExternalEvaluation {
    /**
    * The API endpoint containing your business logic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#evaluate_url ZeroTrustAccessGroup#evaluate_url}
    */
    readonly evaluateUrl?: string;
    /**
    * The API endpoint containing the key that Access uses to verify that the response came from your API.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#keys_url ZeroTrustAccessGroup#keys_url}
    */
    readonly keysUrl?: string;
}
export declare function zeroTrustAccessGroupExcludeExternalEvaluationToTerraform(struct?: ZeroTrustAccessGroupExcludeExternalEvaluation | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeExternalEvaluationToHclTerraform(struct?: ZeroTrustAccessGroupExcludeExternalEvaluation | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeExternalEvaluationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeExternalEvaluation | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeExternalEvaluation | cdktf.IResolvable | undefined);
    private _evaluateUrl?;
    get evaluateUrl(): string;
    set evaluateUrl(value: string);
    resetEvaluateUrl(): void;
    get evaluateUrlInput(): string | undefined;
    private _keysUrl?;
    get keysUrl(): string;
    set keysUrl(value: string);
    resetKeysUrl(): void;
    get keysUrlInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupExcludeExternalEvaluationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeExternalEvaluation[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeExternalEvaluationOutputReference;
}
export interface ZeroTrustAccessGroupExcludeGithub {
    /**
    * The ID of your Github identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
    /**
    * The name of the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name?: string;
    /**
    * The teams that should be matched.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#teams ZeroTrustAccessGroup#teams}
    */
    readonly teams?: string[];
}
export declare function zeroTrustAccessGroupExcludeGithubToTerraform(struct?: ZeroTrustAccessGroupExcludeGithub | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeGithubToHclTerraform(struct?: ZeroTrustAccessGroupExcludeGithub | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeGithubOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeGithub | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeGithub | cdktf.IResolvable | undefined);
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _teams?;
    get teams(): string[];
    set teams(value: string[]);
    resetTeams(): void;
    get teamsInput(): string[] | undefined;
}
export declare class ZeroTrustAccessGroupExcludeGithubList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeGithub[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeGithubOutputReference;
}
export interface ZeroTrustAccessGroupExcludeGsuite {
    /**
    * The email of the Google Workspace group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email ZeroTrustAccessGroup#email}
    */
    readonly email?: string[];
    /**
    * The ID of your Google Workspace identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupExcludeGsuiteToTerraform(struct?: ZeroTrustAccessGroupExcludeGsuite | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeGsuiteToHclTerraform(struct?: ZeroTrustAccessGroupExcludeGsuite | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeGsuiteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeGsuite | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeGsuite | cdktf.IResolvable | undefined);
    private _email?;
    get email(): string[];
    set email(value: string[]);
    resetEmail(): void;
    get emailInput(): string[] | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupExcludeGsuiteList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeGsuite[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeGsuiteOutputReference;
}
export interface ZeroTrustAccessGroupExcludeOkta {
    /**
    * The ID of your Okta identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
    /**
    * The name of the Okta Group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name?: string[];
}
export declare function zeroTrustAccessGroupExcludeOktaToTerraform(struct?: ZeroTrustAccessGroupExcludeOkta | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeOktaToHclTerraform(struct?: ZeroTrustAccessGroupExcludeOkta | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeOktaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeOkta | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeOkta | cdktf.IResolvable | undefined);
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
    private _name?;
    get name(): string[];
    set name(value: string[]);
    resetName(): void;
    get nameInput(): string[] | undefined;
}
export declare class ZeroTrustAccessGroupExcludeOktaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeOkta[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeOktaOutputReference;
}
export interface ZeroTrustAccessGroupExcludeSaml {
    /**
    * The name of the SAML attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#attribute_name ZeroTrustAccessGroup#attribute_name}
    */
    readonly attributeName?: string;
    /**
    * The SAML attribute value to look for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#attribute_value ZeroTrustAccessGroup#attribute_value}
    */
    readonly attributeValue?: string;
    /**
    * The ID of your SAML identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupExcludeSamlToTerraform(struct?: ZeroTrustAccessGroupExcludeSaml | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeSamlToHclTerraform(struct?: ZeroTrustAccessGroupExcludeSaml | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeSamlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExcludeSaml | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExcludeSaml | cdktf.IResolvable | undefined);
    private _attributeName?;
    get attributeName(): string;
    set attributeName(value: string);
    resetAttributeName(): void;
    get attributeNameInput(): string | undefined;
    private _attributeValue?;
    get attributeValue(): string;
    set attributeValue(value: string);
    resetAttributeValue(): void;
    get attributeValueInput(): string | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupExcludeSamlList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExcludeSaml[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeSamlOutputReference;
}
export interface ZeroTrustAccessGroupExclude {
    /**
    * Matches any valid Access service token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#any_valid_service_token ZeroTrustAccessGroup#any_valid_service_token}
    */
    readonly anyValidServiceToken?: boolean | cdktf.IResolvable;
    /**
    * The type of authentication method. Refer to https://datatracker.ietf.org/doc/html/rfc8176#section-2 for possible types.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#auth_method ZeroTrustAccessGroup#auth_method}
    */
    readonly authMethod?: string;
    /**
    * Matches any valid client certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#certificate ZeroTrustAccessGroup#certificate}
    */
    readonly certificate?: boolean | cdktf.IResolvable;
    /**
    * Matches a valid client certificate common name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#common_name ZeroTrustAccessGroup#common_name}
    */
    readonly commonName?: string;
    /**
    * Overflow field if you need to have multiple common_name rules in a single policy.  Use in place of the singular common_name field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#common_names ZeroTrustAccessGroup#common_names}
    */
    readonly commonNames?: string[];
    /**
    * The ID of a device posture integration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#device_posture ZeroTrustAccessGroup#device_posture}
    */
    readonly devicePosture?: string[];
    /**
    * The email of the user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email ZeroTrustAccessGroup#email}
    */
    readonly email?: string[];
    /**
    * The email domain to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email_domain ZeroTrustAccessGroup#email_domain}
    */
    readonly emailDomain?: string[];
    /**
    * The ID of a previously created email list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email_list ZeroTrustAccessGroup#email_list}
    */
    readonly emailList?: string[];
    /**
    * Matches everyone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#everyone ZeroTrustAccessGroup#everyone}
    */
    readonly everyone?: boolean | cdktf.IResolvable;
    /**
    * Matches a specific country.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#geo ZeroTrustAccessGroup#geo}
    */
    readonly geo?: string[];
    /**
    * The ID of a previously created Access group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#group ZeroTrustAccessGroup#group}
    */
    readonly group?: string[];
    /**
    * An IPv4 or IPv6 CIDR block.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ip ZeroTrustAccessGroup#ip}
    */
    readonly ip?: string[];
    /**
    * The ID of a previously created IP list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ip_list ZeroTrustAccessGroup#ip_list}
    */
    readonly ipList?: string[];
    /**
    * The ID of a configured identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#login_method ZeroTrustAccessGroup#login_method}
    */
    readonly loginMethod?: string[];
    /**
    * The ID of an Access service token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#service_token ZeroTrustAccessGroup#service_token}
    */
    readonly serviceToken?: string[];
    /**
    * auth_context block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#auth_context ZeroTrustAccessGroup#auth_context}
    */
    readonly authContext?: ZeroTrustAccessGroupExcludeAuthContext[] | cdktf.IResolvable;
    /**
    * azure block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#azure ZeroTrustAccessGroup#azure}
    */
    readonly azure?: ZeroTrustAccessGroupExcludeAzure[] | cdktf.IResolvable;
    /**
    * external_evaluation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#external_evaluation ZeroTrustAccessGroup#external_evaluation}
    */
    readonly externalEvaluation?: ZeroTrustAccessGroupExcludeExternalEvaluation[] | cdktf.IResolvable;
    /**
    * github block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#github ZeroTrustAccessGroup#github}
    */
    readonly github?: ZeroTrustAccessGroupExcludeGithub[] | cdktf.IResolvable;
    /**
    * gsuite block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#gsuite ZeroTrustAccessGroup#gsuite}
    */
    readonly gsuite?: ZeroTrustAccessGroupExcludeGsuite[] | cdktf.IResolvable;
    /**
    * okta block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#okta ZeroTrustAccessGroup#okta}
    */
    readonly okta?: ZeroTrustAccessGroupExcludeOkta[] | cdktf.IResolvable;
    /**
    * saml block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#saml ZeroTrustAccessGroup#saml}
    */
    readonly saml?: ZeroTrustAccessGroupExcludeSaml[] | cdktf.IResolvable;
}
export declare function zeroTrustAccessGroupExcludeToTerraform(struct?: ZeroTrustAccessGroupExclude | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupExcludeToHclTerraform(struct?: ZeroTrustAccessGroupExclude | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupExcludeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupExclude | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupExclude | cdktf.IResolvable | undefined);
    private _anyValidServiceToken?;
    get anyValidServiceToken(): boolean | cdktf.IResolvable;
    set anyValidServiceToken(value: boolean | cdktf.IResolvable);
    resetAnyValidServiceToken(): void;
    get anyValidServiceTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _authMethod?;
    get authMethod(): string;
    set authMethod(value: string);
    resetAuthMethod(): void;
    get authMethodInput(): string | undefined;
    private _certificate?;
    get certificate(): boolean | cdktf.IResolvable;
    set certificate(value: boolean | cdktf.IResolvable);
    resetCertificate(): void;
    get certificateInput(): boolean | cdktf.IResolvable | undefined;
    private _commonName?;
    get commonName(): string;
    set commonName(value: string);
    resetCommonName(): void;
    get commonNameInput(): string | undefined;
    private _commonNames?;
    get commonNames(): string[];
    set commonNames(value: string[]);
    resetCommonNames(): void;
    get commonNamesInput(): string[] | undefined;
    private _devicePosture?;
    get devicePosture(): string[];
    set devicePosture(value: string[]);
    resetDevicePosture(): void;
    get devicePostureInput(): string[] | undefined;
    private _email?;
    get email(): string[];
    set email(value: string[]);
    resetEmail(): void;
    get emailInput(): string[] | undefined;
    private _emailDomain?;
    get emailDomain(): string[];
    set emailDomain(value: string[]);
    resetEmailDomain(): void;
    get emailDomainInput(): string[] | undefined;
    private _emailList?;
    get emailList(): string[];
    set emailList(value: string[]);
    resetEmailList(): void;
    get emailListInput(): string[] | undefined;
    private _everyone?;
    get everyone(): boolean | cdktf.IResolvable;
    set everyone(value: boolean | cdktf.IResolvable);
    resetEveryone(): void;
    get everyoneInput(): boolean | cdktf.IResolvable | undefined;
    private _geo?;
    get geo(): string[];
    set geo(value: string[]);
    resetGeo(): void;
    get geoInput(): string[] | undefined;
    private _group?;
    get group(): string[];
    set group(value: string[]);
    resetGroup(): void;
    get groupInput(): string[] | undefined;
    private _ip?;
    get ip(): string[];
    set ip(value: string[]);
    resetIp(): void;
    get ipInput(): string[] | undefined;
    private _ipList?;
    get ipList(): string[];
    set ipList(value: string[]);
    resetIpList(): void;
    get ipListInput(): string[] | undefined;
    private _loginMethod?;
    get loginMethod(): string[];
    set loginMethod(value: string[]);
    resetLoginMethod(): void;
    get loginMethodInput(): string[] | undefined;
    private _serviceToken?;
    get serviceToken(): string[];
    set serviceToken(value: string[]);
    resetServiceToken(): void;
    get serviceTokenInput(): string[] | undefined;
    private _authContext;
    get authContext(): ZeroTrustAccessGroupExcludeAuthContextList;
    putAuthContext(value: ZeroTrustAccessGroupExcludeAuthContext[] | cdktf.IResolvable): void;
    resetAuthContext(): void;
    get authContextInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeAuthContext[] | undefined;
    private _azure;
    get azure(): ZeroTrustAccessGroupExcludeAzureList;
    putAzure(value: ZeroTrustAccessGroupExcludeAzure[] | cdktf.IResolvable): void;
    resetAzure(): void;
    get azureInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeAzure[] | undefined;
    private _externalEvaluation;
    get externalEvaluation(): ZeroTrustAccessGroupExcludeExternalEvaluationList;
    putExternalEvaluation(value: ZeroTrustAccessGroupExcludeExternalEvaluation[] | cdktf.IResolvable): void;
    resetExternalEvaluation(): void;
    get externalEvaluationInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeExternalEvaluation[] | undefined;
    private _github;
    get github(): ZeroTrustAccessGroupExcludeGithubList;
    putGithub(value: ZeroTrustAccessGroupExcludeGithub[] | cdktf.IResolvable): void;
    resetGithub(): void;
    get githubInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeGithub[] | undefined;
    private _gsuite;
    get gsuite(): ZeroTrustAccessGroupExcludeGsuiteList;
    putGsuite(value: ZeroTrustAccessGroupExcludeGsuite[] | cdktf.IResolvable): void;
    resetGsuite(): void;
    get gsuiteInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeGsuite[] | undefined;
    private _okta;
    get okta(): ZeroTrustAccessGroupExcludeOktaList;
    putOkta(value: ZeroTrustAccessGroupExcludeOkta[] | cdktf.IResolvable): void;
    resetOkta(): void;
    get oktaInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeOkta[] | undefined;
    private _saml;
    get saml(): ZeroTrustAccessGroupExcludeSamlList;
    putSaml(value: ZeroTrustAccessGroupExcludeSaml[] | cdktf.IResolvable): void;
    resetSaml(): void;
    get samlInput(): cdktf.IResolvable | ZeroTrustAccessGroupExcludeSaml[] | undefined;
}
export declare class ZeroTrustAccessGroupExcludeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupExclude[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupExcludeOutputReference;
}
export interface ZeroTrustAccessGroupIncludeAuthContext {
    /**
    * The ACID of the Authentication Context.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ac_id ZeroTrustAccessGroup#ac_id}
    */
    readonly acId: string;
    /**
    * The ID of the Authentication Context.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The ID of the Azure identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId: string;
}
export declare function zeroTrustAccessGroupIncludeAuthContextToTerraform(struct?: ZeroTrustAccessGroupIncludeAuthContext | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeAuthContextToHclTerraform(struct?: ZeroTrustAccessGroupIncludeAuthContext | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeAuthContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeAuthContext | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeAuthContext | cdktf.IResolvable | undefined);
    private _acId?;
    get acId(): string;
    set acId(value: string);
    get acIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupIncludeAuthContextList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeAuthContext[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeAuthContextOutputReference;
}
export interface ZeroTrustAccessGroupIncludeAzure {
    /**
    * The ID of the Azure group or user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string[];
    /**
    * The ID of the Azure identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupIncludeAzureToTerraform(struct?: ZeroTrustAccessGroupIncludeAzure | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeAzureToHclTerraform(struct?: ZeroTrustAccessGroupIncludeAzure | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeAzureOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeAzure | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeAzure | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string[];
    set id(value: string[]);
    resetId(): void;
    get idInput(): string[] | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupIncludeAzureList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeAzure[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeAzureOutputReference;
}
export interface ZeroTrustAccessGroupIncludeExternalEvaluation {
    /**
    * The API endpoint containing your business logic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#evaluate_url ZeroTrustAccessGroup#evaluate_url}
    */
    readonly evaluateUrl?: string;
    /**
    * The API endpoint containing the key that Access uses to verify that the response came from your API.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#keys_url ZeroTrustAccessGroup#keys_url}
    */
    readonly keysUrl?: string;
}
export declare function zeroTrustAccessGroupIncludeExternalEvaluationToTerraform(struct?: ZeroTrustAccessGroupIncludeExternalEvaluation | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeExternalEvaluationToHclTerraform(struct?: ZeroTrustAccessGroupIncludeExternalEvaluation | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeExternalEvaluationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeExternalEvaluation | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeExternalEvaluation | cdktf.IResolvable | undefined);
    private _evaluateUrl?;
    get evaluateUrl(): string;
    set evaluateUrl(value: string);
    resetEvaluateUrl(): void;
    get evaluateUrlInput(): string | undefined;
    private _keysUrl?;
    get keysUrl(): string;
    set keysUrl(value: string);
    resetKeysUrl(): void;
    get keysUrlInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupIncludeExternalEvaluationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeExternalEvaluation[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeExternalEvaluationOutputReference;
}
export interface ZeroTrustAccessGroupIncludeGithub {
    /**
    * The ID of your Github identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
    /**
    * The name of the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name?: string;
    /**
    * The teams that should be matched.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#teams ZeroTrustAccessGroup#teams}
    */
    readonly teams?: string[];
}
export declare function zeroTrustAccessGroupIncludeGithubToTerraform(struct?: ZeroTrustAccessGroupIncludeGithub | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeGithubToHclTerraform(struct?: ZeroTrustAccessGroupIncludeGithub | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeGithubOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeGithub | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeGithub | cdktf.IResolvable | undefined);
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _teams?;
    get teams(): string[];
    set teams(value: string[]);
    resetTeams(): void;
    get teamsInput(): string[] | undefined;
}
export declare class ZeroTrustAccessGroupIncludeGithubList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeGithub[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeGithubOutputReference;
}
export interface ZeroTrustAccessGroupIncludeGsuite {
    /**
    * The email of the Google Workspace group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email ZeroTrustAccessGroup#email}
    */
    readonly email?: string[];
    /**
    * The ID of your Google Workspace identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupIncludeGsuiteToTerraform(struct?: ZeroTrustAccessGroupIncludeGsuite | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeGsuiteToHclTerraform(struct?: ZeroTrustAccessGroupIncludeGsuite | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeGsuiteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeGsuite | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeGsuite | cdktf.IResolvable | undefined);
    private _email?;
    get email(): string[];
    set email(value: string[]);
    resetEmail(): void;
    get emailInput(): string[] | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupIncludeGsuiteList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeGsuite[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeGsuiteOutputReference;
}
export interface ZeroTrustAccessGroupIncludeOkta {
    /**
    * The ID of your Okta identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
    /**
    * The name of the Okta Group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name?: string[];
}
export declare function zeroTrustAccessGroupIncludeOktaToTerraform(struct?: ZeroTrustAccessGroupIncludeOkta | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeOktaToHclTerraform(struct?: ZeroTrustAccessGroupIncludeOkta | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeOktaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeOkta | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeOkta | cdktf.IResolvable | undefined);
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
    private _name?;
    get name(): string[];
    set name(value: string[]);
    resetName(): void;
    get nameInput(): string[] | undefined;
}
export declare class ZeroTrustAccessGroupIncludeOktaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeOkta[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeOktaOutputReference;
}
export interface ZeroTrustAccessGroupIncludeSaml {
    /**
    * The name of the SAML attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#attribute_name ZeroTrustAccessGroup#attribute_name}
    */
    readonly attributeName?: string;
    /**
    * The SAML attribute value to look for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#attribute_value ZeroTrustAccessGroup#attribute_value}
    */
    readonly attributeValue?: string;
    /**
    * The ID of your SAML identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupIncludeSamlToTerraform(struct?: ZeroTrustAccessGroupIncludeSaml | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeSamlToHclTerraform(struct?: ZeroTrustAccessGroupIncludeSaml | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeSamlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupIncludeSaml | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupIncludeSaml | cdktf.IResolvable | undefined);
    private _attributeName?;
    get attributeName(): string;
    set attributeName(value: string);
    resetAttributeName(): void;
    get attributeNameInput(): string | undefined;
    private _attributeValue?;
    get attributeValue(): string;
    set attributeValue(value: string);
    resetAttributeValue(): void;
    get attributeValueInput(): string | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupIncludeSamlList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupIncludeSaml[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeSamlOutputReference;
}
export interface ZeroTrustAccessGroupInclude {
    /**
    * Matches any valid Access service token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#any_valid_service_token ZeroTrustAccessGroup#any_valid_service_token}
    */
    readonly anyValidServiceToken?: boolean | cdktf.IResolvable;
    /**
    * The type of authentication method. Refer to https://datatracker.ietf.org/doc/html/rfc8176#section-2 for possible types.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#auth_method ZeroTrustAccessGroup#auth_method}
    */
    readonly authMethod?: string;
    /**
    * Matches any valid client certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#certificate ZeroTrustAccessGroup#certificate}
    */
    readonly certificate?: boolean | cdktf.IResolvable;
    /**
    * Matches a valid client certificate common name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#common_name ZeroTrustAccessGroup#common_name}
    */
    readonly commonName?: string;
    /**
    * Overflow field if you need to have multiple common_name rules in a single policy.  Use in place of the singular common_name field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#common_names ZeroTrustAccessGroup#common_names}
    */
    readonly commonNames?: string[];
    /**
    * The ID of a device posture integration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#device_posture ZeroTrustAccessGroup#device_posture}
    */
    readonly devicePosture?: string[];
    /**
    * The email of the user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email ZeroTrustAccessGroup#email}
    */
    readonly email?: string[];
    /**
    * The email domain to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email_domain ZeroTrustAccessGroup#email_domain}
    */
    readonly emailDomain?: string[];
    /**
    * The ID of a previously created email list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email_list ZeroTrustAccessGroup#email_list}
    */
    readonly emailList?: string[];
    /**
    * Matches everyone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#everyone ZeroTrustAccessGroup#everyone}
    */
    readonly everyone?: boolean | cdktf.IResolvable;
    /**
    * Matches a specific country.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#geo ZeroTrustAccessGroup#geo}
    */
    readonly geo?: string[];
    /**
    * The ID of a previously created Access group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#group ZeroTrustAccessGroup#group}
    */
    readonly group?: string[];
    /**
    * An IPv4 or IPv6 CIDR block.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ip ZeroTrustAccessGroup#ip}
    */
    readonly ip?: string[];
    /**
    * The ID of a previously created IP list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ip_list ZeroTrustAccessGroup#ip_list}
    */
    readonly ipList?: string[];
    /**
    * The ID of a configured identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#login_method ZeroTrustAccessGroup#login_method}
    */
    readonly loginMethod?: string[];
    /**
    * The ID of an Access service token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#service_token ZeroTrustAccessGroup#service_token}
    */
    readonly serviceToken?: string[];
    /**
    * auth_context block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#auth_context ZeroTrustAccessGroup#auth_context}
    */
    readonly authContext?: ZeroTrustAccessGroupIncludeAuthContext[] | cdktf.IResolvable;
    /**
    * azure block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#azure ZeroTrustAccessGroup#azure}
    */
    readonly azure?: ZeroTrustAccessGroupIncludeAzure[] | cdktf.IResolvable;
    /**
    * external_evaluation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#external_evaluation ZeroTrustAccessGroup#external_evaluation}
    */
    readonly externalEvaluation?: ZeroTrustAccessGroupIncludeExternalEvaluation[] | cdktf.IResolvable;
    /**
    * github block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#github ZeroTrustAccessGroup#github}
    */
    readonly github?: ZeroTrustAccessGroupIncludeGithub[] | cdktf.IResolvable;
    /**
    * gsuite block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#gsuite ZeroTrustAccessGroup#gsuite}
    */
    readonly gsuite?: ZeroTrustAccessGroupIncludeGsuite[] | cdktf.IResolvable;
    /**
    * okta block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#okta ZeroTrustAccessGroup#okta}
    */
    readonly okta?: ZeroTrustAccessGroupIncludeOkta[] | cdktf.IResolvable;
    /**
    * saml block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#saml ZeroTrustAccessGroup#saml}
    */
    readonly saml?: ZeroTrustAccessGroupIncludeSaml[] | cdktf.IResolvable;
}
export declare function zeroTrustAccessGroupIncludeToTerraform(struct?: ZeroTrustAccessGroupInclude | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupIncludeToHclTerraform(struct?: ZeroTrustAccessGroupInclude | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupIncludeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupInclude | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupInclude | cdktf.IResolvable | undefined);
    private _anyValidServiceToken?;
    get anyValidServiceToken(): boolean | cdktf.IResolvable;
    set anyValidServiceToken(value: boolean | cdktf.IResolvable);
    resetAnyValidServiceToken(): void;
    get anyValidServiceTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _authMethod?;
    get authMethod(): string;
    set authMethod(value: string);
    resetAuthMethod(): void;
    get authMethodInput(): string | undefined;
    private _certificate?;
    get certificate(): boolean | cdktf.IResolvable;
    set certificate(value: boolean | cdktf.IResolvable);
    resetCertificate(): void;
    get certificateInput(): boolean | cdktf.IResolvable | undefined;
    private _commonName?;
    get commonName(): string;
    set commonName(value: string);
    resetCommonName(): void;
    get commonNameInput(): string | undefined;
    private _commonNames?;
    get commonNames(): string[];
    set commonNames(value: string[]);
    resetCommonNames(): void;
    get commonNamesInput(): string[] | undefined;
    private _devicePosture?;
    get devicePosture(): string[];
    set devicePosture(value: string[]);
    resetDevicePosture(): void;
    get devicePostureInput(): string[] | undefined;
    private _email?;
    get email(): string[];
    set email(value: string[]);
    resetEmail(): void;
    get emailInput(): string[] | undefined;
    private _emailDomain?;
    get emailDomain(): string[];
    set emailDomain(value: string[]);
    resetEmailDomain(): void;
    get emailDomainInput(): string[] | undefined;
    private _emailList?;
    get emailList(): string[];
    set emailList(value: string[]);
    resetEmailList(): void;
    get emailListInput(): string[] | undefined;
    private _everyone?;
    get everyone(): boolean | cdktf.IResolvable;
    set everyone(value: boolean | cdktf.IResolvable);
    resetEveryone(): void;
    get everyoneInput(): boolean | cdktf.IResolvable | undefined;
    private _geo?;
    get geo(): string[];
    set geo(value: string[]);
    resetGeo(): void;
    get geoInput(): string[] | undefined;
    private _group?;
    get group(): string[];
    set group(value: string[]);
    resetGroup(): void;
    get groupInput(): string[] | undefined;
    private _ip?;
    get ip(): string[];
    set ip(value: string[]);
    resetIp(): void;
    get ipInput(): string[] | undefined;
    private _ipList?;
    get ipList(): string[];
    set ipList(value: string[]);
    resetIpList(): void;
    get ipListInput(): string[] | undefined;
    private _loginMethod?;
    get loginMethod(): string[];
    set loginMethod(value: string[]);
    resetLoginMethod(): void;
    get loginMethodInput(): string[] | undefined;
    private _serviceToken?;
    get serviceToken(): string[];
    set serviceToken(value: string[]);
    resetServiceToken(): void;
    get serviceTokenInput(): string[] | undefined;
    private _authContext;
    get authContext(): ZeroTrustAccessGroupIncludeAuthContextList;
    putAuthContext(value: ZeroTrustAccessGroupIncludeAuthContext[] | cdktf.IResolvable): void;
    resetAuthContext(): void;
    get authContextInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeAuthContext[] | undefined;
    private _azure;
    get azure(): ZeroTrustAccessGroupIncludeAzureList;
    putAzure(value: ZeroTrustAccessGroupIncludeAzure[] | cdktf.IResolvable): void;
    resetAzure(): void;
    get azureInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeAzure[] | undefined;
    private _externalEvaluation;
    get externalEvaluation(): ZeroTrustAccessGroupIncludeExternalEvaluationList;
    putExternalEvaluation(value: ZeroTrustAccessGroupIncludeExternalEvaluation[] | cdktf.IResolvable): void;
    resetExternalEvaluation(): void;
    get externalEvaluationInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeExternalEvaluation[] | undefined;
    private _github;
    get github(): ZeroTrustAccessGroupIncludeGithubList;
    putGithub(value: ZeroTrustAccessGroupIncludeGithub[] | cdktf.IResolvable): void;
    resetGithub(): void;
    get githubInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeGithub[] | undefined;
    private _gsuite;
    get gsuite(): ZeroTrustAccessGroupIncludeGsuiteList;
    putGsuite(value: ZeroTrustAccessGroupIncludeGsuite[] | cdktf.IResolvable): void;
    resetGsuite(): void;
    get gsuiteInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeGsuite[] | undefined;
    private _okta;
    get okta(): ZeroTrustAccessGroupIncludeOktaList;
    putOkta(value: ZeroTrustAccessGroupIncludeOkta[] | cdktf.IResolvable): void;
    resetOkta(): void;
    get oktaInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeOkta[] | undefined;
    private _saml;
    get saml(): ZeroTrustAccessGroupIncludeSamlList;
    putSaml(value: ZeroTrustAccessGroupIncludeSaml[] | cdktf.IResolvable): void;
    resetSaml(): void;
    get samlInput(): cdktf.IResolvable | ZeroTrustAccessGroupIncludeSaml[] | undefined;
}
export declare class ZeroTrustAccessGroupIncludeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupInclude[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupIncludeOutputReference;
}
export interface ZeroTrustAccessGroupRequireAuthContext {
    /**
    * The ACID of the Authentication Context.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ac_id ZeroTrustAccessGroup#ac_id}
    */
    readonly acId: string;
    /**
    * The ID of the Authentication Context.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The ID of the Azure identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId: string;
}
export declare function zeroTrustAccessGroupRequireAuthContextToTerraform(struct?: ZeroTrustAccessGroupRequireAuthContext | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireAuthContextToHclTerraform(struct?: ZeroTrustAccessGroupRequireAuthContext | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireAuthContextOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireAuthContext | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireAuthContext | cdktf.IResolvable | undefined);
    private _acId?;
    get acId(): string;
    set acId(value: string);
    get acIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupRequireAuthContextList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireAuthContext[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireAuthContextOutputReference;
}
export interface ZeroTrustAccessGroupRequireAzure {
    /**
    * The ID of the Azure group or user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#id ZeroTrustAccessGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string[];
    /**
    * The ID of the Azure identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupRequireAzureToTerraform(struct?: ZeroTrustAccessGroupRequireAzure | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireAzureToHclTerraform(struct?: ZeroTrustAccessGroupRequireAzure | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireAzureOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireAzure | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireAzure | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string[];
    set id(value: string[]);
    resetId(): void;
    get idInput(): string[] | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupRequireAzureList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireAzure[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireAzureOutputReference;
}
export interface ZeroTrustAccessGroupRequireExternalEvaluation {
    /**
    * The API endpoint containing your business logic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#evaluate_url ZeroTrustAccessGroup#evaluate_url}
    */
    readonly evaluateUrl?: string;
    /**
    * The API endpoint containing the key that Access uses to verify that the response came from your API.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#keys_url ZeroTrustAccessGroup#keys_url}
    */
    readonly keysUrl?: string;
}
export declare function zeroTrustAccessGroupRequireExternalEvaluationToTerraform(struct?: ZeroTrustAccessGroupRequireExternalEvaluation | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireExternalEvaluationToHclTerraform(struct?: ZeroTrustAccessGroupRequireExternalEvaluation | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireExternalEvaluationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireExternalEvaluation | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireExternalEvaluation | cdktf.IResolvable | undefined);
    private _evaluateUrl?;
    get evaluateUrl(): string;
    set evaluateUrl(value: string);
    resetEvaluateUrl(): void;
    get evaluateUrlInput(): string | undefined;
    private _keysUrl?;
    get keysUrl(): string;
    set keysUrl(value: string);
    resetKeysUrl(): void;
    get keysUrlInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupRequireExternalEvaluationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireExternalEvaluation[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireExternalEvaluationOutputReference;
}
export interface ZeroTrustAccessGroupRequireGithub {
    /**
    * The ID of your Github identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
    /**
    * The name of the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name?: string;
    /**
    * The teams that should be matched.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#teams ZeroTrustAccessGroup#teams}
    */
    readonly teams?: string[];
}
export declare function zeroTrustAccessGroupRequireGithubToTerraform(struct?: ZeroTrustAccessGroupRequireGithub | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireGithubToHclTerraform(struct?: ZeroTrustAccessGroupRequireGithub | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireGithubOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireGithub | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireGithub | cdktf.IResolvable | undefined);
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _teams?;
    get teams(): string[];
    set teams(value: string[]);
    resetTeams(): void;
    get teamsInput(): string[] | undefined;
}
export declare class ZeroTrustAccessGroupRequireGithubList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireGithub[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireGithubOutputReference;
}
export interface ZeroTrustAccessGroupRequireGsuite {
    /**
    * The email of the Google Workspace group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email ZeroTrustAccessGroup#email}
    */
    readonly email?: string[];
    /**
    * The ID of your Google Workspace identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupRequireGsuiteToTerraform(struct?: ZeroTrustAccessGroupRequireGsuite | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireGsuiteToHclTerraform(struct?: ZeroTrustAccessGroupRequireGsuite | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireGsuiteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireGsuite | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireGsuite | cdktf.IResolvable | undefined);
    private _email?;
    get email(): string[];
    set email(value: string[]);
    resetEmail(): void;
    get emailInput(): string[] | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupRequireGsuiteList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireGsuite[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireGsuiteOutputReference;
}
export interface ZeroTrustAccessGroupRequireOkta {
    /**
    * The ID of your Okta identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
    /**
    * The name of the Okta Group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#name ZeroTrustAccessGroup#name}
    */
    readonly name?: string[];
}
export declare function zeroTrustAccessGroupRequireOktaToTerraform(struct?: ZeroTrustAccessGroupRequireOkta | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireOktaToHclTerraform(struct?: ZeroTrustAccessGroupRequireOkta | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireOktaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireOkta | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireOkta | cdktf.IResolvable | undefined);
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
    private _name?;
    get name(): string[];
    set name(value: string[]);
    resetName(): void;
    get nameInput(): string[] | undefined;
}
export declare class ZeroTrustAccessGroupRequireOktaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireOkta[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireOktaOutputReference;
}
export interface ZeroTrustAccessGroupRequireSaml {
    /**
    * The name of the SAML attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#attribute_name ZeroTrustAccessGroup#attribute_name}
    */
    readonly attributeName?: string;
    /**
    * The SAML attribute value to look for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#attribute_value ZeroTrustAccessGroup#attribute_value}
    */
    readonly attributeValue?: string;
    /**
    * The ID of your SAML identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#identity_provider_id ZeroTrustAccessGroup#identity_provider_id}
    */
    readonly identityProviderId?: string;
}
export declare function zeroTrustAccessGroupRequireSamlToTerraform(struct?: ZeroTrustAccessGroupRequireSaml | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireSamlToHclTerraform(struct?: ZeroTrustAccessGroupRequireSaml | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireSamlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequireSaml | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequireSaml | cdktf.IResolvable | undefined);
    private _attributeName?;
    get attributeName(): string;
    set attributeName(value: string);
    resetAttributeName(): void;
    get attributeNameInput(): string | undefined;
    private _attributeValue?;
    get attributeValue(): string;
    set attributeValue(value: string);
    resetAttributeValue(): void;
    get attributeValueInput(): string | undefined;
    private _identityProviderId?;
    get identityProviderId(): string;
    set identityProviderId(value: string);
    resetIdentityProviderId(): void;
    get identityProviderIdInput(): string | undefined;
}
export declare class ZeroTrustAccessGroupRequireSamlList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequireSaml[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireSamlOutputReference;
}
export interface ZeroTrustAccessGroupRequire {
    /**
    * Matches any valid Access service token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#any_valid_service_token ZeroTrustAccessGroup#any_valid_service_token}
    */
    readonly anyValidServiceToken?: boolean | cdktf.IResolvable;
    /**
    * The type of authentication method. Refer to https://datatracker.ietf.org/doc/html/rfc8176#section-2 for possible types.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#auth_method ZeroTrustAccessGroup#auth_method}
    */
    readonly authMethod?: string;
    /**
    * Matches any valid client certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#certificate ZeroTrustAccessGroup#certificate}
    */
    readonly certificate?: boolean | cdktf.IResolvable;
    /**
    * Matches a valid client certificate common name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#common_name ZeroTrustAccessGroup#common_name}
    */
    readonly commonName?: string;
    /**
    * Overflow field if you need to have multiple common_name rules in a single policy.  Use in place of the singular common_name field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#common_names ZeroTrustAccessGroup#common_names}
    */
    readonly commonNames?: string[];
    /**
    * The ID of a device posture integration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#device_posture ZeroTrustAccessGroup#device_posture}
    */
    readonly devicePosture?: string[];
    /**
    * The email of the user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email ZeroTrustAccessGroup#email}
    */
    readonly email?: string[];
    /**
    * The email domain to match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email_domain ZeroTrustAccessGroup#email_domain}
    */
    readonly emailDomain?: string[];
    /**
    * The ID of a previously created email list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#email_list ZeroTrustAccessGroup#email_list}
    */
    readonly emailList?: string[];
    /**
    * Matches everyone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#everyone ZeroTrustAccessGroup#everyone}
    */
    readonly everyone?: boolean | cdktf.IResolvable;
    /**
    * Matches a specific country.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#geo ZeroTrustAccessGroup#geo}
    */
    readonly geo?: string[];
    /**
    * The ID of a previously created Access group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#group ZeroTrustAccessGroup#group}
    */
    readonly group?: string[];
    /**
    * An IPv4 or IPv6 CIDR block.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ip ZeroTrustAccessGroup#ip}
    */
    readonly ip?: string[];
    /**
    * The ID of a previously created IP list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#ip_list ZeroTrustAccessGroup#ip_list}
    */
    readonly ipList?: string[];
    /**
    * The ID of a configured identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#login_method ZeroTrustAccessGroup#login_method}
    */
    readonly loginMethod?: string[];
    /**
    * The ID of an Access service token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#service_token ZeroTrustAccessGroup#service_token}
    */
    readonly serviceToken?: string[];
    /**
    * auth_context block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#auth_context ZeroTrustAccessGroup#auth_context}
    */
    readonly authContext?: ZeroTrustAccessGroupRequireAuthContext[] | cdktf.IResolvable;
    /**
    * azure block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#azure ZeroTrustAccessGroup#azure}
    */
    readonly azure?: ZeroTrustAccessGroupRequireAzure[] | cdktf.IResolvable;
    /**
    * external_evaluation block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#external_evaluation ZeroTrustAccessGroup#external_evaluation}
    */
    readonly externalEvaluation?: ZeroTrustAccessGroupRequireExternalEvaluation[] | cdktf.IResolvable;
    /**
    * github block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#github ZeroTrustAccessGroup#github}
    */
    readonly github?: ZeroTrustAccessGroupRequireGithub[] | cdktf.IResolvable;
    /**
    * gsuite block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#gsuite ZeroTrustAccessGroup#gsuite}
    */
    readonly gsuite?: ZeroTrustAccessGroupRequireGsuite[] | cdktf.IResolvable;
    /**
    * okta block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#okta ZeroTrustAccessGroup#okta}
    */
    readonly okta?: ZeroTrustAccessGroupRequireOkta[] | cdktf.IResolvable;
    /**
    * saml block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#saml ZeroTrustAccessGroup#saml}
    */
    readonly saml?: ZeroTrustAccessGroupRequireSaml[] | cdktf.IResolvable;
}
export declare function zeroTrustAccessGroupRequireToTerraform(struct?: ZeroTrustAccessGroupRequire | cdktf.IResolvable): any;
export declare function zeroTrustAccessGroupRequireToHclTerraform(struct?: ZeroTrustAccessGroupRequire | cdktf.IResolvable): any;
export declare class ZeroTrustAccessGroupRequireOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustAccessGroupRequire | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustAccessGroupRequire | cdktf.IResolvable | undefined);
    private _anyValidServiceToken?;
    get anyValidServiceToken(): boolean | cdktf.IResolvable;
    set anyValidServiceToken(value: boolean | cdktf.IResolvable);
    resetAnyValidServiceToken(): void;
    get anyValidServiceTokenInput(): boolean | cdktf.IResolvable | undefined;
    private _authMethod?;
    get authMethod(): string;
    set authMethod(value: string);
    resetAuthMethod(): void;
    get authMethodInput(): string | undefined;
    private _certificate?;
    get certificate(): boolean | cdktf.IResolvable;
    set certificate(value: boolean | cdktf.IResolvable);
    resetCertificate(): void;
    get certificateInput(): boolean | cdktf.IResolvable | undefined;
    private _commonName?;
    get commonName(): string;
    set commonName(value: string);
    resetCommonName(): void;
    get commonNameInput(): string | undefined;
    private _commonNames?;
    get commonNames(): string[];
    set commonNames(value: string[]);
    resetCommonNames(): void;
    get commonNamesInput(): string[] | undefined;
    private _devicePosture?;
    get devicePosture(): string[];
    set devicePosture(value: string[]);
    resetDevicePosture(): void;
    get devicePostureInput(): string[] | undefined;
    private _email?;
    get email(): string[];
    set email(value: string[]);
    resetEmail(): void;
    get emailInput(): string[] | undefined;
    private _emailDomain?;
    get emailDomain(): string[];
    set emailDomain(value: string[]);
    resetEmailDomain(): void;
    get emailDomainInput(): string[] | undefined;
    private _emailList?;
    get emailList(): string[];
    set emailList(value: string[]);
    resetEmailList(): void;
    get emailListInput(): string[] | undefined;
    private _everyone?;
    get everyone(): boolean | cdktf.IResolvable;
    set everyone(value: boolean | cdktf.IResolvable);
    resetEveryone(): void;
    get everyoneInput(): boolean | cdktf.IResolvable | undefined;
    private _geo?;
    get geo(): string[];
    set geo(value: string[]);
    resetGeo(): void;
    get geoInput(): string[] | undefined;
    private _group?;
    get group(): string[];
    set group(value: string[]);
    resetGroup(): void;
    get groupInput(): string[] | undefined;
    private _ip?;
    get ip(): string[];
    set ip(value: string[]);
    resetIp(): void;
    get ipInput(): string[] | undefined;
    private _ipList?;
    get ipList(): string[];
    set ipList(value: string[]);
    resetIpList(): void;
    get ipListInput(): string[] | undefined;
    private _loginMethod?;
    get loginMethod(): string[];
    set loginMethod(value: string[]);
    resetLoginMethod(): void;
    get loginMethodInput(): string[] | undefined;
    private _serviceToken?;
    get serviceToken(): string[];
    set serviceToken(value: string[]);
    resetServiceToken(): void;
    get serviceTokenInput(): string[] | undefined;
    private _authContext;
    get authContext(): ZeroTrustAccessGroupRequireAuthContextList;
    putAuthContext(value: ZeroTrustAccessGroupRequireAuthContext[] | cdktf.IResolvable): void;
    resetAuthContext(): void;
    get authContextInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireAuthContext[] | undefined;
    private _azure;
    get azure(): ZeroTrustAccessGroupRequireAzureList;
    putAzure(value: ZeroTrustAccessGroupRequireAzure[] | cdktf.IResolvable): void;
    resetAzure(): void;
    get azureInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireAzure[] | undefined;
    private _externalEvaluation;
    get externalEvaluation(): ZeroTrustAccessGroupRequireExternalEvaluationList;
    putExternalEvaluation(value: ZeroTrustAccessGroupRequireExternalEvaluation[] | cdktf.IResolvable): void;
    resetExternalEvaluation(): void;
    get externalEvaluationInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireExternalEvaluation[] | undefined;
    private _github;
    get github(): ZeroTrustAccessGroupRequireGithubList;
    putGithub(value: ZeroTrustAccessGroupRequireGithub[] | cdktf.IResolvable): void;
    resetGithub(): void;
    get githubInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireGithub[] | undefined;
    private _gsuite;
    get gsuite(): ZeroTrustAccessGroupRequireGsuiteList;
    putGsuite(value: ZeroTrustAccessGroupRequireGsuite[] | cdktf.IResolvable): void;
    resetGsuite(): void;
    get gsuiteInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireGsuite[] | undefined;
    private _okta;
    get okta(): ZeroTrustAccessGroupRequireOktaList;
    putOkta(value: ZeroTrustAccessGroupRequireOkta[] | cdktf.IResolvable): void;
    resetOkta(): void;
    get oktaInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireOkta[] | undefined;
    private _saml;
    get saml(): ZeroTrustAccessGroupRequireSamlList;
    putSaml(value: ZeroTrustAccessGroupRequireSaml[] | cdktf.IResolvable): void;
    resetSaml(): void;
    get samlInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequireSaml[] | undefined;
}
export declare class ZeroTrustAccessGroupRequireList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustAccessGroupRequire[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustAccessGroupRequireOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group cloudflare_zero_trust_access_group}
*/
export declare class ZeroTrustAccessGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_access_group";
    /**
    * Generates CDKTF code for importing a ZeroTrustAccessGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustAccessGroup to import
    * @param importFromId The id of the existing ZeroTrustAccessGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustAccessGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_access_group cloudflare_zero_trust_access_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustAccessGroupConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustAccessGroupConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    private _exclude;
    get exclude(): ZeroTrustAccessGroupExcludeList;
    putExclude(value: ZeroTrustAccessGroupExclude[] | cdktf.IResolvable): void;
    resetExclude(): void;
    get excludeInput(): cdktf.IResolvable | ZeroTrustAccessGroupExclude[] | undefined;
    private _include;
    get include(): ZeroTrustAccessGroupIncludeList;
    putInclude(value: ZeroTrustAccessGroupInclude[] | cdktf.IResolvable): void;
    get includeInput(): cdktf.IResolvable | ZeroTrustAccessGroupInclude[] | undefined;
    private _require;
    get require(): ZeroTrustAccessGroupRequireList;
    putRequire(value: ZeroTrustAccessGroupRequire[] | cdktf.IResolvable): void;
    resetRequire(): void;
    get requireInput(): cdktf.IResolvable | ZeroTrustAccessGroupRequire[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
