/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustDevicePostureRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#account_id ZeroTrustDevicePostureRule#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#description ZeroTrustDevicePostureRule#description}
    */
    readonly description?: string;
    /**
    * Expire posture results after the specified amount of time. Must be in the format `1h` or `30m`. Valid units are `h` and `m`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#expiration ZeroTrustDevicePostureRule#expiration}
    */
    readonly expiration?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#id ZeroTrustDevicePostureRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the device posture rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#name ZeroTrustDevicePostureRule#name}
    */
    readonly name?: string;
    /**
    * Tells the client when to run the device posture check. Must be in the format `1h` or `30m`. Valid units are `h` and `m`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#schedule ZeroTrustDevicePostureRule#schedule}
    */
    readonly schedule?: string;
    /**
    * The device posture rule type. Available values: `serial_number`, `file`, `application`, `gateway`, `warp`, `domain_joined`, `os_version`, `disk_encryption`, `firewall`, `client_certificate`, `client_certificate_v2`, `workspace_one`, `unique_client_id`, `crowdstrike_s2s`, `sentinelone`, `kolide`, `tanium_s2s`, `intune`, `sentinelone_s2s`, `custom_s2s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#type ZeroTrustDevicePostureRule#type}
    */
    readonly type: string;
    /**
    * input block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#input ZeroTrustDevicePostureRule#input}
    */
    readonly input?: ZeroTrustDevicePostureRuleInput[] | cdktf.IResolvable;
    /**
    * match block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#match ZeroTrustDevicePostureRule#match}
    */
    readonly match?: ZeroTrustDevicePostureRuleMatch[] | cdktf.IResolvable;
}
export interface ZeroTrustDevicePostureRuleInputLocations {
    /**
    * List of paths to check for client certificate rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#paths ZeroTrustDevicePostureRule#paths}
    */
    readonly paths?: string[];
    /**
    * List of trust stores to check for client certificate rule. Available values: `system`, `user`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#trust_stores ZeroTrustDevicePostureRule#trust_stores}
    */
    readonly trustStores?: string[];
}
export declare function zeroTrustDevicePostureRuleInputLocationsToTerraform(struct?: ZeroTrustDevicePostureRuleInputLocations | cdktf.IResolvable): any;
export declare function zeroTrustDevicePostureRuleInputLocationsToHclTerraform(struct?: ZeroTrustDevicePostureRuleInputLocations | cdktf.IResolvable): any;
export declare class ZeroTrustDevicePostureRuleInputLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustDevicePostureRuleInputLocations | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustDevicePostureRuleInputLocations | cdktf.IResolvable | undefined);
    private _paths?;
    get paths(): string[];
    set paths(value: string[]);
    resetPaths(): void;
    get pathsInput(): string[] | undefined;
    private _trustStores?;
    get trustStores(): string[];
    set trustStores(value: string[]);
    resetTrustStores(): void;
    get trustStoresInput(): string[] | undefined;
}
export declare class ZeroTrustDevicePostureRuleInputLocationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustDevicePostureRuleInputLocations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustDevicePostureRuleInputLocationsOutputReference;
}
export interface ZeroTrustDevicePostureRuleInput {
    /**
    * The number of active threats from SentinelOne.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#active_threats ZeroTrustDevicePostureRule#active_threats}
    */
    readonly activeThreats?: number;
    /**
    * The UUID of a Cloudflare managed certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#certificate_id ZeroTrustDevicePostureRule#certificate_id}
    */
    readonly certificateId?: string;
    /**
    * Specific volume(s) to check for encryption.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#check_disks ZeroTrustDevicePostureRule#check_disks}
    */
    readonly checkDisks?: string[];
    /**
    * Confirm the certificate was not imported from another device.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#check_private_key ZeroTrustDevicePostureRule#check_private_key}
    */
    readonly checkPrivateKey?: boolean | cdktf.IResolvable;
    /**
    * The common name for a certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#cn ZeroTrustDevicePostureRule#cn}
    */
    readonly cn?: string;
    /**
    * The workspace one or intune device compliance status. `compliant` and `noncompliant` are values supported by both providers. `unknown`, `conflict`, `error`, `ingraceperiod` values are only supported by intune. Available values: `compliant`, `noncompliant`, `unknown`, `conflict`, `error`, `ingraceperiod`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#compliance_status ZeroTrustDevicePostureRule#compliance_status}
    */
    readonly complianceStatus?: string;
    /**
    * The workspace one or intune connection id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#connection_id ZeroTrustDevicePostureRule#connection_id}
    */
    readonly connectionId?: string;
    /**
    * The count comparison operator for kolide. Available values: `>`, `>=`, `<`, `<=`, `==`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#count_operator ZeroTrustDevicePostureRule#count_operator}
    */
    readonly countOperator?: string;
    /**
    * The domain that the client must join.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#domain ZeroTrustDevicePostureRule#domain}
    */
    readonly domain?: string;
    /**
    * The time a device last seen in Tanium. Must be in the format `1h` or `30m`. Valid units are `d`, `h` and `m`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#eid_last_seen ZeroTrustDevicePostureRule#eid_last_seen}
    */
    readonly eidLastSeen?: string;
    /**
    * True if the firewall must be enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#enabled ZeroTrustDevicePostureRule#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Checks if the file should exist.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#exists ZeroTrustDevicePostureRule#exists}
    */
    readonly exists?: boolean | cdktf.IResolvable;
    /**
    * List of values indicating purposes for which the certificate public key can be used. Available values: `clientAuth`, `emailProtection`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#extended_key_usage ZeroTrustDevicePostureRule#extended_key_usage}
    */
    readonly extendedKeyUsage?: string[];
    /**
    * The Teams List id. Required for `serial_number` and `unique_client_id` rule types.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#id ZeroTrustDevicePostureRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * True if SentinelOne device is infected.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#infected ZeroTrustDevicePostureRule#infected}
    */
    readonly infected?: boolean | cdktf.IResolvable;
    /**
    * True if SentinelOne device is active.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#is_active ZeroTrustDevicePostureRule#is_active}
    */
    readonly isActive?: boolean | cdktf.IResolvable;
    /**
    * The number of issues for kolide.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#issue_count ZeroTrustDevicePostureRule#issue_count}
    */
    readonly issueCount?: string;
    /**
    * The duration of time that the host was last seen from Crowdstrike. Must be in the format `1h` or `30m`. Valid units are `d`, `h` and `m`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#last_seen ZeroTrustDevicePostureRule#last_seen}
    */
    readonly lastSeen?: string;
    /**
    * The network status from SentinelOne. Available values: `connected`, `disconnected`, `disconnecting`, `connecting`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#network_status ZeroTrustDevicePostureRule#network_status}
    */
    readonly networkStatus?: string;
    /**
    * The current operational state of a SentinelOne Agent. Available values: `na`, `partially_disabled`, `auto_fully_disabled`, `fully_disabled`, `auto_partially_disabled`, `disabled_error`, `db_corruption`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#operational_state ZeroTrustDevicePostureRule#operational_state}
    */
    readonly operationalState?: string;
    /**
    * The version comparison operator. Available values: `>`, `>=`, `<`, `<=`, `==`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#operator ZeroTrustDevicePostureRule#operator}
    */
    readonly operator?: string;
    /**
    * OS signal score from Crowdstrike. Value must be between 1 and 100.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#os ZeroTrustDevicePostureRule#os}
    */
    readonly os?: string;
    /**
    * The operating system excluding version information.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#os_distro_name ZeroTrustDevicePostureRule#os_distro_name}
    */
    readonly osDistroName?: string;
    /**
    * The operating system version excluding OS name information or release name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#os_distro_revision ZeroTrustDevicePostureRule#os_distro_revision}
    */
    readonly osDistroRevision?: string;
    /**
    * Extra version value following the operating system semantic version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#os_version_extra ZeroTrustDevicePostureRule#os_version_extra}
    */
    readonly osVersionExtra?: string;
    /**
    * Overall ZTA score from Crowdstrike. Value must be between 1 and 100.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#overall ZeroTrustDevicePostureRule#overall}
    */
    readonly overall?: string;
    /**
    * The path to the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#path ZeroTrustDevicePostureRule#path}
    */
    readonly path?: string;
    /**
    * True if all drives must be encrypted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#require_all ZeroTrustDevicePostureRule#require_all}
    */
    readonly requireAll?: boolean | cdktf.IResolvable;
    /**
    * The risk level from Tanium. Available values: `low`, `medium`, `high`, `critical`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#risk_level ZeroTrustDevicePostureRule#risk_level}
    */
    readonly riskLevel?: string;
    /**
    * Checks if the application should be running.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#running ZeroTrustDevicePostureRule#running}
    */
    readonly running?: boolean | cdktf.IResolvable;
    /**
    * A value between 0-100 assigned to devices set by the 3rd party posture provider for custom device posture integrations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#score ZeroTrustDevicePostureRule#score}
    */
    readonly score?: number;
    /**
    * Sensor signal score from Crowdstrike. Value must be between 1 and 100.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#sensor_config ZeroTrustDevicePostureRule#sensor_config}
    */
    readonly sensorConfig?: string;
    /**
    * The sha256 hash of the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#sha256 ZeroTrustDevicePostureRule#sha256}
    */
    readonly sha256?: string;
    /**
    * The host’s current online status from Crowdstrike. Available values: `online`, `offline`, `unknown`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#state ZeroTrustDevicePostureRule#state}
    */
    readonly state?: string;
    /**
    * The thumbprint of the file certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#thumbprint ZeroTrustDevicePostureRule#thumbprint}
    */
    readonly thumbprint?: string;
    /**
    * The total score from Tanium.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#total_score ZeroTrustDevicePostureRule#total_score}
    */
    readonly totalScore?: number;
    /**
    * The operating system semantic version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#version ZeroTrustDevicePostureRule#version}
    */
    readonly version?: string;
    /**
    * The version comparison operator for Crowdstrike. Available values: `>`, `>=`, `<`, `<=`, `==`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#version_operator ZeroTrustDevicePostureRule#version_operator}
    */
    readonly versionOperator?: string;
    /**
    * locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#locations ZeroTrustDevicePostureRule#locations}
    */
    readonly locations?: ZeroTrustDevicePostureRuleInputLocations[] | cdktf.IResolvable;
}
export declare function zeroTrustDevicePostureRuleInputToTerraform(struct?: ZeroTrustDevicePostureRuleInput | cdktf.IResolvable): any;
export declare function zeroTrustDevicePostureRuleInputToHclTerraform(struct?: ZeroTrustDevicePostureRuleInput | cdktf.IResolvable): any;
export declare class ZeroTrustDevicePostureRuleInputOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustDevicePostureRuleInput | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustDevicePostureRuleInput | cdktf.IResolvable | undefined);
    private _activeThreats?;
    get activeThreats(): number;
    set activeThreats(value: number);
    resetActiveThreats(): void;
    get activeThreatsInput(): number | undefined;
    private _certificateId?;
    get certificateId(): string;
    set certificateId(value: string);
    resetCertificateId(): void;
    get certificateIdInput(): string | undefined;
    private _checkDisks?;
    get checkDisks(): string[];
    set checkDisks(value: string[]);
    resetCheckDisks(): void;
    get checkDisksInput(): string[] | undefined;
    private _checkPrivateKey?;
    get checkPrivateKey(): boolean | cdktf.IResolvable;
    set checkPrivateKey(value: boolean | cdktf.IResolvable);
    resetCheckPrivateKey(): void;
    get checkPrivateKeyInput(): boolean | cdktf.IResolvable | undefined;
    private _cn?;
    get cn(): string;
    set cn(value: string);
    resetCn(): void;
    get cnInput(): string | undefined;
    private _complianceStatus?;
    get complianceStatus(): string;
    set complianceStatus(value: string);
    resetComplianceStatus(): void;
    get complianceStatusInput(): string | undefined;
    private _connectionId?;
    get connectionId(): string;
    set connectionId(value: string);
    resetConnectionId(): void;
    get connectionIdInput(): string | undefined;
    private _countOperator?;
    get countOperator(): string;
    set countOperator(value: string);
    resetCountOperator(): void;
    get countOperatorInput(): string | undefined;
    private _domain?;
    get domain(): string;
    set domain(value: string);
    resetDomain(): void;
    get domainInput(): string | undefined;
    private _eidLastSeen?;
    get eidLastSeen(): string;
    set eidLastSeen(value: string);
    resetEidLastSeen(): void;
    get eidLastSeenInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _exists?;
    get exists(): boolean | cdktf.IResolvable;
    set exists(value: boolean | cdktf.IResolvable);
    resetExists(): void;
    get existsInput(): boolean | cdktf.IResolvable | undefined;
    private _extendedKeyUsage?;
    get extendedKeyUsage(): string[];
    set extendedKeyUsage(value: string[]);
    resetExtendedKeyUsage(): void;
    get extendedKeyUsageInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _infected?;
    get infected(): boolean | cdktf.IResolvable;
    set infected(value: boolean | cdktf.IResolvable);
    resetInfected(): void;
    get infectedInput(): boolean | cdktf.IResolvable | undefined;
    private _isActive?;
    get isActive(): boolean | cdktf.IResolvable;
    set isActive(value: boolean | cdktf.IResolvable);
    resetIsActive(): void;
    get isActiveInput(): boolean | cdktf.IResolvable | undefined;
    private _issueCount?;
    get issueCount(): string;
    set issueCount(value: string);
    resetIssueCount(): void;
    get issueCountInput(): string | undefined;
    private _lastSeen?;
    get lastSeen(): string;
    set lastSeen(value: string);
    resetLastSeen(): void;
    get lastSeenInput(): string | undefined;
    private _networkStatus?;
    get networkStatus(): string;
    set networkStatus(value: string);
    resetNetworkStatus(): void;
    get networkStatusInput(): string | undefined;
    private _operationalState?;
    get operationalState(): string;
    set operationalState(value: string);
    resetOperationalState(): void;
    get operationalStateInput(): string | undefined;
    private _operator?;
    get operator(): string;
    set operator(value: string);
    resetOperator(): void;
    get operatorInput(): string | undefined;
    private _os?;
    get os(): string;
    set os(value: string);
    resetOs(): void;
    get osInput(): string | undefined;
    private _osDistroName?;
    get osDistroName(): string;
    set osDistroName(value: string);
    resetOsDistroName(): void;
    get osDistroNameInput(): string | undefined;
    private _osDistroRevision?;
    get osDistroRevision(): string;
    set osDistroRevision(value: string);
    resetOsDistroRevision(): void;
    get osDistroRevisionInput(): string | undefined;
    private _osVersionExtra?;
    get osVersionExtra(): string;
    set osVersionExtra(value: string);
    resetOsVersionExtra(): void;
    get osVersionExtraInput(): string | undefined;
    private _overall?;
    get overall(): string;
    set overall(value: string);
    resetOverall(): void;
    get overallInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _requireAll?;
    get requireAll(): boolean | cdktf.IResolvable;
    set requireAll(value: boolean | cdktf.IResolvable);
    resetRequireAll(): void;
    get requireAllInput(): boolean | cdktf.IResolvable | undefined;
    private _riskLevel?;
    get riskLevel(): string;
    set riskLevel(value: string);
    resetRiskLevel(): void;
    get riskLevelInput(): string | undefined;
    private _running?;
    get running(): boolean | cdktf.IResolvable;
    set running(value: boolean | cdktf.IResolvable);
    resetRunning(): void;
    get runningInput(): boolean | cdktf.IResolvable | undefined;
    private _score?;
    get score(): number;
    set score(value: number);
    resetScore(): void;
    get scoreInput(): number | undefined;
    private _sensorConfig?;
    get sensorConfig(): string;
    set sensorConfig(value: string);
    resetSensorConfig(): void;
    get sensorConfigInput(): string | undefined;
    private _sha256?;
    get sha256(): string;
    set sha256(value: string);
    resetSha256(): void;
    get sha256Input(): string | undefined;
    private _state?;
    get state(): string;
    set state(value: string);
    resetState(): void;
    get stateInput(): string | undefined;
    private _thumbprint?;
    get thumbprint(): string;
    set thumbprint(value: string);
    resetThumbprint(): void;
    get thumbprintInput(): string | undefined;
    private _totalScore?;
    get totalScore(): number;
    set totalScore(value: number);
    resetTotalScore(): void;
    get totalScoreInput(): number | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _versionOperator?;
    get versionOperator(): string;
    set versionOperator(value: string);
    resetVersionOperator(): void;
    get versionOperatorInput(): string | undefined;
    private _locations;
    get locations(): ZeroTrustDevicePostureRuleInputLocationsList;
    putLocations(value: ZeroTrustDevicePostureRuleInputLocations[] | cdktf.IResolvable): void;
    resetLocations(): void;
    get locationsInput(): cdktf.IResolvable | ZeroTrustDevicePostureRuleInputLocations[] | undefined;
}
export declare class ZeroTrustDevicePostureRuleInputList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustDevicePostureRuleInput[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustDevicePostureRuleInputOutputReference;
}
export interface ZeroTrustDevicePostureRuleMatch {
    /**
    * The platform of the device. Available values: `windows`, `mac`, `linux`, `android`, `ios`, `chromeos`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#platform ZeroTrustDevicePostureRule#platform}
    */
    readonly platform?: string;
}
export declare function zeroTrustDevicePostureRuleMatchToTerraform(struct?: ZeroTrustDevicePostureRuleMatch | cdktf.IResolvable): any;
export declare function zeroTrustDevicePostureRuleMatchToHclTerraform(struct?: ZeroTrustDevicePostureRuleMatch | cdktf.IResolvable): any;
export declare class ZeroTrustDevicePostureRuleMatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustDevicePostureRuleMatch | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustDevicePostureRuleMatch | cdktf.IResolvable | undefined);
    private _platform?;
    get platform(): string;
    set platform(value: string);
    resetPlatform(): void;
    get platformInput(): string | undefined;
}
export declare class ZeroTrustDevicePostureRuleMatchList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustDevicePostureRuleMatch[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustDevicePostureRuleMatchOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule cloudflare_zero_trust_device_posture_rule}
*/
export declare class ZeroTrustDevicePostureRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_device_posture_rule";
    /**
    * Generates CDKTF code for importing a ZeroTrustDevicePostureRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustDevicePostureRule to import
    * @param importFromId The id of the existing ZeroTrustDevicePostureRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustDevicePostureRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_device_posture_rule cloudflare_zero_trust_device_posture_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustDevicePostureRuleConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustDevicePostureRuleConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expiration?;
    get expiration(): string;
    set expiration(value: string);
    resetExpiration(): void;
    get expirationInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _schedule?;
    get schedule(): string;
    set schedule(value: string);
    resetSchedule(): void;
    get scheduleInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _input;
    get input(): ZeroTrustDevicePostureRuleInputList;
    putInput(value: ZeroTrustDevicePostureRuleInput[] | cdktf.IResolvable): void;
    resetInput(): void;
    get inputInput(): cdktf.IResolvable | ZeroTrustDevicePostureRuleInput[] | undefined;
    private _match;
    get match(): ZeroTrustDevicePostureRuleMatchList;
    putMatch(value: ZeroTrustDevicePostureRuleMatch[] | cdktf.IResolvable): void;
    resetMatch(): void;
    get matchInput(): cdktf.IResolvable | ZeroTrustDevicePostureRuleMatch[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
