/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustDlpProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#account_id ZeroTrustDlpProfile#account_id}
    */
    readonly accountId: string;
    /**
    * Related DLP policies will trigger when the match count exceeds the number set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#allowed_match_count ZeroTrustDlpProfile#allowed_match_count}
    */
    readonly allowedMatchCount: number;
    /**
    * Brief summary of the profile and its intended use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#description ZeroTrustDlpProfile#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#id ZeroTrustDlpProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the profile. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#name ZeroTrustDlpProfile#name}
    */
    readonly name: string;
    /**
    * If true, scan images via OCR to determine if any text present matches filters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#ocr_enabled ZeroTrustDlpProfile#ocr_enabled}
    */
    readonly ocrEnabled?: boolean | cdktf.IResolvable;
    /**
    * The type of the profile. Available values: `custom`, `predefined`. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#type ZeroTrustDlpProfile#type}
    */
    readonly type: string;
    /**
    * context_awareness block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#context_awareness ZeroTrustDlpProfile#context_awareness}
    */
    readonly contextAwareness?: ZeroTrustDlpProfileContextAwareness;
    /**
    * entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#entry ZeroTrustDlpProfile#entry}
    */
    readonly entry: ZeroTrustDlpProfileEntry[] | cdktf.IResolvable;
}
export interface ZeroTrustDlpProfileContextAwarenessSkip {
    /**
    * Return all matches, regardless of context analysis result, if the data is a file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#files ZeroTrustDlpProfile#files}
    */
    readonly files: boolean | cdktf.IResolvable;
}
export declare function zeroTrustDlpProfileContextAwarenessSkipToTerraform(struct?: ZeroTrustDlpProfileContextAwarenessSkipOutputReference | ZeroTrustDlpProfileContextAwarenessSkip): any;
export declare function zeroTrustDlpProfileContextAwarenessSkipToHclTerraform(struct?: ZeroTrustDlpProfileContextAwarenessSkipOutputReference | ZeroTrustDlpProfileContextAwarenessSkip): any;
export declare class ZeroTrustDlpProfileContextAwarenessSkipOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustDlpProfileContextAwarenessSkip | undefined;
    set internalValue(value: ZeroTrustDlpProfileContextAwarenessSkip | undefined);
    private _files?;
    get files(): boolean | cdktf.IResolvable;
    set files(value: boolean | cdktf.IResolvable);
    get filesInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustDlpProfileContextAwareness {
    /**
    * Scan the context of predefined entries to only return matches surrounded by keywords.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#enabled ZeroTrustDlpProfile#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * skip block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#skip ZeroTrustDlpProfile#skip}
    */
    readonly skip: ZeroTrustDlpProfileContextAwarenessSkip;
}
export declare function zeroTrustDlpProfileContextAwarenessToTerraform(struct?: ZeroTrustDlpProfileContextAwarenessOutputReference | ZeroTrustDlpProfileContextAwareness): any;
export declare function zeroTrustDlpProfileContextAwarenessToHclTerraform(struct?: ZeroTrustDlpProfileContextAwarenessOutputReference | ZeroTrustDlpProfileContextAwareness): any;
export declare class ZeroTrustDlpProfileContextAwarenessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustDlpProfileContextAwareness | undefined;
    set internalValue(value: ZeroTrustDlpProfileContextAwareness | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _skip;
    get skip(): ZeroTrustDlpProfileContextAwarenessSkipOutputReference;
    putSkip(value: ZeroTrustDlpProfileContextAwarenessSkip): void;
    get skipInput(): ZeroTrustDlpProfileContextAwarenessSkip | undefined;
}
export interface ZeroTrustDlpProfileEntryPattern {
    /**
    * The regex that defines the pattern.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#regex ZeroTrustDlpProfile#regex}
    */
    readonly regex: string;
    /**
    * The validation algorithm to apply with this pattern.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#validation ZeroTrustDlpProfile#validation}
    */
    readonly validation?: string;
}
export declare function zeroTrustDlpProfileEntryPatternToTerraform(struct?: ZeroTrustDlpProfileEntryPatternOutputReference | ZeroTrustDlpProfileEntryPattern): any;
export declare function zeroTrustDlpProfileEntryPatternToHclTerraform(struct?: ZeroTrustDlpProfileEntryPatternOutputReference | ZeroTrustDlpProfileEntryPattern): any;
export declare class ZeroTrustDlpProfileEntryPatternOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustDlpProfileEntryPattern | undefined;
    set internalValue(value: ZeroTrustDlpProfileEntryPattern | undefined);
    private _regex?;
    get regex(): string;
    set regex(value: string);
    get regexInput(): string | undefined;
    private _validation?;
    get validation(): string;
    set validation(value: string);
    resetValidation(): void;
    get validationInput(): string | undefined;
}
export interface ZeroTrustDlpProfileEntry {
    /**
    * Whether the entry is active. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#enabled ZeroTrustDlpProfile#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Unique entry identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#id ZeroTrustDlpProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the entry to deploy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#name ZeroTrustDlpProfile#name}
    */
    readonly name: string;
    /**
    * pattern block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#pattern ZeroTrustDlpProfile#pattern}
    */
    readonly pattern?: ZeroTrustDlpProfileEntryPattern;
}
export declare function zeroTrustDlpProfileEntryToTerraform(struct?: ZeroTrustDlpProfileEntry | cdktf.IResolvable): any;
export declare function zeroTrustDlpProfileEntryToHclTerraform(struct?: ZeroTrustDlpProfileEntry | cdktf.IResolvable): any;
export declare class ZeroTrustDlpProfileEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustDlpProfileEntry | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustDlpProfileEntry | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _pattern;
    get pattern(): ZeroTrustDlpProfileEntryPatternOutputReference;
    putPattern(value: ZeroTrustDlpProfileEntryPattern): void;
    resetPattern(): void;
    get patternInput(): ZeroTrustDlpProfileEntryPattern | undefined;
}
export declare class ZeroTrustDlpProfileEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustDlpProfileEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustDlpProfileEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile cloudflare_zero_trust_dlp_profile}
*/
export declare class ZeroTrustDlpProfile extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_dlp_profile";
    /**
    * Generates CDKTF code for importing a ZeroTrustDlpProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustDlpProfile to import
    * @param importFromId The id of the existing ZeroTrustDlpProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustDlpProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_dlp_profile cloudflare_zero_trust_dlp_profile} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustDlpProfileConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustDlpProfileConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _allowedMatchCount?;
    get allowedMatchCount(): number;
    set allowedMatchCount(value: number);
    get allowedMatchCountInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _ocrEnabled?;
    get ocrEnabled(): boolean | cdktf.IResolvable;
    set ocrEnabled(value: boolean | cdktf.IResolvable);
    resetOcrEnabled(): void;
    get ocrEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _contextAwareness;
    get contextAwareness(): ZeroTrustDlpProfileContextAwarenessOutputReference;
    putContextAwareness(value: ZeroTrustDlpProfileContextAwareness): void;
    resetContextAwareness(): void;
    get contextAwarenessInput(): ZeroTrustDlpProfileContextAwareness | undefined;
    private _entry;
    get entry(): ZeroTrustDlpProfileEntryList;
    putEntry(value: ZeroTrustDlpProfileEntry[] | cdktf.IResolvable): void;
    get entryInput(): cdktf.IResolvable | ZeroTrustDlpProfileEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
