/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustGatewayPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#account_id ZeroTrustGatewayPolicy#account_id}
    */
    readonly accountId: string;
    /**
    * The action executed by matched teams rule. Available values: `allow`, `block`, `safesearch`, `ytrestricted`, `on`, `off`, `scan`, `noscan`, `isolate`, `noisolate`, `override`, `l4_override`, `egress`, `audit_ssh`, `resolve`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#action ZeroTrustGatewayPolicy#action}
    */
    readonly action: string;
    /**
    * The description of the teams rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#description ZeroTrustGatewayPolicy#description}
    */
    readonly description: string;
    /**
    * The wirefilter expression to be used for device_posture check matching.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#device_posture ZeroTrustGatewayPolicy#device_posture}
    */
    readonly devicePosture?: string;
    /**
    * Indicator of rule enablement.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#enabled ZeroTrustGatewayPolicy#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * The protocol or layer to evaluate the traffic and identity expressions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#filters ZeroTrustGatewayPolicy#filters}
    */
    readonly filters?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#id ZeroTrustGatewayPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The wirefilter expression to be used for identity matching.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#identity ZeroTrustGatewayPolicy#identity}
    */
    readonly identity?: string;
    /**
    * The name of the teams rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#name ZeroTrustGatewayPolicy#name}
    */
    readonly name: string;
    /**
    * The evaluation precedence of the teams rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#precedence ZeroTrustGatewayPolicy#precedence}
    */
    readonly precedence: number;
    /**
    * The wirefilter expression to be used for traffic matching.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#traffic ZeroTrustGatewayPolicy#traffic}
    */
    readonly traffic?: string;
    /**
    * rule_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#rule_settings ZeroTrustGatewayPolicy#rule_settings}
    */
    readonly ruleSettings?: ZeroTrustGatewayPolicyRuleSettings;
}
export interface ZeroTrustGatewayPolicyRuleSettingsAuditSsh {
    /**
    * Log all SSH commands.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#command_logging ZeroTrustGatewayPolicy#command_logging}
    */
    readonly commandLogging: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsAuditSshToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsAuditSshOutputReference | ZeroTrustGatewayPolicyRuleSettingsAuditSsh): any;
export declare function zeroTrustGatewayPolicyRuleSettingsAuditSshToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsAuditSshOutputReference | ZeroTrustGatewayPolicyRuleSettingsAuditSsh): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsAuditSshOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsAuditSsh | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsAuditSsh | undefined);
    private _commandLogging?;
    get commandLogging(): boolean | cdktf.IResolvable;
    set commandLogging(value: boolean | cdktf.IResolvable);
    get commandLoggingInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls {
    /**
    * Disable clipboard redirection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#disable_clipboard_redirection ZeroTrustGatewayPolicy#disable_clipboard_redirection}
    */
    readonly disableClipboardRedirection?: boolean | cdktf.IResolvable;
    /**
    * Disable copy-paste.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#disable_copy_paste ZeroTrustGatewayPolicy#disable_copy_paste}
    */
    readonly disableCopyPaste?: boolean | cdktf.IResolvable;
    /**
    * Disable download.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#disable_download ZeroTrustGatewayPolicy#disable_download}
    */
    readonly disableDownload?: boolean | cdktf.IResolvable;
    /**
    * Disable keyboard usage.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#disable_keyboard ZeroTrustGatewayPolicy#disable_keyboard}
    */
    readonly disableKeyboard?: boolean | cdktf.IResolvable;
    /**
    * Disable printing.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#disable_printing ZeroTrustGatewayPolicy#disable_printing}
    */
    readonly disablePrinting?: boolean | cdktf.IResolvable;
    /**
    * Disable upload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#disable_upload ZeroTrustGatewayPolicy#disable_upload}
    */
    readonly disableUpload?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsBisoAdminControlsToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControlsOutputReference | ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls): any;
export declare function zeroTrustGatewayPolicyRuleSettingsBisoAdminControlsToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControlsOutputReference | ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsBisoAdminControlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | undefined);
    private _disableClipboardRedirection?;
    get disableClipboardRedirection(): boolean | cdktf.IResolvable;
    set disableClipboardRedirection(value: boolean | cdktf.IResolvable);
    resetDisableClipboardRedirection(): void;
    get disableClipboardRedirectionInput(): boolean | cdktf.IResolvable | undefined;
    private _disableCopyPaste?;
    get disableCopyPaste(): boolean | cdktf.IResolvable;
    set disableCopyPaste(value: boolean | cdktf.IResolvable);
    resetDisableCopyPaste(): void;
    get disableCopyPasteInput(): boolean | cdktf.IResolvable | undefined;
    private _disableDownload?;
    get disableDownload(): boolean | cdktf.IResolvable;
    set disableDownload(value: boolean | cdktf.IResolvable);
    resetDisableDownload(): void;
    get disableDownloadInput(): boolean | cdktf.IResolvable | undefined;
    private _disableKeyboard?;
    get disableKeyboard(): boolean | cdktf.IResolvable;
    set disableKeyboard(value: boolean | cdktf.IResolvable);
    resetDisableKeyboard(): void;
    get disableKeyboardInput(): boolean | cdktf.IResolvable | undefined;
    private _disablePrinting?;
    get disablePrinting(): boolean | cdktf.IResolvable;
    set disablePrinting(value: boolean | cdktf.IResolvable);
    resetDisablePrinting(): void;
    get disablePrintingInput(): boolean | cdktf.IResolvable | undefined;
    private _disableUpload?;
    get disableUpload(): boolean | cdktf.IResolvable;
    set disableUpload(value: boolean | cdktf.IResolvable);
    resetDisableUpload(): void;
    get disableUploadInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsCheckSession {
    /**
    * Configure how fresh the session needs to be to be considered valid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#duration ZeroTrustGatewayPolicy#duration}
    */
    readonly duration: string;
    /**
    * Enable session enforcement for this rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#enforce ZeroTrustGatewayPolicy#enforce}
    */
    readonly enforce: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsCheckSessionToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsCheckSessionOutputReference | ZeroTrustGatewayPolicyRuleSettingsCheckSession): any;
export declare function zeroTrustGatewayPolicyRuleSettingsCheckSessionToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsCheckSessionOutputReference | ZeroTrustGatewayPolicyRuleSettingsCheckSession): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsCheckSessionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsCheckSession | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsCheckSession | undefined);
    private _duration?;
    get duration(): string;
    set duration(value: string);
    get durationInput(): string | undefined;
    private _enforce?;
    get enforce(): boolean | cdktf.IResolvable;
    set enforce(value: boolean | cdktf.IResolvable);
    get enforceInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 {
    /**
    * The IPv4 or IPv6 address of the upstream resolver.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ip ZeroTrustGatewayPolicy#ip}
    */
    readonly ip: string;
    /**
    * A port number to use for the upstream resolver. Defaults to `53`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#port ZeroTrustGatewayPolicy#port}
    */
    readonly port?: number;
    /**
    * Whether to connect to this resolver over a private network. Must be set when `vnet_id` is set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#route_through_private_network ZeroTrustGatewayPolicy#route_through_private_network}
    */
    readonly routeThroughPrivateNetwork?: boolean | cdktf.IResolvable;
    /**
    * specify a virtual network for this resolver. Uses default virtual network id if omitted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#vnet_id ZeroTrustGatewayPolicy#vnet_id}
    */
    readonly vnetId?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4ToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4ToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4 | cdktf.IResolvable | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _routeThroughPrivateNetwork?;
    get routeThroughPrivateNetwork(): boolean | cdktf.IResolvable;
    set routeThroughPrivateNetwork(value: boolean | cdktf.IResolvable);
    resetRouteThroughPrivateNetwork(): void;
    get routeThroughPrivateNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _vnetId?;
    get vnetId(): string;
    set vnetId(value: string);
    resetVnetId(): void;
    get vnetIdInput(): string | undefined;
}
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4List extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4OutputReference;
}
export interface ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 {
    /**
    * The IPv4 or IPv6 address of the upstream resolver.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ip ZeroTrustGatewayPolicy#ip}
    */
    readonly ip: string;
    /**
    * A port number to use for the upstream resolver. Defaults to `53`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#port ZeroTrustGatewayPolicy#port}
    */
    readonly port?: number;
    /**
    * Whether to connect to this resolver over a private network. Must be set when `vnet_id` is set.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#route_through_private_network ZeroTrustGatewayPolicy#route_through_private_network}
    */
    readonly routeThroughPrivateNetwork?: boolean | cdktf.IResolvable;
    /**
    * specify a virtual network for this resolver. Uses default virtual network id if omitted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#vnet_id ZeroTrustGatewayPolicy#vnet_id}
    */
    readonly vnetId?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6ToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable): any;
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6ToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6 | cdktf.IResolvable | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _routeThroughPrivateNetwork?;
    get routeThroughPrivateNetwork(): boolean | cdktf.IResolvable;
    set routeThroughPrivateNetwork(value: boolean | cdktf.IResolvable);
    resetRouteThroughPrivateNetwork(): void;
    get routeThroughPrivateNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _vnetId?;
    get vnetId(): string;
    set vnetId(value: string);
    resetVnetId(): void;
    get vnetIdInput(): string | undefined;
}
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6List extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6OutputReference;
}
export interface ZeroTrustGatewayPolicyRuleSettingsDnsResolvers {
    /**
    * ipv4 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ipv4 ZeroTrustGatewayPolicy#ipv4}
    */
    readonly ipv4?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | cdktf.IResolvable;
    /**
    * ipv6 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ipv6 ZeroTrustGatewayPolicy#ipv6}
    */
    readonly ipv6?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversOutputReference | ZeroTrustGatewayPolicyRuleSettingsDnsResolvers): any;
export declare function zeroTrustGatewayPolicyRuleSettingsDnsResolversToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsDnsResolversOutputReference | ZeroTrustGatewayPolicyRuleSettingsDnsResolvers): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsDnsResolversOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | undefined);
    private _ipv4;
    get ipv4(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4List;
    putIpv4(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | cdktf.IResolvable): void;
    resetIpv4(): void;
    get ipv4Input(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv4[] | undefined;
    private _ipv6;
    get ipv6(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6List;
    putIpv6(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | cdktf.IResolvable): void;
    resetIpv6(): void;
    get ipv6Input(): cdktf.IResolvable | ZeroTrustGatewayPolicyRuleSettingsDnsResolversIpv6[] | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsEgress {
    /**
    * The IPv4 address to be used for egress.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ipv4 ZeroTrustGatewayPolicy#ipv4}
    */
    readonly ipv4: string;
    /**
    * The IPv4 address to be used for egress in the event of an error egressing with the primary IPv4. Can be '0.0.0.0' to indicate local egreass via Warp IPs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ipv4_fallback ZeroTrustGatewayPolicy#ipv4_fallback}
    */
    readonly ipv4Fallback?: string;
    /**
    * The IPv6 range to be used for egress.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ipv6 ZeroTrustGatewayPolicy#ipv6}
    */
    readonly ipv6: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsEgressToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsEgressOutputReference | ZeroTrustGatewayPolicyRuleSettingsEgress): any;
export declare function zeroTrustGatewayPolicyRuleSettingsEgressToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsEgressOutputReference | ZeroTrustGatewayPolicyRuleSettingsEgress): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsEgressOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsEgress | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsEgress | undefined);
    private _ipv4?;
    get ipv4(): string;
    set ipv4(value: string);
    get ipv4Input(): string | undefined;
    private _ipv4Fallback?;
    get ipv4Fallback(): string;
    set ipv4Fallback(value: string);
    resetIpv4Fallback(): void;
    get ipv4FallbackInput(): string | undefined;
    private _ipv6?;
    get ipv6(): string;
    set ipv6(value: string);
    get ipv6Input(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsL4Override {
    /**
    * Override IP to forward traffic to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ip ZeroTrustGatewayPolicy#ip}
    */
    readonly ip: string;
    /**
    * Override Port to forward traffic to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#port ZeroTrustGatewayPolicy#port}
    */
    readonly port: number;
}
export declare function zeroTrustGatewayPolicyRuleSettingsL4OverrideToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsL4OverrideOutputReference | ZeroTrustGatewayPolicyRuleSettingsL4Override): any;
export declare function zeroTrustGatewayPolicyRuleSettingsL4OverrideToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsL4OverrideOutputReference | ZeroTrustGatewayPolicyRuleSettingsL4Override): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsL4OverrideOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsL4Override | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsL4Override | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsNotificationSettings {
    /**
    * Enable notification settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#enabled ZeroTrustGatewayPolicy#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Notification content.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#message ZeroTrustGatewayPolicy#message}
    */
    readonly message?: string;
    /**
    * Support URL to show in the notification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#support_url ZeroTrustGatewayPolicy#support_url}
    */
    readonly supportUrl?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsNotificationSettingsToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsNotificationSettingsOutputReference | ZeroTrustGatewayPolicyRuleSettingsNotificationSettings): any;
export declare function zeroTrustGatewayPolicyRuleSettingsNotificationSettingsToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsNotificationSettingsOutputReference | ZeroTrustGatewayPolicyRuleSettingsNotificationSettings): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsNotificationSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _message?;
    get message(): string;
    set message(value: string);
    resetMessage(): void;
    get messageInput(): string | undefined;
    private _supportUrl?;
    get supportUrl(): string;
    set supportUrl(value: string);
    resetSupportUrl(): void;
    get supportUrlInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsPayloadLog {
    /**
    * Enable or disable DLP Payload Logging for this rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#enabled ZeroTrustGatewayPolicy#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewayPolicyRuleSettingsPayloadLogToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsPayloadLogOutputReference | ZeroTrustGatewayPolicyRuleSettingsPayloadLog): any;
export declare function zeroTrustGatewayPolicyRuleSettingsPayloadLogToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsPayloadLogOutputReference | ZeroTrustGatewayPolicyRuleSettingsPayloadLog): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsPayloadLogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsPayloadLog | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsPayloadLog | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettingsUntrustedCert {
    /**
    * Action to be taken when the SSL certificate of upstream is invalid. Available values: `pass_through`, `block`, `error`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#action ZeroTrustGatewayPolicy#action}
    */
    readonly action?: string;
}
export declare function zeroTrustGatewayPolicyRuleSettingsUntrustedCertToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsUntrustedCertOutputReference | ZeroTrustGatewayPolicyRuleSettingsUntrustedCert): any;
export declare function zeroTrustGatewayPolicyRuleSettingsUntrustedCertToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsUntrustedCertOutputReference | ZeroTrustGatewayPolicyRuleSettingsUntrustedCert): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsUntrustedCertOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
}
export interface ZeroTrustGatewayPolicyRuleSettings {
    /**
    * Add custom headers to allowed requests in the form of key-value pairs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#add_headers ZeroTrustGatewayPolicy#add_headers}
    */
    readonly addHeaders?: {
        [key: string]: string;
    };
    /**
    * Allow parent MSP accounts to enable bypass their children's rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#allow_child_bypass ZeroTrustGatewayPolicy#allow_child_bypass}
    */
    readonly allowChildBypass?: boolean | cdktf.IResolvable;
    /**
    * Indicator of block page enablement.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#block_page_enabled ZeroTrustGatewayPolicy#block_page_enabled}
    */
    readonly blockPageEnabled?: boolean | cdktf.IResolvable;
    /**
    * The displayed reason for a user being blocked.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#block_page_reason ZeroTrustGatewayPolicy#block_page_reason}
    */
    readonly blockPageReason?: string;
    /**
    * Allow child MSP accounts to bypass their parent's rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#bypass_parent_rule ZeroTrustGatewayPolicy#bypass_parent_rule}
    */
    readonly bypassParentRule?: boolean | cdktf.IResolvable;
    /**
    * Set to true, to ignore the category matches at CNAME domains in a response.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ignore_cname_category_matches ZeroTrustGatewayPolicy#ignore_cname_category_matches}
    */
    readonly ignoreCnameCategoryMatches?: boolean | cdktf.IResolvable;
    /**
    * Disable DNSSEC validation (must be Allow rule).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#insecure_disable_dnssec_validation ZeroTrustGatewayPolicy#insecure_disable_dnssec_validation}
    */
    readonly insecureDisableDnssecValidation?: boolean | cdktf.IResolvable;
    /**
    * Turns on IP category based filter on dns if the rule contains dns category checks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#ip_categories ZeroTrustGatewayPolicy#ip_categories}
    */
    readonly ipCategories?: boolean | cdktf.IResolvable;
    /**
    * The host to override matching DNS queries with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#override_host ZeroTrustGatewayPolicy#override_host}
    */
    readonly overrideHost?: string;
    /**
    * The IPs to override matching DNS queries with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#override_ips ZeroTrustGatewayPolicy#override_ips}
    */
    readonly overrideIps?: string[];
    /**
    * Enable sending queries that match the resolver policy to Cloudflare's default 1.1.1.1 DNS resolver. Cannot be set when `dns_resolvers` are specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#resolve_dns_through_cloudflare ZeroTrustGatewayPolicy#resolve_dns_through_cloudflare}
    */
    readonly resolveDnsThroughCloudflare?: boolean | cdktf.IResolvable;
    /**
    * audit_ssh block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#audit_ssh ZeroTrustGatewayPolicy#audit_ssh}
    */
    readonly auditSsh?: ZeroTrustGatewayPolicyRuleSettingsAuditSsh;
    /**
    * biso_admin_controls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#biso_admin_controls ZeroTrustGatewayPolicy#biso_admin_controls}
    */
    readonly bisoAdminControls?: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls;
    /**
    * check_session block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#check_session ZeroTrustGatewayPolicy#check_session}
    */
    readonly checkSession?: ZeroTrustGatewayPolicyRuleSettingsCheckSession;
    /**
    * dns_resolvers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#dns_resolvers ZeroTrustGatewayPolicy#dns_resolvers}
    */
    readonly dnsResolvers?: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers;
    /**
    * egress block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#egress ZeroTrustGatewayPolicy#egress}
    */
    readonly egress?: ZeroTrustGatewayPolicyRuleSettingsEgress;
    /**
    * l4override block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#l4override ZeroTrustGatewayPolicy#l4override}
    */
    readonly l4Override?: ZeroTrustGatewayPolicyRuleSettingsL4Override;
    /**
    * notification_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#notification_settings ZeroTrustGatewayPolicy#notification_settings}
    */
    readonly notificationSettings?: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings;
    /**
    * payload_log block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#payload_log ZeroTrustGatewayPolicy#payload_log}
    */
    readonly payloadLog?: ZeroTrustGatewayPolicyRuleSettingsPayloadLog;
    /**
    * untrusted_cert block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#untrusted_cert ZeroTrustGatewayPolicy#untrusted_cert}
    */
    readonly untrustedCert?: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert;
}
export declare function zeroTrustGatewayPolicyRuleSettingsToTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsOutputReference | ZeroTrustGatewayPolicyRuleSettings): any;
export declare function zeroTrustGatewayPolicyRuleSettingsToHclTerraform(struct?: ZeroTrustGatewayPolicyRuleSettingsOutputReference | ZeroTrustGatewayPolicyRuleSettings): any;
export declare class ZeroTrustGatewayPolicyRuleSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewayPolicyRuleSettings | undefined;
    set internalValue(value: ZeroTrustGatewayPolicyRuleSettings | undefined);
    private _addHeaders?;
    get addHeaders(): {
        [key: string]: string;
    };
    set addHeaders(value: {
        [key: string]: string;
    });
    resetAddHeaders(): void;
    get addHeadersInput(): {
        [key: string]: string;
    } | undefined;
    private _allowChildBypass?;
    get allowChildBypass(): boolean | cdktf.IResolvable;
    set allowChildBypass(value: boolean | cdktf.IResolvable);
    resetAllowChildBypass(): void;
    get allowChildBypassInput(): boolean | cdktf.IResolvable | undefined;
    private _blockPageEnabled?;
    get blockPageEnabled(): boolean | cdktf.IResolvable;
    set blockPageEnabled(value: boolean | cdktf.IResolvable);
    resetBlockPageEnabled(): void;
    get blockPageEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _blockPageReason?;
    get blockPageReason(): string;
    set blockPageReason(value: string);
    resetBlockPageReason(): void;
    get blockPageReasonInput(): string | undefined;
    private _bypassParentRule?;
    get bypassParentRule(): boolean | cdktf.IResolvable;
    set bypassParentRule(value: boolean | cdktf.IResolvable);
    resetBypassParentRule(): void;
    get bypassParentRuleInput(): boolean | cdktf.IResolvable | undefined;
    private _ignoreCnameCategoryMatches?;
    get ignoreCnameCategoryMatches(): boolean | cdktf.IResolvable;
    set ignoreCnameCategoryMatches(value: boolean | cdktf.IResolvable);
    resetIgnoreCnameCategoryMatches(): void;
    get ignoreCnameCategoryMatchesInput(): boolean | cdktf.IResolvable | undefined;
    private _insecureDisableDnssecValidation?;
    get insecureDisableDnssecValidation(): boolean | cdktf.IResolvable;
    set insecureDisableDnssecValidation(value: boolean | cdktf.IResolvable);
    resetInsecureDisableDnssecValidation(): void;
    get insecureDisableDnssecValidationInput(): boolean | cdktf.IResolvable | undefined;
    private _ipCategories?;
    get ipCategories(): boolean | cdktf.IResolvable;
    set ipCategories(value: boolean | cdktf.IResolvable);
    resetIpCategories(): void;
    get ipCategoriesInput(): boolean | cdktf.IResolvable | undefined;
    private _overrideHost?;
    get overrideHost(): string;
    set overrideHost(value: string);
    resetOverrideHost(): void;
    get overrideHostInput(): string | undefined;
    private _overrideIps?;
    get overrideIps(): string[];
    set overrideIps(value: string[]);
    resetOverrideIps(): void;
    get overrideIpsInput(): string[] | undefined;
    private _resolveDnsThroughCloudflare?;
    get resolveDnsThroughCloudflare(): boolean | cdktf.IResolvable;
    set resolveDnsThroughCloudflare(value: boolean | cdktf.IResolvable);
    resetResolveDnsThroughCloudflare(): void;
    get resolveDnsThroughCloudflareInput(): boolean | cdktf.IResolvable | undefined;
    private _auditSsh;
    get auditSsh(): ZeroTrustGatewayPolicyRuleSettingsAuditSshOutputReference;
    putAuditSsh(value: ZeroTrustGatewayPolicyRuleSettingsAuditSsh): void;
    resetAuditSsh(): void;
    get auditSshInput(): ZeroTrustGatewayPolicyRuleSettingsAuditSsh | undefined;
    private _bisoAdminControls;
    get bisoAdminControls(): ZeroTrustGatewayPolicyRuleSettingsBisoAdminControlsOutputReference;
    putBisoAdminControls(value: ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls): void;
    resetBisoAdminControls(): void;
    get bisoAdminControlsInput(): ZeroTrustGatewayPolicyRuleSettingsBisoAdminControls | undefined;
    private _checkSession;
    get checkSession(): ZeroTrustGatewayPolicyRuleSettingsCheckSessionOutputReference;
    putCheckSession(value: ZeroTrustGatewayPolicyRuleSettingsCheckSession): void;
    resetCheckSession(): void;
    get checkSessionInput(): ZeroTrustGatewayPolicyRuleSettingsCheckSession | undefined;
    private _dnsResolvers;
    get dnsResolvers(): ZeroTrustGatewayPolicyRuleSettingsDnsResolversOutputReference;
    putDnsResolvers(value: ZeroTrustGatewayPolicyRuleSettingsDnsResolvers): void;
    resetDnsResolvers(): void;
    get dnsResolversInput(): ZeroTrustGatewayPolicyRuleSettingsDnsResolvers | undefined;
    private _egress;
    get egress(): ZeroTrustGatewayPolicyRuleSettingsEgressOutputReference;
    putEgress(value: ZeroTrustGatewayPolicyRuleSettingsEgress): void;
    resetEgress(): void;
    get egressInput(): ZeroTrustGatewayPolicyRuleSettingsEgress | undefined;
    private _l4Override;
    get l4Override(): ZeroTrustGatewayPolicyRuleSettingsL4OverrideOutputReference;
    putL4Override(value: ZeroTrustGatewayPolicyRuleSettingsL4Override): void;
    resetL4Override(): void;
    get l4OverrideInput(): ZeroTrustGatewayPolicyRuleSettingsL4Override | undefined;
    private _notificationSettings;
    get notificationSettings(): ZeroTrustGatewayPolicyRuleSettingsNotificationSettingsOutputReference;
    putNotificationSettings(value: ZeroTrustGatewayPolicyRuleSettingsNotificationSettings): void;
    resetNotificationSettings(): void;
    get notificationSettingsInput(): ZeroTrustGatewayPolicyRuleSettingsNotificationSettings | undefined;
    private _payloadLog;
    get payloadLog(): ZeroTrustGatewayPolicyRuleSettingsPayloadLogOutputReference;
    putPayloadLog(value: ZeroTrustGatewayPolicyRuleSettingsPayloadLog): void;
    resetPayloadLog(): void;
    get payloadLogInput(): ZeroTrustGatewayPolicyRuleSettingsPayloadLog | undefined;
    private _untrustedCert;
    get untrustedCert(): ZeroTrustGatewayPolicyRuleSettingsUntrustedCertOutputReference;
    putUntrustedCert(value: ZeroTrustGatewayPolicyRuleSettingsUntrustedCert): void;
    resetUntrustedCert(): void;
    get untrustedCertInput(): ZeroTrustGatewayPolicyRuleSettingsUntrustedCert | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy cloudflare_zero_trust_gateway_policy}
*/
export declare class ZeroTrustGatewayPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_gateway_policy";
    /**
    * Generates CDKTF code for importing a ZeroTrustGatewayPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustGatewayPolicy to import
    * @param importFromId The id of the existing ZeroTrustGatewayPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustGatewayPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_policy cloudflare_zero_trust_gateway_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustGatewayPolicyConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustGatewayPolicyConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _devicePosture?;
    get devicePosture(): string;
    set devicePosture(value: string);
    resetDevicePosture(): void;
    get devicePostureInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _filters?;
    get filters(): string[];
    set filters(value: string[]);
    resetFilters(): void;
    get filtersInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _identity?;
    get identity(): string;
    set identity(value: string);
    resetIdentity(): void;
    get identityInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _precedence?;
    get precedence(): number;
    set precedence(value: number);
    get precedenceInput(): number | undefined;
    private _traffic?;
    get traffic(): string;
    set traffic(value: string);
    resetTraffic(): void;
    get trafficInput(): string | undefined;
    get version(): number;
    private _ruleSettings;
    get ruleSettings(): ZeroTrustGatewayPolicyRuleSettingsOutputReference;
    putRuleSettings(value: ZeroTrustGatewayPolicyRuleSettings): void;
    resetRuleSettings(): void;
    get ruleSettingsInput(): ZeroTrustGatewayPolicyRuleSettings | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
