/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustGatewaySettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#account_id ZeroTrustGatewaySettings#account_id}
    */
    readonly accountId: string;
    /**
    * Whether to enable the activity log.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#activity_log_enabled ZeroTrustGatewaySettings#activity_log_enabled}
    */
    readonly activityLogEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#id ZeroTrustGatewaySettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Enable non-identity onramp for Browser Isolation. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#non_identity_browser_isolation_enabled ZeroTrustGatewaySettings#non_identity_browser_isolation_enabled}
    */
    readonly nonIdentityBrowserIsolationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Indicator that protocol detection is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#protocol_detection_enabled ZeroTrustGatewaySettings#protocol_detection_enabled}
    */
    readonly protocolDetectionEnabled?: boolean | cdktf.IResolvable;
    /**
    * Indicator that decryption of TLS traffic is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#tls_decrypt_enabled ZeroTrustGatewaySettings#tls_decrypt_enabled}
    */
    readonly tlsDecryptEnabled?: boolean | cdktf.IResolvable;
    /**
    * Safely browse websites in Browser Isolation through a URL. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#url_browser_isolation_enabled ZeroTrustGatewaySettings#url_browser_isolation_enabled}
    */
    readonly urlBrowserIsolationEnabled?: boolean | cdktf.IResolvable;
    /**
    * antivirus block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#antivirus ZeroTrustGatewaySettings#antivirus}
    */
    readonly antivirus?: ZeroTrustGatewaySettingsAntivirus;
    /**
    * block_page block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#block_page ZeroTrustGatewaySettings#block_page}
    */
    readonly blockPage?: ZeroTrustGatewaySettingsBlockPage;
    /**
    * body_scanning block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#body_scanning ZeroTrustGatewaySettings#body_scanning}
    */
    readonly bodyScanning?: ZeroTrustGatewaySettingsBodyScanning;
    /**
    * certificate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#certificate ZeroTrustGatewaySettings#certificate}
    */
    readonly certificate?: ZeroTrustGatewaySettingsCertificate;
    /**
    * custom_certificate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#custom_certificate ZeroTrustGatewaySettings#custom_certificate}
    */
    readonly customCertificate?: ZeroTrustGatewaySettingsCustomCertificate;
    /**
    * extended_email_matching block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#extended_email_matching ZeroTrustGatewaySettings#extended_email_matching}
    */
    readonly extendedEmailMatching?: ZeroTrustGatewaySettingsExtendedEmailMatching;
    /**
    * fips block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#fips ZeroTrustGatewaySettings#fips}
    */
    readonly fips?: ZeroTrustGatewaySettingsFips;
    /**
    * logging block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#logging ZeroTrustGatewaySettings#logging}
    */
    readonly logging?: ZeroTrustGatewaySettingsLogging;
    /**
    * payload_log block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#payload_log ZeroTrustGatewaySettings#payload_log}
    */
    readonly payloadLog?: ZeroTrustGatewaySettingsPayloadLog;
    /**
    * proxy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#proxy ZeroTrustGatewaySettings#proxy}
    */
    readonly proxy?: ZeroTrustGatewaySettingsProxy;
    /**
    * ssh_session_log block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#ssh_session_log ZeroTrustGatewaySettings#ssh_session_log}
    */
    readonly sshSessionLog?: ZeroTrustGatewaySettingsSshSessionLog;
}
export interface ZeroTrustGatewaySettingsAntivirusNotificationSettings {
    /**
    * Enable notification settings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Notification content.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#message ZeroTrustGatewaySettings#message}
    */
    readonly message?: string;
    /**
    * Support URL to show in the notification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#support_url ZeroTrustGatewaySettings#support_url}
    */
    readonly supportUrl?: string;
}
export declare function zeroTrustGatewaySettingsAntivirusNotificationSettingsToTerraform(struct?: ZeroTrustGatewaySettingsAntivirusNotificationSettingsOutputReference | ZeroTrustGatewaySettingsAntivirusNotificationSettings): any;
export declare function zeroTrustGatewaySettingsAntivirusNotificationSettingsToHclTerraform(struct?: ZeroTrustGatewaySettingsAntivirusNotificationSettingsOutputReference | ZeroTrustGatewaySettingsAntivirusNotificationSettings): any;
export declare class ZeroTrustGatewaySettingsAntivirusNotificationSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsAntivirusNotificationSettings | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsAntivirusNotificationSettings | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _message?;
    get message(): string;
    set message(value: string);
    resetMessage(): void;
    get messageInput(): string | undefined;
    private _supportUrl?;
    get supportUrl(): string;
    set supportUrl(value: string);
    resetSupportUrl(): void;
    get supportUrlInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsAntivirus {
    /**
    * Scan on file download.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#enabled_download_phase ZeroTrustGatewaySettings#enabled_download_phase}
    */
    readonly enabledDownloadPhase: boolean | cdktf.IResolvable;
    /**
    * Scan on file upload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#enabled_upload_phase ZeroTrustGatewaySettings#enabled_upload_phase}
    */
    readonly enabledUploadPhase: boolean | cdktf.IResolvable;
    /**
    * Block requests for files that cannot be scanned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#fail_closed ZeroTrustGatewaySettings#fail_closed}
    */
    readonly failClosed: boolean | cdktf.IResolvable;
    /**
    * notification_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#notification_settings ZeroTrustGatewaySettings#notification_settings}
    */
    readonly notificationSettings?: ZeroTrustGatewaySettingsAntivirusNotificationSettings;
}
export declare function zeroTrustGatewaySettingsAntivirusToTerraform(struct?: ZeroTrustGatewaySettingsAntivirusOutputReference | ZeroTrustGatewaySettingsAntivirus): any;
export declare function zeroTrustGatewaySettingsAntivirusToHclTerraform(struct?: ZeroTrustGatewaySettingsAntivirusOutputReference | ZeroTrustGatewaySettingsAntivirus): any;
export declare class ZeroTrustGatewaySettingsAntivirusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsAntivirus | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsAntivirus | undefined);
    private _enabledDownloadPhase?;
    get enabledDownloadPhase(): boolean | cdktf.IResolvable;
    set enabledDownloadPhase(value: boolean | cdktf.IResolvable);
    get enabledDownloadPhaseInput(): boolean | cdktf.IResolvable | undefined;
    private _enabledUploadPhase?;
    get enabledUploadPhase(): boolean | cdktf.IResolvable;
    set enabledUploadPhase(value: boolean | cdktf.IResolvable);
    get enabledUploadPhaseInput(): boolean | cdktf.IResolvable | undefined;
    private _failClosed?;
    get failClosed(): boolean | cdktf.IResolvable;
    set failClosed(value: boolean | cdktf.IResolvable);
    get failClosedInput(): boolean | cdktf.IResolvable | undefined;
    private _notificationSettings;
    get notificationSettings(): ZeroTrustGatewaySettingsAntivirusNotificationSettingsOutputReference;
    putNotificationSettings(value: ZeroTrustGatewaySettingsAntivirusNotificationSettings): void;
    resetNotificationSettings(): void;
    get notificationSettingsInput(): ZeroTrustGatewaySettingsAntivirusNotificationSettings | undefined;
}
export interface ZeroTrustGatewaySettingsBlockPage {
    /**
    * Hex code of block page background color.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#background_color ZeroTrustGatewaySettings#background_color}
    */
    readonly backgroundColor?: string;
    /**
    * Indicator of enablement.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Block page footer text.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#footer_text ZeroTrustGatewaySettings#footer_text}
    */
    readonly footerText?: string;
    /**
    * Block page header text.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#header_text ZeroTrustGatewaySettings#header_text}
    */
    readonly headerText?: string;
    /**
    * URL of block page logo.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#logo_path ZeroTrustGatewaySettings#logo_path}
    */
    readonly logoPath?: string;
    /**
    * Admin email for users to contact.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#mailto_address ZeroTrustGatewaySettings#mailto_address}
    */
    readonly mailtoAddress?: string;
    /**
    * Subject line for emails created from block page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#mailto_subject ZeroTrustGatewaySettings#mailto_subject}
    */
    readonly mailtoSubject?: string;
    /**
    * Name of block page configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#name ZeroTrustGatewaySettings#name}
    */
    readonly name?: string;
}
export declare function zeroTrustGatewaySettingsBlockPageToTerraform(struct?: ZeroTrustGatewaySettingsBlockPageOutputReference | ZeroTrustGatewaySettingsBlockPage): any;
export declare function zeroTrustGatewaySettingsBlockPageToHclTerraform(struct?: ZeroTrustGatewaySettingsBlockPageOutputReference | ZeroTrustGatewaySettingsBlockPage): any;
export declare class ZeroTrustGatewaySettingsBlockPageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsBlockPage | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsBlockPage | undefined);
    private _backgroundColor?;
    get backgroundColor(): string;
    set backgroundColor(value: string);
    resetBackgroundColor(): void;
    get backgroundColorInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _footerText?;
    get footerText(): string;
    set footerText(value: string);
    resetFooterText(): void;
    get footerTextInput(): string | undefined;
    private _headerText?;
    get headerText(): string;
    set headerText(value: string);
    resetHeaderText(): void;
    get headerTextInput(): string | undefined;
    private _logoPath?;
    get logoPath(): string;
    set logoPath(value: string);
    resetLogoPath(): void;
    get logoPathInput(): string | undefined;
    private _mailtoAddress?;
    get mailtoAddress(): string;
    set mailtoAddress(value: string);
    resetMailtoAddress(): void;
    get mailtoAddressInput(): string | undefined;
    private _mailtoSubject?;
    get mailtoSubject(): string;
    set mailtoSubject(value: string);
    resetMailtoSubject(): void;
    get mailtoSubjectInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsBodyScanning {
    /**
    * Body scanning inspection mode. Available values: `deep`, `shallow`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#inspection_mode ZeroTrustGatewaySettings#inspection_mode}
    */
    readonly inspectionMode: string;
}
export declare function zeroTrustGatewaySettingsBodyScanningToTerraform(struct?: ZeroTrustGatewaySettingsBodyScanningOutputReference | ZeroTrustGatewaySettingsBodyScanning): any;
export declare function zeroTrustGatewaySettingsBodyScanningToHclTerraform(struct?: ZeroTrustGatewaySettingsBodyScanningOutputReference | ZeroTrustGatewaySettingsBodyScanning): any;
export declare class ZeroTrustGatewaySettingsBodyScanningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsBodyScanning | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsBodyScanning | undefined);
    private _inspectionMode?;
    get inspectionMode(): string;
    set inspectionMode(value: string);
    get inspectionModeInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsCertificate {
    /**
    * ID of certificate for TLS interception.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#id ZeroTrustGatewaySettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function zeroTrustGatewaySettingsCertificateToTerraform(struct?: ZeroTrustGatewaySettingsCertificateOutputReference | ZeroTrustGatewaySettingsCertificate): any;
export declare function zeroTrustGatewaySettingsCertificateToHclTerraform(struct?: ZeroTrustGatewaySettingsCertificateOutputReference | ZeroTrustGatewaySettingsCertificate): any;
export declare class ZeroTrustGatewaySettingsCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsCertificate | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsCertificate | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsCustomCertificate {
    /**
    * Whether TLS encryption should use a custom certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * ID of custom certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#id ZeroTrustGatewaySettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export declare function zeroTrustGatewaySettingsCustomCertificateToTerraform(struct?: ZeroTrustGatewaySettingsCustomCertificateOutputReference | ZeroTrustGatewaySettingsCustomCertificate): any;
export declare function zeroTrustGatewaySettingsCustomCertificateToHclTerraform(struct?: ZeroTrustGatewaySettingsCustomCertificateOutputReference | ZeroTrustGatewaySettingsCustomCertificate): any;
export declare class ZeroTrustGatewaySettingsCustomCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsCustomCertificate | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsCustomCertificate | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get updatedAt(): string;
}
export interface ZeroTrustGatewaySettingsExtendedEmailMatching {
    /**
    * Whether e-mails should be matched on all variants of user emails (with + or . modifiers) in Firewall policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#enabled ZeroTrustGatewaySettings#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsExtendedEmailMatchingToTerraform(struct?: ZeroTrustGatewaySettingsExtendedEmailMatchingOutputReference | ZeroTrustGatewaySettingsExtendedEmailMatching): any;
export declare function zeroTrustGatewaySettingsExtendedEmailMatchingToHclTerraform(struct?: ZeroTrustGatewaySettingsExtendedEmailMatchingOutputReference | ZeroTrustGatewaySettingsExtendedEmailMatching): any;
export declare class ZeroTrustGatewaySettingsExtendedEmailMatchingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsExtendedEmailMatching | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsExtendedEmailMatching | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsFips {
    /**
    * Only allow FIPS-compliant TLS configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#tls ZeroTrustGatewaySettings#tls}
    */
    readonly tls?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsFipsToTerraform(struct?: ZeroTrustGatewaySettingsFipsOutputReference | ZeroTrustGatewaySettingsFips): any;
export declare function zeroTrustGatewaySettingsFipsToHclTerraform(struct?: ZeroTrustGatewaySettingsFipsOutputReference | ZeroTrustGatewaySettingsFips): any;
export declare class ZeroTrustGatewaySettingsFipsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsFips | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsFips | undefined);
    private _tls?;
    get tls(): boolean | cdktf.IResolvable;
    set tls(value: boolean | cdktf.IResolvable);
    resetTls(): void;
    get tlsInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns {
    /**
    * Whether to log all activity.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#log_all ZeroTrustGatewaySettings#log_all}
    */
    readonly logAll: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#log_blocks ZeroTrustGatewaySettings#log_blocks}
    */
    readonly logBlocks: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeDnsToTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDnsOutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns): any;
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeDnsToHclTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDnsOutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns): any;
export declare class ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns | undefined);
    private _logAll?;
    get logAll(): boolean | cdktf.IResolvable;
    set logAll(value: boolean | cdktf.IResolvable);
    get logAllInput(): boolean | cdktf.IResolvable | undefined;
    private _logBlocks?;
    get logBlocks(): boolean | cdktf.IResolvable;
    set logBlocks(value: boolean | cdktf.IResolvable);
    get logBlocksInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp {
    /**
    * Whether to log all activity.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#log_all ZeroTrustGatewaySettings#log_all}
    */
    readonly logAll: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#log_blocks ZeroTrustGatewaySettings#log_blocks}
    */
    readonly logBlocks: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttpToTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttpOutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp): any;
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttpToHclTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttpOutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp): any;
export declare class ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp | undefined);
    private _logAll?;
    get logAll(): boolean | cdktf.IResolvable;
    set logAll(value: boolean | cdktf.IResolvable);
    get logAllInput(): boolean | cdktf.IResolvable | undefined;
    private _logBlocks?;
    get logBlocks(): boolean | cdktf.IResolvable;
    set logBlocks(value: boolean | cdktf.IResolvable);
    get logBlocksInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4 {
    /**
    * Whether to log all activity.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#log_all ZeroTrustGatewaySettings#log_all}
    */
    readonly logAll: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#log_blocks ZeroTrustGatewaySettings#log_blocks}
    */
    readonly logBlocks: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4ToTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4OutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4): any;
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4ToHclTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4OutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4): any;
export declare class ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4 | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4 | undefined);
    private _logAll?;
    get logAll(): boolean | cdktf.IResolvable;
    set logAll(value: boolean | cdktf.IResolvable);
    get logAllInput(): boolean | cdktf.IResolvable | undefined;
    private _logBlocks?;
    get logBlocks(): boolean | cdktf.IResolvable;
    set logBlocks(value: boolean | cdktf.IResolvable);
    get logBlocksInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsLoggingSettingsByRuleType {
    /**
    * dns block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#dns ZeroTrustGatewaySettings#dns}
    */
    readonly dns: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns;
    /**
    * http block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#http ZeroTrustGatewaySettings#http}
    */
    readonly http: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp;
    /**
    * l4 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#l4 ZeroTrustGatewaySettings#l4}
    */
    readonly l4: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4;
}
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeToTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeOutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleType): any;
export declare function zeroTrustGatewaySettingsLoggingSettingsByRuleTypeToHclTerraform(struct?: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeOutputReference | ZeroTrustGatewaySettingsLoggingSettingsByRuleType): any;
export declare class ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsLoggingSettingsByRuleType | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleType | undefined);
    private _dns;
    get dns(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDnsOutputReference;
    putDns(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns): void;
    get dnsInput(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeDns | undefined;
    private _http;
    get http(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttpOutputReference;
    putHttp(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp): void;
    get httpInput(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeHttp | undefined;
    private _l4;
    get l4(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4OutputReference;
    putL4(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4): void;
    get l4Input(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeL4 | undefined;
}
export interface ZeroTrustGatewaySettingsLogging {
    /**
    * Redact personally identifiable information from activity logging (PII fields are: source IP, user email, user ID, device ID, URL, referrer, user agent).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#redact_pii ZeroTrustGatewaySettings#redact_pii}
    */
    readonly redactPii: boolean | cdktf.IResolvable;
    /**
    * settings_by_rule_type block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#settings_by_rule_type ZeroTrustGatewaySettings#settings_by_rule_type}
    */
    readonly settingsByRuleType: ZeroTrustGatewaySettingsLoggingSettingsByRuleType;
}
export declare function zeroTrustGatewaySettingsLoggingToTerraform(struct?: ZeroTrustGatewaySettingsLoggingOutputReference | ZeroTrustGatewaySettingsLogging): any;
export declare function zeroTrustGatewaySettingsLoggingToHclTerraform(struct?: ZeroTrustGatewaySettingsLoggingOutputReference | ZeroTrustGatewaySettingsLogging): any;
export declare class ZeroTrustGatewaySettingsLoggingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsLogging | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsLogging | undefined);
    private _redactPii?;
    get redactPii(): boolean | cdktf.IResolvable;
    set redactPii(value: boolean | cdktf.IResolvable);
    get redactPiiInput(): boolean | cdktf.IResolvable | undefined;
    private _settingsByRuleType;
    get settingsByRuleType(): ZeroTrustGatewaySettingsLoggingSettingsByRuleTypeOutputReference;
    putSettingsByRuleType(value: ZeroTrustGatewaySettingsLoggingSettingsByRuleType): void;
    get settingsByRuleTypeInput(): ZeroTrustGatewaySettingsLoggingSettingsByRuleType | undefined;
}
export interface ZeroTrustGatewaySettingsPayloadLog {
    /**
    * Public key used to encrypt matched payloads.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#public_key ZeroTrustGatewaySettings#public_key}
    */
    readonly publicKey: string;
}
export declare function zeroTrustGatewaySettingsPayloadLogToTerraform(struct?: ZeroTrustGatewaySettingsPayloadLogOutputReference | ZeroTrustGatewaySettingsPayloadLog): any;
export declare function zeroTrustGatewaySettingsPayloadLogToHclTerraform(struct?: ZeroTrustGatewaySettingsPayloadLogOutputReference | ZeroTrustGatewaySettingsPayloadLog): any;
export declare class ZeroTrustGatewaySettingsPayloadLogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsPayloadLog | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsPayloadLog | undefined);
    private _publicKey?;
    get publicKey(): string;
    set publicKey(value: string);
    get publicKeyInput(): string | undefined;
}
export interface ZeroTrustGatewaySettingsProxy {
    /**
    * Sets the time limit in seconds that a user can use an override code to bypass WARP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#disable_for_time ZeroTrustGatewaySettings#disable_for_time}
    */
    readonly disableForTime: number;
    /**
    * Whether root ca is enabled account wide for ZT clients.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#root_ca ZeroTrustGatewaySettings#root_ca}
    */
    readonly rootCa: boolean | cdktf.IResolvable;
    /**
    * Whether gateway proxy is enabled on gateway devices for TCP traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#tcp ZeroTrustGatewaySettings#tcp}
    */
    readonly tcp: boolean | cdktf.IResolvable;
    /**
    * Whether gateway proxy is enabled on gateway devices for UDP traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#udp ZeroTrustGatewaySettings#udp}
    */
    readonly udp: boolean | cdktf.IResolvable;
    /**
    * Whether virtual IP (CGNAT) is enabled account wide and will override existing local interface IP for ZT clients.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#virtual_ip ZeroTrustGatewaySettings#virtual_ip}
    */
    readonly virtualIp: boolean | cdktf.IResolvable;
}
export declare function zeroTrustGatewaySettingsProxyToTerraform(struct?: ZeroTrustGatewaySettingsProxyOutputReference | ZeroTrustGatewaySettingsProxy): any;
export declare function zeroTrustGatewaySettingsProxyToHclTerraform(struct?: ZeroTrustGatewaySettingsProxyOutputReference | ZeroTrustGatewaySettingsProxy): any;
export declare class ZeroTrustGatewaySettingsProxyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsProxy | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsProxy | undefined);
    private _disableForTime?;
    get disableForTime(): number;
    set disableForTime(value: number);
    get disableForTimeInput(): number | undefined;
    private _rootCa?;
    get rootCa(): boolean | cdktf.IResolvable;
    set rootCa(value: boolean | cdktf.IResolvable);
    get rootCaInput(): boolean | cdktf.IResolvable | undefined;
    private _tcp?;
    get tcp(): boolean | cdktf.IResolvable;
    set tcp(value: boolean | cdktf.IResolvable);
    get tcpInput(): boolean | cdktf.IResolvable | undefined;
    private _udp?;
    get udp(): boolean | cdktf.IResolvable;
    set udp(value: boolean | cdktf.IResolvable);
    get udpInput(): boolean | cdktf.IResolvable | undefined;
    private _virtualIp?;
    get virtualIp(): boolean | cdktf.IResolvable;
    set virtualIp(value: boolean | cdktf.IResolvable);
    get virtualIpInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustGatewaySettingsSshSessionLog {
    /**
    * Public key used to encrypt ssh session.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#public_key ZeroTrustGatewaySettings#public_key}
    */
    readonly publicKey: string;
}
export declare function zeroTrustGatewaySettingsSshSessionLogToTerraform(struct?: ZeroTrustGatewaySettingsSshSessionLogOutputReference | ZeroTrustGatewaySettingsSshSessionLog): any;
export declare function zeroTrustGatewaySettingsSshSessionLogToHclTerraform(struct?: ZeroTrustGatewaySettingsSshSessionLogOutputReference | ZeroTrustGatewaySettingsSshSessionLog): any;
export declare class ZeroTrustGatewaySettingsSshSessionLogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustGatewaySettingsSshSessionLog | undefined;
    set internalValue(value: ZeroTrustGatewaySettingsSshSessionLog | undefined);
    private _publicKey?;
    get publicKey(): string;
    set publicKey(value: string);
    get publicKeyInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings cloudflare_zero_trust_gateway_settings}
*/
export declare class ZeroTrustGatewaySettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_gateway_settings";
    /**
    * Generates CDKTF code for importing a ZeroTrustGatewaySettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustGatewaySettings to import
    * @param importFromId The id of the existing ZeroTrustGatewaySettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustGatewaySettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_gateway_settings cloudflare_zero_trust_gateway_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustGatewaySettingsConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustGatewaySettingsConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _activityLogEnabled?;
    get activityLogEnabled(): boolean | cdktf.IResolvable;
    set activityLogEnabled(value: boolean | cdktf.IResolvable);
    resetActivityLogEnabled(): void;
    get activityLogEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _nonIdentityBrowserIsolationEnabled?;
    get nonIdentityBrowserIsolationEnabled(): boolean | cdktf.IResolvable;
    set nonIdentityBrowserIsolationEnabled(value: boolean | cdktf.IResolvable);
    resetNonIdentityBrowserIsolationEnabled(): void;
    get nonIdentityBrowserIsolationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _protocolDetectionEnabled?;
    get protocolDetectionEnabled(): boolean | cdktf.IResolvable;
    set protocolDetectionEnabled(value: boolean | cdktf.IResolvable);
    resetProtocolDetectionEnabled(): void;
    get protocolDetectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _tlsDecryptEnabled?;
    get tlsDecryptEnabled(): boolean | cdktf.IResolvable;
    set tlsDecryptEnabled(value: boolean | cdktf.IResolvable);
    resetTlsDecryptEnabled(): void;
    get tlsDecryptEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _urlBrowserIsolationEnabled?;
    get urlBrowserIsolationEnabled(): boolean | cdktf.IResolvable;
    set urlBrowserIsolationEnabled(value: boolean | cdktf.IResolvable);
    resetUrlBrowserIsolationEnabled(): void;
    get urlBrowserIsolationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _antivirus;
    get antivirus(): ZeroTrustGatewaySettingsAntivirusOutputReference;
    putAntivirus(value: ZeroTrustGatewaySettingsAntivirus): void;
    resetAntivirus(): void;
    get antivirusInput(): ZeroTrustGatewaySettingsAntivirus | undefined;
    private _blockPage;
    get blockPage(): ZeroTrustGatewaySettingsBlockPageOutputReference;
    putBlockPage(value: ZeroTrustGatewaySettingsBlockPage): void;
    resetBlockPage(): void;
    get blockPageInput(): ZeroTrustGatewaySettingsBlockPage | undefined;
    private _bodyScanning;
    get bodyScanning(): ZeroTrustGatewaySettingsBodyScanningOutputReference;
    putBodyScanning(value: ZeroTrustGatewaySettingsBodyScanning): void;
    resetBodyScanning(): void;
    get bodyScanningInput(): ZeroTrustGatewaySettingsBodyScanning | undefined;
    private _certificate;
    get certificate(): ZeroTrustGatewaySettingsCertificateOutputReference;
    putCertificate(value: ZeroTrustGatewaySettingsCertificate): void;
    resetCertificate(): void;
    get certificateInput(): ZeroTrustGatewaySettingsCertificate | undefined;
    private _customCertificate;
    get customCertificate(): ZeroTrustGatewaySettingsCustomCertificateOutputReference;
    putCustomCertificate(value: ZeroTrustGatewaySettingsCustomCertificate): void;
    resetCustomCertificate(): void;
    get customCertificateInput(): ZeroTrustGatewaySettingsCustomCertificate | undefined;
    private _extendedEmailMatching;
    get extendedEmailMatching(): ZeroTrustGatewaySettingsExtendedEmailMatchingOutputReference;
    putExtendedEmailMatching(value: ZeroTrustGatewaySettingsExtendedEmailMatching): void;
    resetExtendedEmailMatching(): void;
    get extendedEmailMatchingInput(): ZeroTrustGatewaySettingsExtendedEmailMatching | undefined;
    private _fips;
    get fips(): ZeroTrustGatewaySettingsFipsOutputReference;
    putFips(value: ZeroTrustGatewaySettingsFips): void;
    resetFips(): void;
    get fipsInput(): ZeroTrustGatewaySettingsFips | undefined;
    private _logging;
    get logging(): ZeroTrustGatewaySettingsLoggingOutputReference;
    putLogging(value: ZeroTrustGatewaySettingsLogging): void;
    resetLogging(): void;
    get loggingInput(): ZeroTrustGatewaySettingsLogging | undefined;
    private _payloadLog;
    get payloadLog(): ZeroTrustGatewaySettingsPayloadLogOutputReference;
    putPayloadLog(value: ZeroTrustGatewaySettingsPayloadLog): void;
    resetPayloadLog(): void;
    get payloadLogInput(): ZeroTrustGatewaySettingsPayloadLog | undefined;
    private _proxy;
    get proxy(): ZeroTrustGatewaySettingsProxyOutputReference;
    putProxy(value: ZeroTrustGatewaySettingsProxy): void;
    resetProxy(): void;
    get proxyInput(): ZeroTrustGatewaySettingsProxy | undefined;
    private _sshSessionLog;
    get sshSessionLog(): ZeroTrustGatewaySettingsSshSessionLogOutputReference;
    putSshSessionLog(value: ZeroTrustGatewaySettingsSshSessionLog): void;
    resetSshSessionLog(): void;
    get sshSessionLogInput(): ZeroTrustGatewaySettingsSshSessionLog | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
