/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustInfrastructureAccessTargetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#account_id ZeroTrustInfrastructureAccessTarget#account_id}
    */
    readonly accountId: string;
    /**
    * A non-unique field that refers to a target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#hostname ZeroTrustInfrastructureAccessTarget#hostname}
    */
    readonly hostname: string;
    /**
    * The IPv4/IPv6 address that identifies where to reach a target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#ip ZeroTrustInfrastructureAccessTarget#ip}
    */
    readonly ip: ZeroTrustInfrastructureAccessTargetIp;
}
export interface ZeroTrustInfrastructureAccessTargetIpIpv4 {
    /**
    * The IP address of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#ip_addr ZeroTrustInfrastructureAccessTarget#ip_addr}
    */
    readonly ipAddr: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#virtual_network_id ZeroTrustInfrastructureAccessTarget#virtual_network_id}
    */
    readonly virtualNetworkId: string;
}
export declare function zeroTrustInfrastructureAccessTargetIpIpv4ToTerraform(struct?: ZeroTrustInfrastructureAccessTargetIpIpv4 | cdktf.IResolvable): any;
export declare function zeroTrustInfrastructureAccessTargetIpIpv4ToHclTerraform(struct?: ZeroTrustInfrastructureAccessTargetIpIpv4 | cdktf.IResolvable): any;
export declare class ZeroTrustInfrastructureAccessTargetIpIpv4OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustInfrastructureAccessTargetIpIpv4 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustInfrastructureAccessTargetIpIpv4 | cdktf.IResolvable | undefined);
    private _ipAddr?;
    get ipAddr(): string;
    set ipAddr(value: string);
    get ipAddrInput(): string | undefined;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    get virtualNetworkIdInput(): string | undefined;
}
export interface ZeroTrustInfrastructureAccessTargetIpIpv6 {
    /**
    * The IP address of the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#ip_addr ZeroTrustInfrastructureAccessTarget#ip_addr}
    */
    readonly ipAddr: string;
    /**
    * The private virtual network identifier for the target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#virtual_network_id ZeroTrustInfrastructureAccessTarget#virtual_network_id}
    */
    readonly virtualNetworkId: string;
}
export declare function zeroTrustInfrastructureAccessTargetIpIpv6ToTerraform(struct?: ZeroTrustInfrastructureAccessTargetIpIpv6 | cdktf.IResolvable): any;
export declare function zeroTrustInfrastructureAccessTargetIpIpv6ToHclTerraform(struct?: ZeroTrustInfrastructureAccessTargetIpIpv6 | cdktf.IResolvable): any;
export declare class ZeroTrustInfrastructureAccessTargetIpIpv6OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustInfrastructureAccessTargetIpIpv6 | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustInfrastructureAccessTargetIpIpv6 | cdktf.IResolvable | undefined);
    private _ipAddr?;
    get ipAddr(): string;
    set ipAddr(value: string);
    get ipAddrInput(): string | undefined;
    private _virtualNetworkId?;
    get virtualNetworkId(): string;
    set virtualNetworkId(value: string);
    get virtualNetworkIdInput(): string | undefined;
}
export interface ZeroTrustInfrastructureAccessTargetIp {
    /**
    * The target's IPv4 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#ipv4 ZeroTrustInfrastructureAccessTarget#ipv4}
    */
    readonly ipv4?: ZeroTrustInfrastructureAccessTargetIpIpv4;
    /**
    * The target's IPv6 address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#ipv6 ZeroTrustInfrastructureAccessTarget#ipv6}
    */
    readonly ipv6?: ZeroTrustInfrastructureAccessTargetIpIpv6;
}
export declare function zeroTrustInfrastructureAccessTargetIpToTerraform(struct?: ZeroTrustInfrastructureAccessTargetIp | cdktf.IResolvable): any;
export declare function zeroTrustInfrastructureAccessTargetIpToHclTerraform(struct?: ZeroTrustInfrastructureAccessTargetIp | cdktf.IResolvable): any;
export declare class ZeroTrustInfrastructureAccessTargetIpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustInfrastructureAccessTargetIp | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustInfrastructureAccessTargetIp | cdktf.IResolvable | undefined);
    private _ipv4;
    get ipv4(): ZeroTrustInfrastructureAccessTargetIpIpv4OutputReference;
    putIpv4(value: ZeroTrustInfrastructureAccessTargetIpIpv4): void;
    resetIpv4(): void;
    get ipv4Input(): cdktf.IResolvable | ZeroTrustInfrastructureAccessTargetIpIpv4 | undefined;
    private _ipv6;
    get ipv6(): ZeroTrustInfrastructureAccessTargetIpIpv6OutputReference;
    putIpv6(value: ZeroTrustInfrastructureAccessTargetIpIpv6): void;
    resetIpv6(): void;
    get ipv6Input(): cdktf.IResolvable | ZeroTrustInfrastructureAccessTargetIpIpv6 | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target cloudflare_zero_trust_infrastructure_access_target}
*/
export declare class ZeroTrustInfrastructureAccessTarget extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_infrastructure_access_target";
    /**
    * Generates CDKTF code for importing a ZeroTrustInfrastructureAccessTarget resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustInfrastructureAccessTarget to import
    * @param importFromId The id of the existing ZeroTrustInfrastructureAccessTarget that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustInfrastructureAccessTarget to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_infrastructure_access_target cloudflare_zero_trust_infrastructure_access_target} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustInfrastructureAccessTargetConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustInfrastructureAccessTargetConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get createdAt(): string;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    get hostnameInput(): string | undefined;
    get id(): string;
    private _ip;
    get ip(): ZeroTrustInfrastructureAccessTargetIpOutputReference;
    putIp(value: ZeroTrustInfrastructureAccessTargetIp): void;
    get ipInput(): cdktf.IResolvable | ZeroTrustInfrastructureAccessTargetIp | undefined;
    get modifiedAt(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
