/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ZeroTrustTunnelCloudflaredConfigAConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#account_id ZeroTrustTunnelCloudflaredConfigA#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#id ZeroTrustTunnelCloudflaredConfigA#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Identifier of the Tunnel to target for this configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#tunnel_id ZeroTrustTunnelCloudflaredConfigA#tunnel_id}
    */
    readonly tunnelId: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#config ZeroTrustTunnelCloudflaredConfigA#config}
    */
    readonly config: ZeroTrustTunnelCloudflaredConfigConfig;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess {
    /**
    * Audience tags of the access rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#aud_tag ZeroTrustTunnelCloudflaredConfigA#aud_tag}
    */
    readonly audTag?: string[];
    /**
    * Whether the access rule is required.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#required ZeroTrustTunnelCloudflaredConfigA#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * Name of the team to which the access rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#team_name ZeroTrustTunnelCloudflaredConfigA#team_name}
    */
    readonly teamName?: string;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccessToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccessOutputReference | ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccessToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccessOutputReference | ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess | undefined);
    private _audTag?;
    get audTag(): string[];
    set audTag(value: string[]);
    resetAudTag(): void;
    get audTagInput(): string[] | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _teamName?;
    get teamName(): string;
    set teamName(value: string);
    resetTeamName(): void;
    get teamNameInput(): string | undefined;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules {
    /**
    * Whether to allow the IP prefix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#allow ZeroTrustTunnelCloudflaredConfigA#allow}
    */
    readonly allow?: boolean | cdktf.IResolvable;
    /**
    * Ports to use within the IP rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ports ZeroTrustTunnelCloudflaredConfigA#ports}
    */
    readonly ports?: number[];
    /**
    * IP rule prefix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#prefix ZeroTrustTunnelCloudflaredConfigA#prefix}
    */
    readonly prefix?: string;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRulesToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules | cdktf.IResolvable): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRulesToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules | cdktf.IResolvable): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules | cdktf.IResolvable | undefined);
    private _allow?;
    get allow(): boolean | cdktf.IResolvable;
    set allow(value: boolean | cdktf.IResolvable);
    resetAllow(): void;
    get allowInput(): boolean | cdktf.IResolvable | undefined;
    private _ports?;
    get ports(): number[];
    set ports(value: number[]);
    resetPorts(): void;
    get portsInput(): number[] | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
}
export declare class ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRulesOutputReference;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest {
    /**
    * Runs as jump host.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#bastion_mode ZeroTrustTunnelCloudflaredConfigA#bastion_mode}
    */
    readonly bastionMode?: boolean | cdktf.IResolvable;
    /**
    * Path to the certificate authority (CA) for the certificate of your origin. This option should be used only if your certificate is not signed by Cloudflare. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ca_pool ZeroTrustTunnelCloudflaredConfigA#ca_pool}
    */
    readonly caPool?: string;
    /**
    * Timeout for establishing a new TCP connection to your origin server. This excludes the time taken to establish TLS, which is controlled by `tlsTimeout`. Defaults to `30s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#connect_timeout ZeroTrustTunnelCloudflaredConfigA#connect_timeout}
    */
    readonly connectTimeout?: string;
    /**
    * Disables chunked transfer encoding. Useful if you are running a Web Server Gateway Interface (WSGI) server. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#disable_chunked_encoding ZeroTrustTunnelCloudflaredConfigA#disable_chunked_encoding}
    */
    readonly disableChunkedEncoding?: boolean | cdktf.IResolvable;
    /**
    * Enables HTTP/2 support for the origin connection. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#http2_origin ZeroTrustTunnelCloudflaredConfigA#http2_origin}
    */
    readonly http2Origin?: boolean | cdktf.IResolvable;
    /**
    * Sets the HTTP Host header on requests sent to the local service. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#http_host_header ZeroTrustTunnelCloudflaredConfigA#http_host_header}
    */
    readonly httpHostHeader?: string;
    /**
    * Maximum number of idle keepalive connections between Tunnel and your origin. This does not restrict the total number of concurrent connections. Defaults to `100`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#keep_alive_connections ZeroTrustTunnelCloudflaredConfigA#keep_alive_connections}
    */
    readonly keepAliveConnections?: number;
    /**
    * Timeout after which an idle keepalive connection can be discarded. Defaults to `1m30s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#keep_alive_timeout ZeroTrustTunnelCloudflaredConfigA#keep_alive_timeout}
    */
    readonly keepAliveTimeout?: string;
    /**
    * Disable the “happy eyeballs” algorithm for IPv4/IPv6 fallback if your local network has misconfigured one of the protocols. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#no_happy_eyeballs ZeroTrustTunnelCloudflaredConfigA#no_happy_eyeballs}
    */
    readonly noHappyEyeballs?: boolean | cdktf.IResolvable;
    /**
    * Disables TLS verification of the certificate presented by your origin. Will allow any certificate from the origin to be accepted. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#no_tls_verify ZeroTrustTunnelCloudflaredConfigA#no_tls_verify}
    */
    readonly noTlsVerify?: boolean | cdktf.IResolvable;
    /**
    * Hostname that cloudflared should expect from your origin server certificate. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#origin_server_name ZeroTrustTunnelCloudflaredConfigA#origin_server_name}
    */
    readonly originServerName?: string;
    /**
    * cloudflared starts a proxy server to translate HTTP traffic into TCP when proxying, for example, SSH or RDP. This configures the listen address for that proxy. Defaults to `127.0.0.1`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#proxy_address ZeroTrustTunnelCloudflaredConfigA#proxy_address}
    */
    readonly proxyAddress?: string;
    /**
    * cloudflared starts a proxy server to translate HTTP traffic into TCP when proxying, for example, SSH or RDP. This configures the listen port for that proxy. If set to zero, an unused port will randomly be chosen. Defaults to `0`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#proxy_port ZeroTrustTunnelCloudflaredConfigA#proxy_port}
    */
    readonly proxyPort?: number;
    /**
    * cloudflared starts a proxy server to translate HTTP traffic into TCP when proxying, for example, SSH or RDP. This configures what type of proxy will be started. Available values: `""`, `socks`. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#proxy_type ZeroTrustTunnelCloudflaredConfigA#proxy_type}
    */
    readonly proxyType?: string;
    /**
    * The timeout after which a TCP keepalive packet is sent on a connection between Tunnel and the origin server. Defaults to `30s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#tcp_keep_alive ZeroTrustTunnelCloudflaredConfigA#tcp_keep_alive}
    */
    readonly tcpKeepAlive?: string;
    /**
    * Timeout for completing a TLS handshake to your origin server, if you have chosen to connect Tunnel to an HTTPS server. Defaults to `10s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#tls_timeout ZeroTrustTunnelCloudflaredConfigA#tls_timeout}
    */
    readonly tlsTimeout?: string;
    /**
    * access block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#access ZeroTrustTunnelCloudflaredConfigA#access}
    */
    readonly access?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess;
    /**
    * ip_rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ip_rules ZeroTrustTunnelCloudflaredConfigA#ip_rules}
    */
    readonly ipRules?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules[] | cdktf.IResolvable;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestOutputReference | ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestOutputReference | ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest | undefined);
    private _bastionMode?;
    get bastionMode(): boolean | cdktf.IResolvable;
    set bastionMode(value: boolean | cdktf.IResolvable);
    resetBastionMode(): void;
    get bastionModeInput(): boolean | cdktf.IResolvable | undefined;
    private _caPool?;
    get caPool(): string;
    set caPool(value: string);
    resetCaPool(): void;
    get caPoolInput(): string | undefined;
    private _connectTimeout?;
    get connectTimeout(): string;
    set connectTimeout(value: string);
    resetConnectTimeout(): void;
    get connectTimeoutInput(): string | undefined;
    private _disableChunkedEncoding?;
    get disableChunkedEncoding(): boolean | cdktf.IResolvable;
    set disableChunkedEncoding(value: boolean | cdktf.IResolvable);
    resetDisableChunkedEncoding(): void;
    get disableChunkedEncodingInput(): boolean | cdktf.IResolvable | undefined;
    private _http2Origin?;
    get http2Origin(): boolean | cdktf.IResolvable;
    set http2Origin(value: boolean | cdktf.IResolvable);
    resetHttp2Origin(): void;
    get http2OriginInput(): boolean | cdktf.IResolvable | undefined;
    private _httpHostHeader?;
    get httpHostHeader(): string;
    set httpHostHeader(value: string);
    resetHttpHostHeader(): void;
    get httpHostHeaderInput(): string | undefined;
    private _keepAliveConnections?;
    get keepAliveConnections(): number;
    set keepAliveConnections(value: number);
    resetKeepAliveConnections(): void;
    get keepAliveConnectionsInput(): number | undefined;
    private _keepAliveTimeout?;
    get keepAliveTimeout(): string;
    set keepAliveTimeout(value: string);
    resetKeepAliveTimeout(): void;
    get keepAliveTimeoutInput(): string | undefined;
    private _noHappyEyeballs?;
    get noHappyEyeballs(): boolean | cdktf.IResolvable;
    set noHappyEyeballs(value: boolean | cdktf.IResolvable);
    resetNoHappyEyeballs(): void;
    get noHappyEyeballsInput(): boolean | cdktf.IResolvable | undefined;
    private _noTlsVerify?;
    get noTlsVerify(): boolean | cdktf.IResolvable;
    set noTlsVerify(value: boolean | cdktf.IResolvable);
    resetNoTlsVerify(): void;
    get noTlsVerifyInput(): boolean | cdktf.IResolvable | undefined;
    private _originServerName?;
    get originServerName(): string;
    set originServerName(value: string);
    resetOriginServerName(): void;
    get originServerNameInput(): string | undefined;
    private _proxyAddress?;
    get proxyAddress(): string;
    set proxyAddress(value: string);
    resetProxyAddress(): void;
    get proxyAddressInput(): string | undefined;
    private _proxyPort?;
    get proxyPort(): number;
    set proxyPort(value: number);
    resetProxyPort(): void;
    get proxyPortInput(): number | undefined;
    private _proxyType?;
    get proxyType(): string;
    set proxyType(value: string);
    resetProxyType(): void;
    get proxyTypeInput(): string | undefined;
    private _tcpKeepAlive?;
    get tcpKeepAlive(): string;
    set tcpKeepAlive(value: string);
    resetTcpKeepAlive(): void;
    get tcpKeepAliveInput(): string | undefined;
    private _tlsTimeout?;
    get tlsTimeout(): string;
    set tlsTimeout(value: string);
    resetTlsTimeout(): void;
    get tlsTimeoutInput(): string | undefined;
    private _access;
    get access(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccessOutputReference;
    putAccess(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess): void;
    resetAccess(): void;
    get accessInput(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestAccess | undefined;
    private _ipRules;
    get ipRules(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRulesList;
    putIpRules(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules[] | cdktf.IResolvable): void;
    resetIpRules(): void;
    get ipRulesInput(): cdktf.IResolvable | ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestIpRules[] | undefined;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigIngressRule {
    /**
    * Hostname to match the incoming request with. If the hostname matches, the request will be sent to the service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#hostname ZeroTrustTunnelCloudflaredConfigA#hostname}
    */
    readonly hostname?: string;
    /**
    * Path of the incoming request. If the path matches, the request will be sent to the local service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#path ZeroTrustTunnelCloudflaredConfigA#path}
    */
    readonly path?: string;
    /**
    * Name of the service to which the request will be sent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#service ZeroTrustTunnelCloudflaredConfigA#service}
    */
    readonly service: string;
    /**
    * origin_request block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#origin_request ZeroTrustTunnelCloudflaredConfigA#origin_request}
    */
    readonly originRequest?: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRule | cdktf.IResolvable): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigIngressRuleToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigIngressRule | cdktf.IResolvable): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigIngressRule | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRule | cdktf.IResolvable | undefined);
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    resetHostname(): void;
    get hostnameInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
    private _originRequest;
    get originRequest(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequestOutputReference;
    putOriginRequest(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest): void;
    resetOriginRequest(): void;
    get originRequestInput(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOriginRequest | undefined;
}
export declare class ZeroTrustTunnelCloudflaredConfigConfigIngressRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustTunnelCloudflaredConfigConfigIngressRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleOutputReference;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess {
    /**
    * Audience tags of the access rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#aud_tag ZeroTrustTunnelCloudflaredConfigA#aud_tag}
    */
    readonly audTag?: string[];
    /**
    * Whether the access rule is required.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#required ZeroTrustTunnelCloudflaredConfigA#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * Name of the team to which the access rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#team_name ZeroTrustTunnelCloudflaredConfigA#team_name}
    */
    readonly teamName?: string;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigOriginRequestAccessToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccessOutputReference | ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigOriginRequestAccessToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccessOutputReference | ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess | undefined);
    private _audTag?;
    get audTag(): string[];
    set audTag(value: string[]);
    resetAudTag(): void;
    get audTagInput(): string[] | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _teamName?;
    get teamName(): string;
    set teamName(value: string);
    resetTeamName(): void;
    get teamNameInput(): string | undefined;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules {
    /**
    * Whether to allow the IP prefix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#allow ZeroTrustTunnelCloudflaredConfigA#allow}
    */
    readonly allow?: boolean | cdktf.IResolvable;
    /**
    * Ports to use within the IP rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ports ZeroTrustTunnelCloudflaredConfigA#ports}
    */
    readonly ports?: number[];
    /**
    * IP rule prefix.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#prefix ZeroTrustTunnelCloudflaredConfigA#prefix}
    */
    readonly prefix?: string;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRulesToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules | cdktf.IResolvable): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRulesToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules | cdktf.IResolvable): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules | cdktf.IResolvable | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules | cdktf.IResolvable | undefined);
    private _allow?;
    get allow(): boolean | cdktf.IResolvable;
    set allow(value: boolean | cdktf.IResolvable);
    resetAllow(): void;
    get allowInput(): boolean | cdktf.IResolvable | undefined;
    private _ports?;
    get ports(): number[];
    set ports(value: number[]);
    resetPorts(): void;
    get portsInput(): number[] | undefined;
    private _prefix?;
    get prefix(): string;
    set prefix(value: string);
    resetPrefix(): void;
    get prefixInput(): string | undefined;
}
export declare class ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRulesOutputReference;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigOriginRequest {
    /**
    * Runs as jump host.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#bastion_mode ZeroTrustTunnelCloudflaredConfigA#bastion_mode}
    */
    readonly bastionMode?: boolean | cdktf.IResolvable;
    /**
    * Path to the certificate authority (CA) for the certificate of your origin. This option should be used only if your certificate is not signed by Cloudflare. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ca_pool ZeroTrustTunnelCloudflaredConfigA#ca_pool}
    */
    readonly caPool?: string;
    /**
    * Timeout for establishing a new TCP connection to your origin server. This excludes the time taken to establish TLS, which is controlled by `tlsTimeout`. Defaults to `30s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#connect_timeout ZeroTrustTunnelCloudflaredConfigA#connect_timeout}
    */
    readonly connectTimeout?: string;
    /**
    * Disables chunked transfer encoding. Useful if you are running a Web Server Gateway Interface (WSGI) server. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#disable_chunked_encoding ZeroTrustTunnelCloudflaredConfigA#disable_chunked_encoding}
    */
    readonly disableChunkedEncoding?: boolean | cdktf.IResolvable;
    /**
    * Enables HTTP/2 support for the origin connection. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#http2_origin ZeroTrustTunnelCloudflaredConfigA#http2_origin}
    */
    readonly http2Origin?: boolean | cdktf.IResolvable;
    /**
    * Sets the HTTP Host header on requests sent to the local service. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#http_host_header ZeroTrustTunnelCloudflaredConfigA#http_host_header}
    */
    readonly httpHostHeader?: string;
    /**
    * Maximum number of idle keepalive connections between Tunnel and your origin. This does not restrict the total number of concurrent connections. Defaults to `100`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#keep_alive_connections ZeroTrustTunnelCloudflaredConfigA#keep_alive_connections}
    */
    readonly keepAliveConnections?: number;
    /**
    * Timeout after which an idle keepalive connection can be discarded. Defaults to `1m30s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#keep_alive_timeout ZeroTrustTunnelCloudflaredConfigA#keep_alive_timeout}
    */
    readonly keepAliveTimeout?: string;
    /**
    * Disable the “happy eyeballs” algorithm for IPv4/IPv6 fallback if your local network has misconfigured one of the protocols. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#no_happy_eyeballs ZeroTrustTunnelCloudflaredConfigA#no_happy_eyeballs}
    */
    readonly noHappyEyeballs?: boolean | cdktf.IResolvable;
    /**
    * Disables TLS verification of the certificate presented by your origin. Will allow any certificate from the origin to be accepted. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#no_tls_verify ZeroTrustTunnelCloudflaredConfigA#no_tls_verify}
    */
    readonly noTlsVerify?: boolean | cdktf.IResolvable;
    /**
    * Hostname that cloudflared should expect from your origin server certificate. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#origin_server_name ZeroTrustTunnelCloudflaredConfigA#origin_server_name}
    */
    readonly originServerName?: string;
    /**
    * cloudflared starts a proxy server to translate HTTP traffic into TCP when proxying, for example, SSH or RDP. This configures the listen address for that proxy. Defaults to `127.0.0.1`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#proxy_address ZeroTrustTunnelCloudflaredConfigA#proxy_address}
    */
    readonly proxyAddress?: string;
    /**
    * cloudflared starts a proxy server to translate HTTP traffic into TCP when proxying, for example, SSH or RDP. This configures the listen port for that proxy. If set to zero, an unused port will randomly be chosen. Defaults to `0`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#proxy_port ZeroTrustTunnelCloudflaredConfigA#proxy_port}
    */
    readonly proxyPort?: number;
    /**
    * cloudflared starts a proxy server to translate HTTP traffic into TCP when proxying, for example, SSH or RDP. This configures what type of proxy will be started. Available values: `""`, `socks`. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#proxy_type ZeroTrustTunnelCloudflaredConfigA#proxy_type}
    */
    readonly proxyType?: string;
    /**
    * The timeout after which a TCP keepalive packet is sent on a connection between Tunnel and the origin server. Defaults to `30s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#tcp_keep_alive ZeroTrustTunnelCloudflaredConfigA#tcp_keep_alive}
    */
    readonly tcpKeepAlive?: string;
    /**
    * Timeout for completing a TLS handshake to your origin server, if you have chosen to connect Tunnel to an HTTPS server. Defaults to `10s`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#tls_timeout ZeroTrustTunnelCloudflaredConfigA#tls_timeout}
    */
    readonly tlsTimeout?: string;
    /**
    * access block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#access ZeroTrustTunnelCloudflaredConfigA#access}
    */
    readonly access?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess;
    /**
    * ip_rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ip_rules ZeroTrustTunnelCloudflaredConfigA#ip_rules}
    */
    readonly ipRules?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules[] | cdktf.IResolvable;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigOriginRequestToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestOutputReference | ZeroTrustTunnelCloudflaredConfigConfigOriginRequest): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigOriginRequestToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestOutputReference | ZeroTrustTunnelCloudflaredConfigConfigOriginRequest): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigOriginRequestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequest | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigOriginRequest | undefined);
    private _bastionMode?;
    get bastionMode(): boolean | cdktf.IResolvable;
    set bastionMode(value: boolean | cdktf.IResolvable);
    resetBastionMode(): void;
    get bastionModeInput(): boolean | cdktf.IResolvable | undefined;
    private _caPool?;
    get caPool(): string;
    set caPool(value: string);
    resetCaPool(): void;
    get caPoolInput(): string | undefined;
    private _connectTimeout?;
    get connectTimeout(): string;
    set connectTimeout(value: string);
    resetConnectTimeout(): void;
    get connectTimeoutInput(): string | undefined;
    private _disableChunkedEncoding?;
    get disableChunkedEncoding(): boolean | cdktf.IResolvable;
    set disableChunkedEncoding(value: boolean | cdktf.IResolvable);
    resetDisableChunkedEncoding(): void;
    get disableChunkedEncodingInput(): boolean | cdktf.IResolvable | undefined;
    private _http2Origin?;
    get http2Origin(): boolean | cdktf.IResolvable;
    set http2Origin(value: boolean | cdktf.IResolvable);
    resetHttp2Origin(): void;
    get http2OriginInput(): boolean | cdktf.IResolvable | undefined;
    private _httpHostHeader?;
    get httpHostHeader(): string;
    set httpHostHeader(value: string);
    resetHttpHostHeader(): void;
    get httpHostHeaderInput(): string | undefined;
    private _keepAliveConnections?;
    get keepAliveConnections(): number;
    set keepAliveConnections(value: number);
    resetKeepAliveConnections(): void;
    get keepAliveConnectionsInput(): number | undefined;
    private _keepAliveTimeout?;
    get keepAliveTimeout(): string;
    set keepAliveTimeout(value: string);
    resetKeepAliveTimeout(): void;
    get keepAliveTimeoutInput(): string | undefined;
    private _noHappyEyeballs?;
    get noHappyEyeballs(): boolean | cdktf.IResolvable;
    set noHappyEyeballs(value: boolean | cdktf.IResolvable);
    resetNoHappyEyeballs(): void;
    get noHappyEyeballsInput(): boolean | cdktf.IResolvable | undefined;
    private _noTlsVerify?;
    get noTlsVerify(): boolean | cdktf.IResolvable;
    set noTlsVerify(value: boolean | cdktf.IResolvable);
    resetNoTlsVerify(): void;
    get noTlsVerifyInput(): boolean | cdktf.IResolvable | undefined;
    private _originServerName?;
    get originServerName(): string;
    set originServerName(value: string);
    resetOriginServerName(): void;
    get originServerNameInput(): string | undefined;
    private _proxyAddress?;
    get proxyAddress(): string;
    set proxyAddress(value: string);
    resetProxyAddress(): void;
    get proxyAddressInput(): string | undefined;
    private _proxyPort?;
    get proxyPort(): number;
    set proxyPort(value: number);
    resetProxyPort(): void;
    get proxyPortInput(): number | undefined;
    private _proxyType?;
    get proxyType(): string;
    set proxyType(value: string);
    resetProxyType(): void;
    get proxyTypeInput(): string | undefined;
    private _tcpKeepAlive?;
    get tcpKeepAlive(): string;
    set tcpKeepAlive(value: string);
    resetTcpKeepAlive(): void;
    get tcpKeepAliveInput(): string | undefined;
    private _tlsTimeout?;
    get tlsTimeout(): string;
    set tlsTimeout(value: string);
    resetTlsTimeout(): void;
    get tlsTimeoutInput(): string | undefined;
    private _access;
    get access(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccessOutputReference;
    putAccess(value: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess): void;
    resetAccess(): void;
    get accessInput(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestAccess | undefined;
    private _ipRules;
    get ipRules(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRulesList;
    putIpRules(value: ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules[] | cdktf.IResolvable): void;
    resetIpRules(): void;
    get ipRulesInput(): cdktf.IResolvable | ZeroTrustTunnelCloudflaredConfigConfigOriginRequestIpRules[] | undefined;
}
export interface ZeroTrustTunnelCloudflaredConfigConfigWarpRouting {
    /**
    * Whether WARP routing is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#enabled ZeroTrustTunnelCloudflaredConfigA#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigWarpRoutingToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigWarpRoutingOutputReference | ZeroTrustTunnelCloudflaredConfigConfigWarpRouting): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigWarpRoutingToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigWarpRoutingOutputReference | ZeroTrustTunnelCloudflaredConfigConfigWarpRouting): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigWarpRoutingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfigWarpRouting | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfigWarpRouting | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ZeroTrustTunnelCloudflaredConfigConfig {
    /**
    * ingress_rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#ingress_rule ZeroTrustTunnelCloudflaredConfigA#ingress_rule}
    */
    readonly ingressRule: ZeroTrustTunnelCloudflaredConfigConfigIngressRule[] | cdktf.IResolvable;
    /**
    * origin_request block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#origin_request ZeroTrustTunnelCloudflaredConfigA#origin_request}
    */
    readonly originRequest?: ZeroTrustTunnelCloudflaredConfigConfigOriginRequest;
    /**
    * warp_routing block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#warp_routing ZeroTrustTunnelCloudflaredConfigA#warp_routing}
    */
    readonly warpRouting?: ZeroTrustTunnelCloudflaredConfigConfigWarpRouting;
}
export declare function zeroTrustTunnelCloudflaredConfigConfigToTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOutputReference | ZeroTrustTunnelCloudflaredConfigConfig): any;
export declare function zeroTrustTunnelCloudflaredConfigConfigToHclTerraform(struct?: ZeroTrustTunnelCloudflaredConfigConfigOutputReference | ZeroTrustTunnelCloudflaredConfigConfig): any;
export declare class ZeroTrustTunnelCloudflaredConfigConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ZeroTrustTunnelCloudflaredConfigConfig | undefined;
    set internalValue(value: ZeroTrustTunnelCloudflaredConfigConfig | undefined);
    private _ingressRule;
    get ingressRule(): ZeroTrustTunnelCloudflaredConfigConfigIngressRuleList;
    putIngressRule(value: ZeroTrustTunnelCloudflaredConfigConfigIngressRule[] | cdktf.IResolvable): void;
    get ingressRuleInput(): cdktf.IResolvable | ZeroTrustTunnelCloudflaredConfigConfigIngressRule[] | undefined;
    private _originRequest;
    get originRequest(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequestOutputReference;
    putOriginRequest(value: ZeroTrustTunnelCloudflaredConfigConfigOriginRequest): void;
    resetOriginRequest(): void;
    get originRequestInput(): ZeroTrustTunnelCloudflaredConfigConfigOriginRequest | undefined;
    private _warpRouting;
    get warpRouting(): ZeroTrustTunnelCloudflaredConfigConfigWarpRoutingOutputReference;
    putWarpRouting(value: ZeroTrustTunnelCloudflaredConfigConfigWarpRouting): void;
    resetWarpRouting(): void;
    get warpRoutingInput(): ZeroTrustTunnelCloudflaredConfigConfigWarpRouting | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config cloudflare_zero_trust_tunnel_cloudflared_config}
*/
export declare class ZeroTrustTunnelCloudflaredConfigA extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_zero_trust_tunnel_cloudflared_config";
    /**
    * Generates CDKTF code for importing a ZeroTrustTunnelCloudflaredConfigA resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ZeroTrustTunnelCloudflaredConfigA to import
    * @param importFromId The id of the existing ZeroTrustTunnelCloudflaredConfigA that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ZeroTrustTunnelCloudflaredConfigA to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.46.0/docs/resources/zero_trust_tunnel_cloudflared_config cloudflare_zero_trust_tunnel_cloudflared_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ZeroTrustTunnelCloudflaredConfigAConfig
    */
    constructor(scope: Construct, id: string, config: ZeroTrustTunnelCloudflaredConfigAConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _tunnelId?;
    get tunnelId(): string;
    set tunnelId(value: string);
    get tunnelIdInput(): string | undefined;
    private _config;
    get config(): ZeroTrustTunnelCloudflaredConfigConfigOutputReference;
    putConfig(value: ZeroTrustTunnelCloudflaredConfigConfig): void;
    get configInput(): ZeroTrustTunnelCloudflaredConfigConfig | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
